% calc_SMB_anom

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% Load basins

load('../out/int/basins/all_basins.mat');
load('../out/int/discharge/balance/balance_discharge.mat');

%% RACMO

disp('Processing RACMO');

% Get info 
fn = 'RACMO2.3p2_ERA5_ANT27_smb_monthly_1979_01_2021_12.nc';
RACMO_time = datenum(1950,1,1) + ncread(fn,'time');
lat = ncread(fn,'lat');
lon = ncread(fn,'lon');
[x_smb,y_smb] = ll2ps(lat,lon);
clear lat lon 

% Get number of days in each RACMO month
[Yrs,Ms,~] = datevec(RACMO_time);
Es = eomday(Yrs,Ms);

% Load
smb = ncread(fn,'smb');
smb(smb<0.01 & smb>-0.01)=NaN;
smb = permute(smb,[1,2,4,3]);

% Get long-term mean in every pixel
idx = find(RACMO_time>=datenum(1979,1,1) & RACMO_time<datenum(2009,1,1));
smb_avg = nanmean(smb(:,:,idx),3);
nanval = smb_avg(1);
smb_avg(smb_avg==nanval) = NaN;

% Calculate anomaly in every pixel
smb(smb==nanval) = NaN;
smb_anom_3D = smb - repmat(smb_avg,[1,1,length(RACMO_time)]);
smb_anom_3D = cube2rect(smb_anom_3D)'; % reshapes so that each row represents a single pixel through time

% Spatially integrate anomaly over each basin
RACMO_smb_anom = zeros([numel(basins.name),length(RACMO_time)]).*NaN;
for i = 1:numel(basins.name)
    % get pixels in basin
    tf = RACMO_tf_all{i};
    % integrate
    RACMO_smb_anom(i,:) = nanmean(smb_anom_3D(tf,:),1).*basins.area(i).*1e-12./Es'.*365.25;
end
disp([num2str(sum(isnan(RACMO_smb_anom(:)))) ' NaNs still there']);
RACMO_smb_anom(isnan(RACMO_smb_anom)) = 0;

%% MAR

disp('Processing MAR')

% Load MAR monthly SMB
smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','SMB');
x_smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','X');
y_smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','Y');
MAR_time = double(ncread('mon-SMB-MAR_ERA5-1980-2021.nc','TIME') + datenum(1977,3,1));

% Get number of days in each MAR month
[Yrs,Ms,~] = datevec(MAR_time);
Es = eomday(Yrs,Ms);

% Only keep area in ice mask
smb = squeeze(smb(:,:,1,:));

% set x and y to units metres
x_smb = x_smb.*1000;
y_smb = y_smb.*1000;
[x_smb,y_smb] = meshgrid(x_smb,y_smb);

% Set nans
smb(smb==0)=NaN;

% Get long-term mean in every pixel
idx = find(MAR_time>=datenum(1979,1,1) & MAR_time<datenum(2009,1,1)); % note, MAR starts in 1980, so this a 29-year climatology
smb_avg = nanmean(smb(:,:,idx),3);
nanval = smb_avg(1);
smb_avg(smb_avg==nanval) = NaN;

% Flip and rotate
smb_avg = flipud(rot90(smb_avg));
dummy = zeros([size(smb_avg),size(smb,3)]).*NaN;
for i = 1:size(smb,3)
    dummy(:,:,i) = flipud(rot90(smb(:,:,i)));
end
smb = dummy;
smb(smb==nanval)=NaN;
clear dummy

% Calculate anomaly in every pixel
smb_anom_3D = smb - repmat(smb_avg,[1,1,length(MAR_time)]);
smb_anom_3D = cube2rect(smb_anom_3D)'; % reshapes so that each row represents a single pixel through time

% Spatially integrate anomaly over each basin
MAR_smb_anom = zeros([numel(basins.name),length(MAR_time)]).*NaN;
for i = 1:numel(basins.name)
    % get pixels in basin
    tf = MAR_tf_all{i};
    % integrate
    MAR_smb_anom(i,:) = nanmean(smb_anom_3D(tf,:),1).*basins.area(i).*1e-12./Es'.*365.25;
end
disp([num2str(sum(isnan(MAR_smb_anom(:)))) ' NaNs still there']);
MAR_smb_anom(isnan(MAR_smb_anom)) = 0;


%% HIRHAM

disp('Processing HIRHAM')

% Get list of all HIRHAM files
if ispc
    filelist = [dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_1979-1989/*.nc') ;...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_1990-1999/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2000-2009/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2010-2017/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2018/*.nc')];
else
    filelist = [dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_1979-1989/*.nc') ;...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_1990-1999/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2000-2009/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2010-2017/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2018/*.nc')];
end
fn = filelist(1).name;

% info
smb_lat = ncread(fn,'lat');
smb_lon = ncread(fn,'lon');
[x_smb,y_smb] = ll2ps(smb_lat,smb_lon);

% Time
HIRHAM_daily_time = datenum(1979,1,1):datenum(2018,12,31);
HIRHAM_time = RACMO_time(RACMO_time<datenum(2019,1,1));

% Load and calculate monthly average HIRHAM
smb = zeros([size(x_smb),length(HIRHAM_time)]).*NaN;
for i = 1:length(HIRHAM_time)
    [Yr,M,~] = datevec(HIRHAM_time(i));
    time_start = datenum(Yr,M,1);
    time_end = datenum(Yr,M+1,1)-1;
    idx = find(HIRHAM_daily_time>=time_start & HIRHAM_daily_time<=time_end);
    count = 0;
    HIRHAM_this_month = zeros([size(x_smb),length(idx)]).*NaN;
    for j = 1:length(idx)
        count = count + 1;
        HIRHAM_this_month(:,:,count) = ncread([filelist(idx(j)).folder '/' filelist(idx(j)).name],'gld');
    end
    HIRHAM_this_month(HIRHAM_this_month==-9999)=NaN;
    nanval = HIRHAM_this_month(1);
    HIRHAM_this_month(HIRHAM_this_month==nanval) = NaN;
    smb(:,:,i) = nanmean(HIRHAM_this_month,3);
end
clear HIRHAM_this_month 

% Get long-term mean in every pixel
idx = find(HIRHAM_time>=datenum(1979,1,1) & HIRHAM_time<datenum(2009,1,1)); 
smb_avg = nanmean(smb(:,:,idx),3);

% Calculate anomaly in every pixel
smb_anom_3D = smb - repmat(smb_avg,[1,1,length(HIRHAM_time)]);
smb_anom_3D = cube2rect(smb_anom_3D)'; % reshapes so that each row represents a single pixel through time

% Spatially integrate anomaly over each basin
HIRHAM_smb_anom = zeros([numel(basins.name),length(HIRHAM_time)]).*NaN;
for i = 1:numel(basins.name)
    % get pixels in basin
    tf = HIRHAM_tf_all{i};
    % integrate
    HIRHAM_smb_anom(i,:) = nanmean(smb_anom_3D(tf,:),1).*basins.area(i).*1e-12.*365.25;
end
disp([num2str(sum(isnan(HIRHAM_smb_anom(:)))) ' NaNs still there']);
HIRHAM_smb_anom(isnan(HIRHAM_smb_anom)) = 0;

%% Calculate ensemble mean
% RACMO: '16-Jan-1979' - '16-Dec-2021'
% MAR: '16-Jan-1980 12:00:00' - '16-Dec-2021 12:00:00
% HIRHAM: '16-Jan-1979' - '16-Dec-2018'

MAR_missing = size(RACMO_smb_anom,2) - size(MAR_smb_anom,2);
HIRHAM_missing = size(RACMO_smb_anom,2) - size(HIRHAM_smb_anom,2);
MAR_smb_anom = [zeros([numel(basins.name),MAR_missing]).*NaN , MAR_smb_anom];
HIRHAM_smb_anom = [HIRHAM_smb_anom, zeros([numel(basins.name),HIRHAM_missing]).*NaN];
ens_smb_anom = nanmean(cat(3,RACMO_smb_anom,MAR_smb_anom,HIRHAM_smb_anom),3);
smb_time = RACMO_time;


%% Save
save('../out/int/derived/basin_smb_anom.mat','ens_smb_anom','smb_time','RACMO_smb_anom','RACMO_time','HIRHAM_smb_anom','HIRHAM_time','MAR_smb_anom','MAR_time');


