% calc_balance_discharge

clear
close all
clc

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/RACMO'));
    addpath(genpath('/resstore/b0133/Data/MAR'));
    addpath(genpath('/resstore/b0133/Data/HIRHAM'));
end

% load basins
load('../out/int/basins/all_basins.mat');

%% Extract climatological SMB in each basin

disp('Processing RACMO');

% Get info 
fn = 'RACMO2.3p2_ERA5_ANT27_smb_monthly_1979_01_2021_12.nc';
smb_time = datenum(1950,1,1) + ncread(fn,'time');
lat = ncread(fn,'lat');
lon = ncread(fn,'lon');
[x_smb,y_smb] = ll2ps(lat,lon);
clear lat lon 

% Load
smb = ncread(fn,'smb');
smb(smb<0.01 & smb>-0.01)=NaN;
smb = permute(smb,[1,2,4,3]);

% Get long-term mean in every pixel
idx = find(smb_time>=datenum(1979,1,1) & smb_time<datenum(2009,1,1));
smb_avg = nanmean(smb(:,:,idx),3);
nanval = smb_avg(1);
smb_avg(smb_avg==nanval) = NaN;

% prepare uncertainty range
start_times = datenum(1979:1989,1,1);
end_times = datenum(1999:2009,1,1);
Qbal_range_RACMO = zeros([numel(basins.name),length(start_times)]).*NaN;

% Integrate climatology over each basin and convert to Gt/yr to approximate
% balance discharge
Qbal_RACMO = zeros([numel(basins.name),1]).*NaN;
RACMO_tf_all = cell([numel(basins.name),1]);
for i = 1:numel(basins.name)
    disp([' - basin: ' num2str(i) '/' num2str(numel(basins.name))]);
    % get pixels in basin
    tf = inpoly2([x_smb(:),y_smb(:)],[basins.x{i},basins.y{i}]);
    % check for basins that are either smaller than a pixel or not covered by racmo
    if sum(tf)==0 || sum(isfinite(smb_avg(tf))) == 0
        d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
        d(isnan(smb_avg(:))) = NaN;
        tf = find(d(:) == nanmin(d(:)),1,'first');
    end
    RACMO_tf_all{i} = tf;
    % integrate
    Qbal_RACMO(i) = nanmean(smb_avg(tf))*basins.area(i)*1e-12/30.437*365.25; % divide by average number of days in month
    
    for j = 1:length(start_times)
        idx = find(smb_time>=start_times(j) & smb_time<end_times(j));
        smb_tmp = nanmean(smb(:,:,idx),3);
        nanval = smb_tmp(1);
        smb_tmp(smb_tmp==nanval) = NaN;
        if sum(tf)==0 || sum(isfinite(smb_tmp(tf)))==0
            d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
            d(isnan(smb_tmp(:))) = NaN;
            tf = find(d(:) == nanmin(d(:)),1,'first');
        end
        Qbal_range_RACMO(i,j) = nanmean(smb_tmp(tf))*basins.area(i)*1e-12/30.437*365.25; % divide by average number of days in month
    end
end
Qbal_err_RACMO = nanstd(Qbal_range_RACMO,[],2);

% Save RACMO output
RACMO_time = smb_time;
save('../out/int/discharge/balance/RACMO_balance_discharge.mat','Qbal_RACMO','Qbal_err_RACMO','RACMO_time','RACMO_tf_all','-v7.3');



%% Repeat with MAR

disp(' ');
disp('Processing MAR')

% Load MAR monthly SMB
smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','SMB');
x_smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','X');
y_smb = ncread('mon-SMB-MAR_ERA5-1980-2021.nc','Y');
smb_time = double(ncread('mon-SMB-MAR_ERA5-1980-2021.nc','TIME') + datenum(1977,3,1));

% Only keep area in ice mask
smb = squeeze(smb(:,:,1,:));

% set x and y to units metres
x_smb = x_smb.*1000;
y_smb = y_smb.*1000;
[x_smb,y_smb] = meshgrid(x_smb,y_smb);

% Set nans
smb(smb==0)=NaN;

% Get long-term mean in every pixel
idx = find(smb_time>=datenum(1979,1,1) & smb_time<datenum(2009,1,1)); % note, MAR starts in 1980, so this a 29-year climatology
smb_avg = nanmean(smb(:,:,idx),3);
nanval = smb_avg(1);
smb_avg(smb_avg==nanval) = NaN;

% Flip and rotate
smb_avg = flipud(rot90(smb_avg));

% prepare uncertainty range
start_times = datenum(1979:1989,1,1);
end_times = datenum(1999:2009,1,1);
Qbal_range_MAR = zeros([numel(basins.name),length(start_times)]).*NaN;

% Integrate climatology over each basin and convert to Gt/yr to approximate
% balance discharge
Qbal_MAR = zeros([numel(basins.name),1]).*NaN;
MAR_tf_all = cell([numel(basins.name),1]);
for i = 1:numel(basins.name)
    disp([' - basin: ' num2str(i) '/' num2str(numel(basins.name))]);
    % get pixels in basin
    tf = inpoly2([x_smb(:),y_smb(:)],[basins.x{i},basins.y{i}]);
    % check for basins that are either smaller than a pixel or not covered by MAR
    if sum(tf)==0 || sum(isfinite(smb_avg(tf))) == 0
        d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
        d(isnan(smb_avg(:))) = NaN;
        tf = find(d(:) == nanmin(d(:)),1,'first');
    end
    MAR_tf_all{i} = tf;
    % integrate
    Qbal_MAR(i) = nanmean(smb_avg(tf))*basins.area(i)*1e-12/30.437*365.25; % divide by average number of days in month
    
    for j = 1:length(start_times)
        idx = find(smb_time>=start_times(j) & smb_time<end_times(j));
        smb_tmp = nanmean(smb(:,:,idx),3);
        nanval = smb_tmp(1);
        smb_tmp(smb_tmp==nanval) = NaN;
        if sum(tf)==0 || sum(isfinite(smb_tmp(tf)))==0
            d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
            d(isnan(smb_tmp(:))) = NaN;
            tf = find(d(:) == nanmin(d(:)),1,'first');
        end
        Qbal_range_MAR(i,j) = nanmean(smb_tmp(tf))*basins.area(i)*1e-12/30.437*365.25; % divide by average number of days in month
    end
end
Qbal_err_MAR = nanstd(Qbal_range_MAR,[],2);

% Save MAR output
MAR_time = smb_time;
save('../out/int/discharge/balance/MAR_balance_discharge.mat','Qbal_MAR','Qbal_err_MAR','MAR_time','MAR_tf_all','-v7.3');



%% Repeat for HIRHAM

disp(' ');
disp('Processing HIRHAM')

% Get list of all HIRHAM files
if ispc
    filelist = [dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_1979-1989/*.nc') ;...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_1990-1999/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2000-2009/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2010-2017/*.nc');...
        dir('D:\work\Fellowship_Leeds\Data\HIRHAM/ANT22_trans-Daily2D_2018/*.nc')];
else
    filelist = [dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_1979-1989/*.nc') ;...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_1990-1999/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2000-2009/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2010-2017/*.nc');...
        dir('/resstore/b0133/Data/HIRHAM/ANT22_trans-Daily2D_2018/*.nc')];
end
fn = filelist(1).name;

% Subset over ASE
smb_lat = ncread(fn,'lat');
smb_lon = ncread(fn,'lon');
[x_smb,y_smb] = ll2ps(smb_lat,smb_lon);

% Set time (daily from 1979,1,1 to 2018,12,31
smb_daily_time = datenum(1979,1,1):datenum(2018,12,31);
smb_time = datenum(1950,1,1) + ncread('RACMO2.3p2_ERA5_ANT27_smb_monthly_1979_01_2021_12.nc','time');
smb_time = smb_time(smb_time<datenum(2019,1,1));

% Load; Units are mm w.e. per day
% Load and calculate monthly average HIRHAM
smb = zeros([size(x_smb),length(smb_time)]).*NaN;
for i = 1:length(smb_time)
    [Yr,M,~] = datevec(smb_time(i));
    time_start = datenum(Yr,M,1);
    time_end = datenum(Yr,M+1,1)-1;
    idx = find(smb_daily_time>=time_start & smb_daily_time<=time_end);
    count = 0;
    HIRHAM_this_month = zeros([size(x_smb),length(idx)]).*NaN;
    for j = 1:length(idx)
        count = count + 1;
        HIRHAM_this_month(:,:,count) = ncread([filelist(idx(j)).folder '/' filelist(idx(j)).name],'gld');
    end
    HIRHAM_this_month(HIRHAM_this_month==-9999)=NaN;
    nanval = HIRHAM_this_month(1);
    HIRHAM_this_month(HIRHAM_this_month==nanval) = NaN;
    smb(:,:,i) = nanmean(HIRHAM_this_month,3);
end
clear HIRHAM_this_month 

% Get long-term mean in every pixel
idx = find(smb_time>=datenum(1979,1,1) & smb_time<datenum(2009,1,1)); 
smb_avg = nanmean(smb(:,:,idx),3);

% prepare uncertainty range
start_times = datenum(1979:1989,1,1);
end_times = datenum(1999:2009,1,1);
Qbal_range_HIRHAM = zeros([numel(basins.name),length(start_times)]).*NaN;

% Integrate climatology over each basin and convert to Gt/yr to approximate
% balance discharge
Qbal_HIRHAM = zeros([numel(basins.name),1]).*NaN;
HIRHAM_tf_all = cell([numel(basins.name),1]);
for i = 1:numel(basins.name)
    disp([' - basin: ' num2str(i) '/' num2str(numel(basins.name))]);
    % get pixels in basin
    tf = inpoly2([x_smb(:),y_smb(:)],[basins.x{i},basins.y{i}]);
    % check for basins that are either smaller than a pixel or not covered by HIRHAM
    if sum(tf)==0 || sum(isfinite(smb_avg(tf))) == 0
        d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
        d(isnan(smb_avg(:))) = NaN;
        tf = find(d(:) == nanmin(d(:)),1,'first');
    end
    HIRHAM_tf_all{i} = tf;
    % integrate
    Qbal_HIRHAM(i) = nanmean(smb_avg(tf))*basins.area(i)*1e-12*365.25; % divide by average number of days in month
    
    for j = 1:length(start_times)
        idx = find(smb_time>=start_times(j) & smb_time<end_times(j));
        smb_tmp = nanmean(smb(:,:,idx),3);
        nanval = smb_tmp(1);
        smb_tmp(smb_tmp==nanval) = NaN;
        if sum(tf)==0 || sum(isfinite(smb_tmp(tf)))==0
            d = sqrt((basins.centroid(i,1)-x_smb(:)).^2 + (basins.centroid(i,2)-y_smb(:)).^2);
            d(isnan(smb_tmp(:))) = NaN;
            tf = find(d(:) == nanmin(d(:)),1,'first');
        end
        Qbal_range_HIRHAM(i,j) = nanmean(smb_tmp(tf))*basins.area(i)*1e-12*365.25; % divide by average number of days in month
    end
end
Qbal_err_HIRHAM = nanstd(Qbal_range_HIRHAM,[],2);

% Save HIRHAM output
HIRHAM_time = smb_time;
save('../out/int/discharge/balance/HIRHAM_balance_discharge.mat','Qbal_HIRHAM','Qbal_err_HIRHAM','HIRHAM_time','HIRHAM_tf_all','-v7.3');

% 3-model mean
Qbal_ens = nanmean([Qbal_HIRHAM,Qbal_MAR,Qbal_RACMO],2);
Qbal_err_ens = sqrt(Qbal_err_HIRHAM.^2 + Qbal_err_MAR.^2 + Qbal_err_RACMO.^2);

%% Save

% save
save('../out/int/discharge/balance/balance_discharge.mat','Qbal_RACMO','Qbal_err_RACMO',...
    'Qbal_MAR','Qbal_err_MAR',...
    'Qbal_HIRHAM','Qbal_err_HIRHAM',...
	'Qbal_ens','Qbal_err_ens');



