% invert_discharge

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% Load data

% Basins
load('../out/int/basins/all_basins.mat');

% balance discharge
Qbal = load('../out/int/discharge/balance/balance_discharge.mat');
Qbal.ens = nanmean([Qbal.Qbal_HIRHAM,Qbal.Qbal_MAR,Qbal.Qbal_RACMO],2);
Qbal.ensE = sqrt(Qbal.Qbal_err_HIRHAM.^2 + Qbal.Qbal_err_MAR.^2 + Qbal.Qbal_err_RACMO.^2);

% SMB anomaly timeseries (Gt/yr)
smb = load('../out/int/derived/basin_smb_anom.mat');
smb.anom_smooth = movmean(smb.ens_smb_anom,60,2,'omitnan');
smb.err = abs(smb.anom_smooth).*0.1; % placeholder

% dHdt timeseries
dH = load('../out/int/mass_balance/basin_quadratic_dH.mat');

%% We have total thickness change from 1996 to 2023
% Get the average rate of thickness change and average smb anomaly during that time period

% SMB
idx = find(smb.smb_time>=datenum(1996,1,1) & smb.smb_time<=datenum(2014,1,1));
smb.anom_smooth = smb.anom_smooth(:,idx);
smb.anom_smooth = nanmean(smb.anom_smooth,2);
smb.anom_smooth_err = Qbal.ensE;

% dH
t = 1:1/12:32; % years from 1991
dH.dH_time = datenum(1991+t,1,15);
idx = find(dH.dH_time>=datenum(1996,1,1) & dH.dH_time<=datenum(2014,1,1)); 
num_years = (dH.dH_time(idx(end)) - dH.dH_time(idx(1)))/365.25; 
dH.avg_dHdt_Gt = dH.basin_dH_Gt./num_years; 
dH.avg_dHdt_err_Gt = dH.basin_dH_err_Gt./num_years;

%% Calculate discharge

% normally, we would calculate mass balance as
%   mb = smb-d;
% which is the same as
%   mb = (refSMB+SMBanom) - d;
% So if we assume that dHdt is representative of mb (it must be over some
% timescale), then
%   d = (refSMB+SMBanom) - mb;

% calculate discharge
Qinv = (smb.anom_smooth + Qbal.ens) - dH.avg_dHdt_Gt;
Qinv_err = sqrt(smb.anom_smooth_err.^2 + Qbal.ensE.^2 + dH.avg_dHdt_err_Gt.^2);

% Some basins have negative Qinv<0
Qinv(Qinv<0) = 0;

% plot inverted discharge
ind = find(basins.type_ID==2);
cpts = 0:100;
cmap = colorcet('Gouldian','N',length(cpts));
% fill basins
figure('color','w');
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qinv(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar;
colormap(colorcet('Gouldian'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(0,100,length(cb.Ticks));
ylabel(cb,'Discharge (Gt/yr)');
export_fig('../out/int/discharge/inverted/basin_discharge_invert_Gtyr.png','-dpng','-r300');


% save
save('../out/int/discharge/inverted/inverted_discharge.mat','Qinv','Qinv_err');

