% comparison_with_other_publications

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Import Gardner data

data = readtable('gardner_raw.txt','ReadVariableNames',false);%,'NumHeaderLines',1);
tmp1 = data.Var4; % 2008 discharge and error
tmp2 = data.Var5; % 2015 discharge and error
Qg = zeros([numel(tmp1),2]).*NaN;
Eg = zeros([numel(tmp1),2]).*NaN;
% this is discharge for 27 zwally basins, then EAIS, WAIS, AP and AIS
for i = 1:numel(tmp1)
    tmp1b = strsplit(cell2mat(tmp1(i)),'');
    tmp2b = strsplit(cell2mat(tmp2(i)),'');
    Qg(i,:) = [str2double(tmp1b{1}), str2double(tmp2b{1})]; % discharge in 2008 and 2015
    Eg(i,:) = [str2double(tmp1b{2}), str2double(tmp2b{2})]; % error in 2008 and 2015
end
clear data tmp1 tmp2 tmp1b tmp2b

%% Import Depoorter data

[~,dnames] = xlsread('depoorter.xlsx','B3:B29');
Qd = xlsread('depoorter.xlsx','D3:D29');
Ed = xlsread('depoorter.xlsx','E3:E29');


%% Import Rignot data

% load rignot data
fn = 'pnas.1812883116.sd01.xlsx';
[~,names] = xlsread(fn,'A5:A193');
Qr = xlsread(fn,'K5:AW193');
rtime = datenum(1979:2017,7,1);
[~,type_tmp] = xlsread(fn,'J5:J193');

% Remove Islands discharge from total
Qr(end,:) = Qr(end,:) - 76.9899;
Qr(end-1,:) = [];
names(end-1) = [];
type_tmp(end-1) = [];

% Clean up the rignot names
rnames = cell([numel(names),1]);
for i = 1:numel(names)
    rname = names{i};
    rname = strtrim(rname); % remove leading whitespace
    if contains(rname,'_')
        rname = strrep(rname,'_',' '); % remove underscores
    end
    rnames{i} = rname;
end

% Clean up the type
rtype = zeros([numel(names),1]).*NaN;
for i = 1:numel(type_tmp)
    t = type_tmp{i};
    if ~isempty(t)
        t = strrep(t,'[',''); % 
        t = strrep(t,']',''); % 
        rtype(i) = str2double(t);
    end
end

%% Load my discharge

% load data
FB_mean = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
B2_mean = ncread('../out/pub/discharge/nc/AIS_discharge_BedMap2.nc','discharge_mean');
FB_se = 1.96.*ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
B2_se = 1.96.*ncread('../out/pub/discharge/nc/AIS_discharge_BedMap2.nc','discharge_standard_error');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% basin info
basins = readBasinInfo;


%% Compare with Gardner

idx08 = find(time>datenum(2007,1,1) & time<datenum(2010,1,1));
idx15 = find(time>datenum(2015,1,1) & time<datenum(2016,1,1));
Q08 = nanmean(FB_mean(:,idx08),2);
Q15 = nanmean(FB_mean(:,idx15),2); 
E08 = rssq(FB_se(:,idx08),2);
E15 = rssq(FB_se(:,idx15),2);

% Set basin names
basin_names = 1:27;
gnames = arrayfun(@num2str, 1:27, 'UniformOutput', 0);

% get index of zwally basins in our data
basin_idx = find(basins.type_ID==3);
basin_idx = basin_idx(basin_idx>10); % skip the AIS, WAIS, EAIS and AP for now

% Get the residuals
resid08 = Q08(basin_idx) - Qg(1:27,1);
resid15 = Q15(basin_idx) - Qg(1:27,2);
[~,iv] = sort(abs(resid08),'descend'); % get index of sorted residuals

% Get the percentage residuals
relresid08 = resid08./Q08(basin_idx).*100;
relresid15 = resid15./Q15(basin_idx).*100;
[~,reliv] = sort(abs(relresid08),'descend'); % get index of sorted residuals


%% Compare with Depoorter

use = time>datenum(2007,1,1) & time<datenum(2010,1,1);

% pre-allocate
bQd = zeros([numel(dnames),1]).*NaN;
bQdE = zeros([numel(dnames),1]).*NaN;

% Extract our discharge for Depoorter basins
for i = 1:numel(dnames)
    
    % Get the index of this depoorter basin on our basin dataset
    rind = find(strcmpi(basins.name,dnames{i})==1,1,'last'); % do a quick check, which works for most basins
    if strcmpi(dnames{i},'Moscow University')
        rind = find(strcmpi('Moscow_University_IS',basins.name)==1,1,'last'); % use the ice shelf version
    elseif strcmpi(dnames{i},'Crosson and Dotson')
        rind = find(strcmpi('Crosson_IS',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Dotson_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Pine Island')
        rind = find(strcmpi('Pine_Island_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'George VI')
        rind = find(strcmpi('George_VI_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Larsen B-C')
        rind = find(strcmpi('Larsen_B_IS',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Larsen_C_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Filchner-Ronne')
        rind = find(strcmpi('Filchner_IS',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Ronne_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Brunt and Riiser-Larsen')
        rind = find(strcmpi('Brunt_Stancomb_IS',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Riiser_Larsen_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Jelbart and Fimbul')
        rind = find(strcmpi('Jelbart',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Fimbul_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Ross')
        rind = find(strcmpi('Ross_East_IS',basins.name)==1,1,'last');
        rind(2) = find(strcmpi('Ross_West_IS',basins.name)==1,1,'last');
    elseif strcmpi(dnames{i},'Venable')
        rind = find(strcmpi('Venable',basins.name)==1,1,'first');
    end
    
    % Get our data
    tmp = FB_mean(rind,use);
    tmp = nanmean(tmp,2); % time-average
    bQd(i) = nansum(tmp); % sum discharge across various required basins
    tmp = FB_se(rind,use);
    tmp = rssq(tmp,2); % time-average
    bQdE(i) = (rssq(tmp));
end

% keep the residuals
residsd = bQd-Qd;
relresidsd = residsd./bQd.*100;


%% Compare with Rignot

% Only compare with actual observations 
mask = ismember(rtype,[1,3,5]); % 1,3,5 for all with any bed data. Just 1 for only bedmap2

% which bit of rignot time to use
use = rtime>datenum(1996,1,1);

% Plot time-series to start with
for i = 1:numel(mask)
    %if mask(i) == 1
        
        % Get the rignot data
        rts = Qr(i,:);
        rname = rnames{i};
        
        % Get the index of this rignot basin on our basin dataset
        rind = find(strcmpi(basins.name,rname)==1,1,'first'); % do a quick check, which works for most basins
        if strcmpi(rname,'George VI')
            rind = find(strcmpi('George VI',basins.name)==1,1,'last'); % use the ice shelf version
        end
        if isempty(rind)
            rind = find(strcmpi(basins.name,[rname '_IS'])==1,1,'first');
        end
        if isempty(rind)
            if strcmpi(rname,'Stancomb Wills')
                rind = find(strcmpi('Brunt Stancomb',basins.name)==1);
            elseif strcmpi(rname,'Denman')
                rind = find(strcmpi('Denman Scott',basins.name)==1);
            elseif strcmpi(rname,'Drygalski Ice Shelf')
                rind = find(strcmpi('David',basins.name)==1);
            elseif strcmpi(rname,'Drygalski Headland')
                rind = find(strcmpi('Drygalskis Headland',basins.name)==1);
            elseif strcmpi(rname,'West Ice Shelf')
                rind = find(strcmpi('Leopold and Astrid Coast',basins.name)==1); 
            elseif strcmpi(rname,'Prince Harald Ice Shelf')
                rind = find(strcmpi('Prince Harald',basins.name)==1); 
            elseif strcmpi(rname,'Wilkins Ice Shelf')
                rind = find(strcmpi('Wilkins_IS',basins.name)==1,1,'last'); 
            elseif strcmpi(rname,'Wilma Robert Downer')
                rind = find(strcmpi('WilmaRobertDowner',basins.name)==1);
            elseif strcmpi(rname,'Harriott Ice Shelf')
                rind = find(strcmpi('Harriott',basins.name)==1);
            elseif strcmpi(rname,'George VI')
                rind = find(strcmpi('George_VI_IS',basins.name)==1,1,'last'); % use the ice shelf version
            elseif strcmpi(rname,'WAIS')
                rind = find(strcmpi('West_Antarctica_Rignot',basins.name)==1);
            elseif strcmpi(rname,'EAIS')
                rind = find(strcmpi('East_Antarctica_Rignot',basins.name)==1);
            elseif strcmpi(rname,'AP')
                rind = find(strcmpi('Peninsula_Rignot',basins.name)==1);
            elseif strcmpi(rname,'TOTAL SURVEYED')
                rind = find(strcmpi('Antarctica',basins.name)==1);
            elseif strcmpi(rname,'LarsenB')
                rind = find(strcmp('Larsen_B_IS',basins.name)==1);
            elseif strcmp(rname,'Wilkins Island')
                rind = find(strcmp('Hp-I',basins.name)==1);
            elseif strcmp(rname,'Ruppert Coast')
                rind = find(strcmp('Ruppert Coast2',basins.name)==1);
            elseif strcmp(rname,'Shirases Coast')
                rind = find(strcmp('Shirases Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Ross West')
                rind = find(strcmpi('Ross_West_IS',basins.name)==1,1,'last');
            elseif strcmp(rname,'Ross East')
                rind = find(strcmpi('Ross_East_IS',basins.name)==1,1,'last');
            elseif strcmp(rname,'Victoria Land')
                rind = find(strcmp('Victoria Land1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:) + FB_mean(rind+2,:);
            elseif strcmp(rname,'Oates Coast')
                rind = find(strcmp('Oates Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Wilkes Land')
                rind = find(strcmp('Wilkes Land1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Sabrina Coast')
                rind = find(strcmp('Sabrina Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmpi(rname,'Amery Ice Shelf')
                rind = find(strcmpi('Amery_IS',basins.name)==1,1,'last');
            elseif strcmp(rname,'Prince Harald Coast')
                rind = find(strcmp('Prince Harald Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Princess Astrid')
                rind = find(strcmp('Princess Astrid Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Princess Martha')
                rind = find(strcmp('Princess Martha Coast1',basins.name)==1);
                FB_mean(rind,:) = FB_mean(rind,:) + FB_mean(rind+1,:);
            elseif strcmp(rname,'Wordie')
                rind = find(strcmp('Wordie_IS',basins.name)==1);
            end  
        end
        rinds(i) = rind;
        rnames_Davison{i} = basins.name{rind};
        
        % Plot both
        figure('color','w','units','inches','position',[1 1 2.5 1],'visible','off');
        plot(rtime(use),rts(use),'r+','linewidth',1); datetick('x'); hold on;
        if rtype(i) == 1
            shadedErrorBar(time,FB_mean(rind,:),FB_se(rind,:)); % use BedMap2
        else
            shadedErrorBar(time,FB_mean(rind,:),FB_se(rind,:));
        end
        box on
        ylabel('Discharge (Gt yr^{-1})','fontname','Helvetica','fontsize',8);
        title(basins.name{rind},'interpreter','none','fontname','Helvetica','fontsize',8);
        export_fig(['../out/pub/figures/comparison/rignot_timeseries/' basins.name{rind} '.png'],'-dpng','-r150');
        close
        
    %end
end

% add negligible random noise to time to help with plotting
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);
        
% Add the rignot data
mask = ismember(rtype,1); % 1,3,5 for all with any bed data. Just 1 for only bedmap2
resids = [];
relresids = [];
avg_resids = [];
avg_relresids = [];
count = 0;
for i = 1:numel(mask)
    count = count+1;
    if rtype(i) == 1
        ts = FB_mean(rinds(i),:);
    else
        ts = FB_mean(rinds(i),:);
    end
    ts = interp1gap(time,ts,rtime);
    %scatter(ts,Qr(i,:),12,'b','filled');
    resids = [resids(:)',ts-Qr(i,:)];
    relresids = [relresids(:)',(ts-Qr(i,:))./ts.*100];
    avg_resids = [avg_resids(:)', nanmean(abs(ts-Qr(i,:)))];
    avg_relresids = [avg_relresids(:)', nanmean(abs(ts-Qr(i,:)))./nanmean(ts).*100];
    rnames_use{count} = rnames_Davison{i};
    avg_bQr(count) = nanmean(ts);
    avg_Qr(count) = nanmean(Qr(i,:));
end

% Reset some discharge time-series
%   - Shirases Coast
rind = find(strcmp('Shirases Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
% - Victoria land
rind = find(strcmp('Victoria Land1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:) - FB_mean(rind+2,:);
%   - Oates coast
rind = find(strcmp('Oates Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
%   - Wilkes Land
rind = find(strcmp('Wilkes Land1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
%   - Sabrina Coast
rind = find(strcmp('Sabrina Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
%   - Prince Harald Coast
rind = find(strcmp('Prince Harald Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
%   - Princess Astrid Coast
rind = find(strcmp('Princess Astrid Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
%   - Princess Martha Coast
rind = find(strcmp('Princess Martha Coast1',basins.name)==1);
FB_mean(rind,:) = FB_mean(rind,:) - FB_mean(rind+1,:);
                
%% Concatenate everthing

% Basin names
all_names = cat(1,gnames(:),gnames(:),dnames,rnames_use(:));

% Discharge
Davison_data = [Q08(basin_idx) ; Q15(basin_idx) ; bQd ; avg_bQr(:)];
Davison_err = [E08(basin_idx); E15(basin_idx) ; bQdE ;avg_bQr(:).*0]; 
Other_data = [Qg(1:27,1); Qg(1:27,2); Qd ; avg_Qr(:)];
Other_err = [Eg(1:27,1); Eg(1:27,2); Ed; avg_Qr(:).*0];
source = [ones([27*2,1]) ; ones([length(Qd),1]).*2  ; ones([length(avg_Qr),1]).*3]; 
source_name = cell([length(source),1]);
for i = 1:length(source)
    if source(i) == 1
        source_name{i} = 'Gardner';
    elseif source(i) == 2
        source_name{i} = 'Depoorter';
    elseif source(i) == 3
        source_name{i} = 'Rignot';
    end
end

% Residuals
resids = [resid08(:); resid15(:); residsd; resids(:)];
relresids = [relresid08(:); relresid15(:); relresidsd; relresids(:)];
avg_resids = [resid08(:); resid15(:); residsd; avg_resids(:)];
avg_relresids = [relresid08(:); relresid15(:); relresidsd; avg_relresids(:)];

% Tabulate for ease of comparison
T = table(all_names,Davison_data,Davison_err,Other_data,Other_err,avg_resids(:),avg_relresids(:),source_name,'VariableNames',{'Basin','Davison_discharge','Davison_error','Other_discharge','Other_error','Residual','RelResidual','Other_source'});


%% scatter plot each basin 

% Plot full size
figure('color','w','units','inches','position',[1 1 2 2]);
plot([0 250],[0 250],'k--'); hold on
errorbar(Davison_data(source==1),Other_data(source==1),Other_err(source==1),Other_err(source==1),Davison_err(source==1),Davison_err(source==1),'ko','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==2),Other_data(source==2),Other_err(source==2),Other_err(source==2),Davison_err(source==2),Davison_err(source==2),'bo','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==3),Other_data(source==3),Other_err(source==3),Other_err(source==3),Davison_err(source==3),Davison_err(source==3),'ro','CapSize',4,'MarkerSize',3);
fullTickLabels = {'0','50','100','150','200','250'};
set(gca,'XLim',[0 250],'YLim',[0 250],...
    'XTick',0:50:250,'YTick',0:50:250,...
    'XTickLabels',fullTickLabels,'YTickLabels',fullTickLabels);
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Davison et al (Gt yr^{-1})','fontsize',10);
ylabel('Other studies (Gt yr^{-1})','fontsize',10);

fullTickLabels = {'0','50','100','150','200','250'};
set(gca,'XLim',[0 250],'YLim',[0 250],...
    'XTick',0:50:250,'YTick',0:50:250,...
    'XTickLabels',fullTickLabels,'YTickLabels',fullTickLabels);
export_fig('../out/pub/figures/comparison/combined_comparison_full_size.png','-dpng','-r300');

% Plot 100-150
figure('color','w','units','inches','position',[1 1 2 2]);
plot([100 150],[100 150],'k--'); hold on
use = Davison_data>100 & Davison_data<150 & Other_data>100 & Other_data<150;
errorbar(Davison_data(source==1 & use),Other_data(source==1 & use),Other_err(source==1 & use),Other_err(source==1 & use),Davison_err(source==1 & use),Davison_err(source==1 & use),'ko','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==2 & use),Other_data(source==2 & use),Other_err(source==2 & use),Other_err(source==2 & use),Davison_err(source==2 & use),Davison_err(source==2 & use),'bo','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==3 & use),Other_data(source==3 & use),Other_err(source==3 & use),Other_err(source==3 & use),Davison_err(source==3 & use),Davison_err(source==3 & use),'ro','CapSize',4,'MarkerSize',3);
partTickLabels = {'100','125','150'};
set(gca,'XLim',[100 150],'YLim',[100 150],...
    'XTick',100:25:150,'YTick',100:25:150,...
    'XTickLabels',partTickLabels,'YTickLabels',partTickLabels);
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Davison et al (Gt yr^{-1})','fontsize',10);
ylabel('Other studies (Gt yr^{-1})','fontsize',10);
export_fig('../out/pub/figures/comparison/combined_comparison_100-150.png','-dpng','-r300');

% Export 50-100
figure('color','w','units','inches','position',[1 1 2 2]);
plot([50 100],[50 100],'k--'); hold on
use = Davison_data>50 & Davison_data<100 & Other_data>50 & Other_data<100;
errorbar(Davison_data(source==1 & use),Other_data(source==1 & use),Other_err(source==1 & use),Other_err(source==1 & use),Davison_err(source==1 & use),Davison_err(source==1 & use),'ko','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==2 & use),Other_data(source==2 & use),Other_err(source==2 & use),Other_err(source==2 & use),Davison_err(source==2 & use),Davison_err(source==2 & use),'bo','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==3 & use),Other_data(source==3 & use),Other_err(source==3 & use),Other_err(source==3 & use),Davison_err(source==3 & use),Davison_err(source==3 & use),'ro','CapSize',4,'MarkerSize',3);
partTickLabels = {'50','75','100'};
set(gca,'XLim',[50 100],'YLim',[50 100],...
    'XTick',50:25:100,'YTick',50:25:100,...
    'XTickLabels',partTickLabels,'YTickLabels',partTickLabels);
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Davison et al (Gt yr^{-1})','fontsize',10);
ylabel('Other studies (Gt yr^{-1})','fontsize',10);
export_fig('../out/pub/figures/comparison/combined_comparison_50-100.png','-dpng','-r300');


% Export 0-50
figure('color','w','units','inches','position',[1 1 2 2]);
plot([0 50],[0 50],'k--'); hold on
use = Davison_data>0 & Davison_data<50 & Other_data>0 & Other_data<50;
errorbar(Davison_data(source==1 & use),Other_data(source==1 & use),Other_err(source==1 & use),Other_err(source==1 & use),Davison_err(source==1 & use),Davison_err(source==1 & use),'ko','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==2 & use),Other_data(source==2 & use),Other_err(source==2 & use),Other_err(source==2 & use),Davison_err(source==2 & use),Davison_err(source==2 & use),'bo','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==3 & use),Other_data(source==3 & use),Other_err(source==3 & use),Other_err(source==3 & use),Davison_err(source==3 & use),Davison_err(source==3 & use),'ro','CapSize',4,'MarkerSize',3);
partTickLabels = {'0','25','50'};
set(gca,'XLim',[0 50],'YLim',[0 50],...
    'XTick',0:25:50,'YTick',0:25:50,...
    'XTickLabels',partTickLabels,'YTickLabels',partTickLabels);
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Davison et al (Gt yr^{-1})','fontsize',10);
ylabel('Other studies (Gt yr^{-1})','fontsize',10);
export_fig('../out/pub/figures/comparison/combined_comparison_0-50.png','-dpng','-r300');

% Export 0-25
figure('color','w','units','inches','position',[1 1 2 2]);
plot([0 25],[0 25],'k--'); hold on
use = Davison_data>0 & Davison_data<25 & Other_data>0 & Other_data<25;
errorbar(Davison_data(source==1 & use),Other_data(source==1 & use),Other_err(source==1 & use),Other_err(source==1 & use),Davison_err(source==1 & use),Davison_err(source==1 & use),'ko','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==2 & use),Other_data(source==2 & use),Other_err(source==2 & use),Other_err(source==2 & use),Davison_err(source==2 & use),Davison_err(source==2 & use),'bo','CapSize',4,'MarkerSize',3);
errorbar(Davison_data(source==3 & use),Other_data(source==3 & use),Other_err(source==3 & use),Other_err(source==3 & use),Davison_err(source==3 & use),Davison_err(source==3 & use),'ro','CapSize',4,'MarkerSize',3);
partTickLabels = {'0','10','20'};
set(gca,'XLim',[0 25],'YLim',[0 25],...
    'XTick',0:10:20,'YTick',0:10:20,...
    'XTickLabels',partTickLabels,'YTickLabels',partTickLabels);
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Davison et al (Gt yr^{-1})','fontsize',10);
ylabel('Other studies (Gt yr^{-1})','fontsize',10);
export_fig('../out/pub/figures/comparison/combined_comparison_0-25.png','-dpng','-r300');


%% plot residuals of everything

figure('color','w','units','inches','position',[1 1 2 2]);
histogram(resids,'binwidth',1,'edgecol','none'); hold on
set(gca,'XLim',[-25 25]);
ylims = get(gca,'YLim');
plot([0 0],[0 max(ylims)],'k--');
set(gca,'fontsize',10,'fontname','Helvetica');
xlabel('Difference (Gt yr^{-1})','fontsize',10);
ylabel('# basins','fontsize',10);
export_fig('../out/pub/figures/comparison/residuals.png','-dpng','-r600');
close all

%% Plot map comparing average discharge with Rignot 

% Get difference
Qdiff = Davison_data(source==3) - Other_data(source==3);
QRelDiff = Qdiff./Other_data(source==3).*100;
Qnames = all_names(source==3);
        
% Prepare colors
ulim = 50;
cpts = -ulim:0.25:ulim;
cmap = cmocean('balance',length(cpts));

% Compare
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
plot_basins('imbie refined','k'); hold on
antbounds('coast','k');
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]); % start with all basins white
set(gca,'YTick',[],'YTickLabel',{},'XTick',[],'XTickLabel',{},'XColor','none','YColor','none');
for i = 1:numel(Qdiff)
    if basins.type_ID(rinds(i))==2
        [~,color_ind] = findNearest(cpts,QRelDiff(i));
        plot(basins.x{rinds(i)},basins.y{rinds(i)},'k'); % plot basin outline black
        fill(basins.x{rinds(i)}(1:end-1),basins.y{rinds(i)}(1:end-1),cmap(color_ind,:)); % fill the interior
    end
end
export_fig('../out/pub/figures/comparison/Rignot_basin_map_perc_diff.png','-dpng','-r600');
close

%% Plot time-series for East, West and APN

% Set colors
WAIS_col = [0.8500 0.3250 0.0980];
EAIS_col = [0.4940 0.1840 0.5560];
APN_col = [0 0.4470 0.7410];

% set portion of rignot data to plot
use = rtime>datenum(1996,1,1);

% Total
figure('color','w','units','inches','position',[1 1 3 1]);
% Plot Davison data
scatter(time,FB_mean(1,:),10,'k','filled','markerEdgeColor','none'); datetick('x'); hold on;
ptch2 = shadedErrorBar(time,FB_mean(1,:),1.96.*FB_se(1,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = [.3 .3 .3];
ptch2.patch.FaceAlpha = 0.5;
% plot Rignot data
plot(rtime(use),Qr(end,use),'r+','linewidth',1); datetick('x'); hold on;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',1850:50:2250,'YTickLabel',{' ',' ',' ','2000',' ','2100',' ','2200',' '});
text(datenum(1996,7,1),2210,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/comparison/AIS_timeseries.png','-dpng','-r600');


% WAIS
figure('color','w','units','inches','position',[1 1 3 1]);
% Plot Davison data
scatter(time,FB_mean(2,:),10,WAIS_col,'filled','markerEdgeColor','none'); datetick('x'); hold on;
ptch2 = shadedErrorBar(time,FB_mean(2,:),1.96.*FB_se(2,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = WAIS_col;
ptch2.patch.FaceAlpha = 0.5;
% plot Rignot data
idx = find(strcmp('WAIS',rnames)==1);
plot(rtime(use),Qr(idx,use),'r+','linewidth',1); datetick('x'); hold on;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',700:100:1000,'YTickLabel',{'700','800','900','1000'},...
    'YLim',[690 1010]);
text(datenum(1996,7,1),950,'West Antarctica','color',WAIS_col,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/comparison/WAIS_timeseries.png','-dpng','-r600');


% EAIS
figure('color','w','units','inches','position',[1 1 3 1]);
% Plot Davison data
scatter(time,FB_mean(3,:),10,EAIS_col,'filled','markerEdgeColor','none'); datetick('x'); hold on;
ptch2 = shadedErrorBar(time,FB_mean(3,:),1.96.*FB_se(3,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = EAIS_col;
ptch2.patch.FaceAlpha = 0.5;
% plot Rignot data
idx = find(strcmp('EAIS',rnames)==1);
plot(rtime(use),Qr(idx,use),'r+','linewidth',1); datetick('x'); hold on;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',900:50:1100,'YTickLabel',{'900',' 950','1000','1050','1100'},...
    'YLim',[900 1115],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' ','1998',' ','2002',' ','2006',' ',...
    '2010',' ','2014',' ','2018',' ','2022',' '});
text(datenum(1996,7,1),1030,'East Antarctica','color',EAIS_col,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/comparison/EAIS_timeseries.png','-dpng','-r600');


% APN
figure('color','w','units','inches','position',[1 1 3 1]);
% Plot Davison data
scatter(time,FB_mean(4,:),10,APN_col,'filled','markerEdgeColor','none'); datetick('x'); hold on;
ptch2 = shadedErrorBar(time,FB_mean(4,:),1.96.*FB_se(4,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = APN_col;
ptch2.patch.FaceAlpha = 0.5;
% plot Rignot data
idx = find(strcmp('AP',rnames)==1);
plot(rtime(use),Qr(idx,use),'r+','linewidth',1); datetick('x'); hold on;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' ','1998',' ','2002',' ','2006',' ',...
    '2010',' ','2014',' ','2018',' ','2022',' '});  
text(datenum(2015,7,1),265,'Peninsula','color',APN_col,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/comparison/APN_timeseries.png','-dpng','-r600');

