% making_FrankenBed

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Load first gate

g = shaperead('../out/pub/gates/flux_gates.shp');
gate_x = g(1).X;
gate_y = g(1).Y;
gate_nan = isnan(gate_x); % indices of gate nans
clear g

%% Plot mass balance from SEC

% load
load('../out/int/mass_balance/basin_quadratic_dH.mat');
basins = readBasinInfo;
all_basins = load('../out/int/basins/all_basins.mat');

keep = zeros([numel(all_basins.basins.name),1]);
for i = 1:numel(all_basins.basins.name)
    n = all_basins.basins.name{i};
    if sum(strcmp(n,basins.name))==1
        keep(i) = 1;
    end
end
keep = logical(keep);

% Time
t = 1:1/12:32; % years from 1991
dH_time = datenum(1991+t,1,15); % monthly from 1991
idx = find(dH_time>=datenum(1997,1,1) & dH_time<=datenum(2021,12,31));
num_years = (dH_time(idx(end))-dH_time(idx(1)))/365.25;

% plot mass balance colorbar
basin_dH_Gtyr = basin_dH_Gt./num_years;
ind = find(basins.type_ID==2);
cpts = 40:-.1:-40;
cmap = cmocean('balance',length(cpts));
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,basin_dH_Gtyr(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar('location','southoutside');
colormap(cmocean('-balance'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(-40,40,length(cb.Ticks));
export_fig('../out/pub/figures/making_FrankenBed/MB_colorbar.png','-dpng','-r600');
close

% plot mass balance
basin_dH_Gtyr = basin_dH_Gt./num_years;
ind = find(basins.type_ID==2);
cpts = 40:-.1:-40;
cmap = cmocean('balance',length(cpts));
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,basin_dH_Gtyr(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
colormap(cmocean('-balance'));
export_fig('../out/pub/figures/making_FrankenBed/MB.png','-dpng','-r600');
close

%% Plot implied discharge and required dischrge change

load('../out/int/derived/thickness_adjustment_0m.mat');
load('../out/int/discharge/inverted/inverted_discharge.mat');
FB_mean = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);
ind = find(basins.type_ID==2);
Qinv = Qinv(keep);
Qinv_err = Qinv_err(keep);
basin_H_change = basin_H_change(keep);
basin_H_inverted = basin_H_inverted(keep);
basin_H_orig = basin_H_orig(keep);

% Get average observed discharge during inversion period
use = time<=datenum(2014,1,1);
bQ = nanmean(FB_mean(:,use),2);

% plot colormap for inverted dischage
cpts = 0:100;
cmap = colorcet('Gouldian','N',length(cpts));
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qinv(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar('location','southoutside');
colormap(colorcet('Gouldian'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(0,100,length(cb.Ticks));
%ylabel(cb,'Discharge (Gt/yr)');
export_fig('../out/pub/figures/making_FrankenBed/discharge_colorbar.png','-dpng','-r600');
close


% plot inverted dischage
cpts = 0:100;
cmap = colorcet('Gouldian','N',length(cpts));
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qinv(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
colormap(colorcet('Gouldian'));
export_fig('../out/pub/figures/making_FrankenBed/inverted_discharge_0m.png','-dpng','-r600');
close

% plot discharge change colorbar
Qdiff = (Qinv - bQ)./bQ.*100;
Qdiff(basin_H_change==0) = 0;
cpts = -50:.5:50;
cmap = cmocean('balance',length(cpts));
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qdiff(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar('location','southoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(-50,50,length(cb.Ticks));
%ylabel(cb,'Inv discharge minus ref discharge (%)');
export_fig('../out/pub/figures/making_FrankenBed/discharge_change_colorbar','-dpng','-r600');
close


% plot discharge change 
Qdiff = (Qinv - bQ)./bQ.*100;
Qdiff(basin_H_change==0) = 0;
cpts = -50:.5:50;
cmap = cmocean('balance',length(cpts));
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qdiff(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
colormap(cmocean('balance'));
export_fig('../out/pub/figures/making_FrankenBed/discharge_change','-dpng','-r600');
close

%% plot required thickness change


% Relative change colorbar
cpts = -100:1:100;
cmap = cmocean('balance',length(cpts));
rel_diff = basin_H_change./basin_H_orig.*100;
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,rel_diff(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar('location','southoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(-100,100,length(cb.Ticks));
%ylabel(cb,'\Delta H (%)');
%title('+ve = bedmachine too thin')
export_fig('../out/pub/figures/making_FrankenBed/thickness_change_colorbar','-dpng','-r600');
close

% Relative change without colorbar
cpts = -100:1:100;
cmap = cmocean('balance',length(cpts));
rel_diff = basin_H_change./basin_H_orig.*100;
% fill basins
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,rel_diff(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
colormap(cmocean('balance'));
export_fig('../out/pub/figures/making_FrankenBed/thickness_change','-dpng','-r600');
close

