% plot_SEC


clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Load first gate

g = shaperead('../out/pub/gates/flux_gates.shp');
gate_x = g(1).X;
gate_y = g(1).Y;
gate_nan = isnan(gate_x); % indices of gate nans
clear g

%% Plot SEC grids

% load
fn = '../out/pub/reference_grids/sec_quadratic_1992_2023.nc';
x = ncread(fn,'x');
y = ncread(fn,'y');
xlims = [min(x) max(x)];
ylims = [min(y) max(y)];
[X,Y] = meshgrid(x,y);
quad = flipud(rot90(ncread(fn,'sec_quadratic')));
lin = flipud(rot90(ncread(fn,'sec_linear')));
icept = flipud(rot90(ncread(fn,'sec_icept')));
input_start_time = flipud(rot90(ncread(fn,'input_dh_start_time'))) + 1991; % year
t = 1:1/12:32; % years from 1991
t_sampling_original = 140/365;
t_sampling_hires = 1/12;
dH_time = datenum(1991+t,1,15); % monthly from 1991
num_years = (dH_time(end)-dH_time(1))/365.25;

% Mask areas south of 81.5
quad(input_start_time>=2010) = NaN;
lin(input_start_time>=2010) = NaN;
icept(input_start_time>=2010) = NaN;
%clear input_start_time

% Plot quad colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,quad)
caxis([-0.05 0.05]);
cmocean('-balance','pivot',0);
cb = colorbar('location','southoutside');
%xlabel(cb,'m yr^{-1}','fontsize',8);
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2)-0.15 cbpos(3)*0.8 cbpos(4)*0.75];
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/quad_colorbar.png','-dpng','-r600');
close

% plot lin colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,lin)
caxis([-0.5 0.5]);
cmocean('-balance','pivot',0);
cb = colorbar('location','southoutside');
%xlabel(cb,'m yr^{-1}','fontsize',8);
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2)-0.15 cbpos(3)*0.8 cbpos(4)*0.75];
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/lin_colorbar.png','-dpng','-r600');
close

% plot icept colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,icept)
caxis([-2 2]);
cmocean('-balance','pivot',0);
cb = colorbar('location','southoutside');
%xlabel(cb,'m yr^{-1}','fontsize',8);
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2)-0.15 cbpos(3)*0.8 cbpos(4)*0.75];
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/icept_colorbar.png','-dpng','-r600');
close

% Plot quad 
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,quad)
caxis([-0.05 0.05]);
cmocean('-balance','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/quad.png','-dpng','-r600');
close

% plot lin 
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,lin)
caxis([-0.5 0.5]);
cmocean('-balance','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/lin.png','-dpng','-r600');
close

% plot icept colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
imagescn(x,y,icept)
caxis([-2 2]);
cmocean('-balance','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/SEC/icept.png','-dpng','-r600');
close

