% plot_bed_data

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Load first gate

g = shaperead('../out/pub/gates/flux_gates.shp');
gate_x = g(1).X;
gate_y = g(1).Y;
gate_nan = isnan(gate_x); % indices of gate nans
clear g

%% BedMachine with FrankenBed Zooms

% Get coordinates of sub regions
[~,pel_x,pel_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/Cui_2020_PEL/Bed_elevation.tif'); % this is relative to the WGS84 datum
[~,apn_x,apn_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/Huss_2013_Peninsula/SOM/thickness/thickness.tif');
xlims_pel = [min(pel_x) max(pel_x)];
ylims_pel = [min(pel_y) max(pel_y)];
xlims_apn = [min(apn_x) max(apn_x)];
ylims_apn = [min(apn_y) max(apn_y)];

% load
[~,x,y] = geoimread('../out/pub/reference_grids/FrankenBed.tif');
[X,Y] = meshgrid(x,y);
bed = wgs2gl04c(X,Y,bedmachine_interp('bed',X,Y,'datum','wgs84'));

% plot with colorbar for legend
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed./1000)
caxis([-2.000 3.000]);
cmocean('topo','pivot',0);
cb = colorbar;
ylabel(cb,'Elevation w.r.t gl04c (km)','fontsize',8);
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2) cbpos(3)*0.4 cbpos(4)];
axis off
xlims = [min(x)-2e6 max(x)+2e6];
ylims = [min(y)-2e6 max(y)+2e6];
set(gca,'XLim',xlims,'YLim',ylims);
plot(gate_x,gate_y,'k');
export_fig('../out/pub/figures/bed/bed_colorbar.png','-dpng','-r600');
close

% plot without colorbar
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-2000 3000]);
cmocean('topo','pivot',0);
axis off
xlims = [min(x) max(x)];
ylims = [min(y) max(y)];
set(gca,'XLim',xlims,'YLim',ylims);
plot(gate_x,gate_y,'k');
plot([xlims_apn(1) xlims_apn(1) xlims_apn(2) xlims_apn(2) xlims_apn(1)],[ylims_apn(1) ylims_apn(2) ylims_apn(2) ylims_apn(1) ylims_apn(1)],'r','linewidth',2);
plot([xlims_pel(1) xlims_pel(1) xlims_pel(2) xlims_pel(2) xlims_pel(1)],[ylims_pel(1) ylims_pel(2) ylims_pel(2) ylims_pel(1) ylims_pel(1)],'color',[255,140,0]./255,'linewidth',2);
export_fig('../out/pub/figures/bed/BedMachine.png','-dpng','-r600');
close

% Just Princess Elizabeth Land zoomed
bed = geoimread('FrankenBed.tif');
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-2000 3000]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',xlims_pel,'YLim',ylims_pel);
plot(gate_x,gate_y,'k');
plot([xlims_pel(1) xlims_pel(1) xlims_pel(2) xlims_pel(2) xlims_pel(1)],[ylims_pel(1) ylims_pel(2) ylims_pel(2) ylims_pel(1) ylims_pel(1)],'color',[255,140,0]./255,'linewidth',2);
scalebarps('location','southwest','color','w')
export_fig('../out/pub/figures/bed/FrankenBed_PEL.png','-dpng','-r600');
close

% Just Peninsula zoomed
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-2000 3000]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',xlims_apn,'YLim',ylims_apn);
plot(gate_x,gate_y,'k');
plot([xlims_apn(1) xlims_apn(1) xlims_apn(2) xlims_apn(2) xlims_apn(1)],[ylims_apn(1) ylims_apn(2) ylims_apn(2) ylims_apn(1) ylims_apn(1)],'r','linewidth',2);
plot([-2.4595 -2.4595 -2.3748 -2.3748 -2.4595]*1e6,[1.2464 1.3689 1.3689 1.2464 1.2464]*1e6,'m','linewidth',2); % zoom peninsula box
scalebarps('location','northeast')
export_fig('../out/pub/figures/bed/FrankenBed_Peninsula.png','-dpng','-r600');
close

% Just Peninsula example zoomed
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-1500 1500]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',[-2.4595   -2.3748]*1e6,'YLim',[1.2464    1.3689]*1e6);
plot(gate_x,gate_y,'k');
plot([-2.4595 -2.4595 -2.3748 -2.3748 -2.4595]*1e6,[1.2464 1.3689 1.3689 1.2464 1.2464]*1e6,'m','linewidth',2); % zoom peninsula box
scalebarps('location','southwest')
export_fig('../out/pub/figures/bed/FrankenBed_HGE.png','-dpng','-r600');
close

% HGE colorbar
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed./1000)
caxis([-1.500 1.500]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',[-2.4595+0.02   -2.3748-0.02]*1e6,'YLim',[1.2464+0.02  1.3689-0.02]*1e6);
cb = colorbar;
ylabel(cb,'Elevation w.r.t gl04c (km)','fontsize',8);
cbpos = cb.Position;
cb.Position = [cbpos(1)+0.1 cbpos(2) cbpos(3)*0.5 cbpos(4)*0.65];
plot(gate_x,gate_y,'k');
plot([-2.4595 -2.4595 -2.3748 -2.3748 -2.4595]*1e6,[1.2464 1.3689 1.3689 1.2464 1.2464]*1e6,'m','linewidth',2); % zoom peninsula box
export_fig('../out/pub/figures/bed/HGE_colorbar.png','-dpng','-r600');
close

%% BedMachine

bed = wgs2gl04c(X,Y,bedmachine_interp('bed',X,Y,'datum','wgs84'));
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-2000 3000]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
plot(gate_x,gate_y,'k');
export_fig('../out/pub/figures/bed/BedMachine.png','-dpng','-r600');
close

%% BedMap2

bed = wgs2gl04c(X,Y,bedmap2_interp(X,Y,'bed'));
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
imagescn(x,y,bed)
caxis([-2000 3000]);
cmocean('topo','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
plot(gate_x,gate_y,'k');
export_fig('../out/pub/figures/bed/BedMap2.png','-dpng','-r600');
close

%% Thickness changes with FrankenBedAdj

A = load('../out/int/derived/thickness_adj_0m.mat');
basins = readBasinInfo;
ind = find(basins.type_ID==2);

% Relative change without colorbar
cpts = -100:1:100;
cmap = cmocean('balance',length(cpts));
rel_diff = A.basin_H_change./A.basin_avg_H_orig.*100;
% fill basins
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,rel_diff(i));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
colormap(cmocean('balance'));
export_fig('../out/pub/figures/bed/FrankenBedAdj_perc_thickness_change_0m.png','-dpng','-r600');
close

% Relative change with colorbar
cpts = -100:1:100;
cmap = cmocean('balance',length(cpts));
rel_diff = A.basin_H_change./A.basin_avg_H_orig.*100;
% fill basins
figure('color','w','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','color','none'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,rel_diff(i));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar;
colormap(cmocean('balance'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(-100,100,length(cb.Ticks));
ylabel(cb,'\Delta H (%)','fontsize',8);
set(gca,'XLim',[xlims(1)-2e6 xlims(2)+2e6],'YLim',[ylims(1)-2e6 ylims(2)+2e6]);
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2) cbpos(3)*0.5 cbpos(4)];
export_fig('../out/pub/figures/bed/FrankenBedAdj_change_colorbar.png','-dpng','-r600');
close



