% plot_corrections_impact

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;
num_gates = 16;

% load data
corrections.SMB = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','SMB_correction_all_gates'),3);
corrections.firn = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','FDM_firn_correction_all_gates'),3);
corrections.dH = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','dH_correction_all_gates'),3);
corrections.net = corrections.firn + corrections.SMB + corrections.dH;
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% prepare for plotting
cmap = cbrewer('qual','Set1',4);

% Make figure
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 1;
plot([time(1) time(end)],[0 0],'k--'); hold on;
scatter(time,corrections.SMB(ind,:),8,'r','filled');   % downstream correction (baseline minus 'in situ')
datetick('x');
scatter(time,corrections.firn(ind,:),8,cmap(2,:),'filled');  % firn correction (baseline minus 'no firn')
scatter(time,corrections.dH(ind,:),8,cmap(3,:),'filled'); % dH (baseline minus dH only)
scatter(time,corrections.net(ind,:),8,'k','filled'); % net effect of all corrections
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YLim',[-70 40]);
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),30,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');
%legend('Downstream SMB','Firn','dH','Net','location','northwest')

% West Antarctica
p2 = subplot(5,1,2);
ind = 2;
plot([time(1) time(end)],[0 0],'k--'); hold on;
scatter(time,corrections.SMB(ind,:),8,'r','filled');   % downstream correction (baseline minus 'in situ')
datetick('x');
scatter(time,corrections.firn(ind,:),8,cmap(2,:),'filled');  % firn correction (baseline minus 'no firn')
scatter(time,corrections.dH(ind,:),8,cmap(3,:),'filled'); % dH (baseline minus dH only)
scatter(time,corrections.net(ind,:),8,'k','filled'); % net effect of all corrections
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YAxisLocation','right','YLim',[-35,30]);
pos = p2.Position;
p2.Position = [pos(1) pos(2)+0.09 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),22,'West Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% East Antarctica
p3 = subplot(5,1,3);
ind = 3;
plot([time(1) time(end)],[0 0],'k--'); hold on;
scatter(time,corrections.SMB(ind,:),8,'r','filled');   % downstream correction (baseline minus 'in situ')
datetick('x');
scatter(time,corrections.firn(ind,:),8,cmap(2,:),'filled');  % firn correction (baseline minus 'no firn')
scatter(time,corrections.dH(ind,:),8,cmap(3,:),'filled'); % dH (baseline minus dH only)
scatter(time,corrections.net(ind,:),8,'k','filled'); % net effect of all corrections
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YLim',[-30 18]);
pos = p3.Position;
p3.Position = [pos(1) pos(2)+0.13 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),12,'East Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% Peninsula
p4 = subplot(5,1,4);
ind = 4;
plot([time(1) time(end)],[0 0],'k--'); hold on;
scatter(time,corrections.SMB(ind,:),8,'r','filled');   % downstream correction (baseline minus 'in situ')
datetick('x');
scatter(time,corrections.firn(ind,:),8,cmap(2,:),'filled');  % firn correction (baseline minus 'no firn')
scatter(time,corrections.dH(ind,:),8,cmap(3,:),'filled'); % dH (baseline minus dH only)
scatter(time,corrections.net(ind,:),8,'k','filled'); % net effect of all corrections
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{'1996','1998','2000','2002','2004','2006','2008','2010',...
    '2012','2014','2016','2018','2020','2022'},...
    'YAxisLocation','right','YLim',[-18 12]);
pos = p4.Position;
p4.Position = [pos(1) pos(2)+0.17 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),9,'Peninsula','color','k','fontname','Helvetica','fontweight','bold');

export_fig('../out/pub/figures/corrections_impact/corrections.png','-dpng','-r600');
close

