% plot_discharge

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;

WAIS_col = [0.8500 0.3250 0.0980];
EAIS_col = [0.4940 0.1840 0.5560];
APN_col = [0 0.4470 0.7410];
% [0.9290 0.6940 0.1250]

% Load data
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
bQse = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
bQp = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_coverage');
bQ_all = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);
bQp(isnan(bQp)) = 0;

% add negligible random noise to time to help with plotting
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);

%% Plot

% Plot discharge for each bed, with coverage
figure('color','w','units','inches','position',[1 1 4 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 1;
for i = 1:16
    plot(time,squeeze(bQ_all(ind,:,i)),'color',[.8 .8 .8 .5],'linewidth',1,'marker','none'); hold on;
end
s = scatter(time,bQ(ind,:),10,'k','filled','markerEdgeColor','none'); datetick('x')
ptch2 = shadedErrorBar(time,bQ(ind,:),1.96.*bQse(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = [.3 .3 .3];
ptch2.patch.FaceAlpha = 0.5;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',1850:50:2250,'YTickLabel',{'1850',' ','1950',' ','2050',' ','2150',' ','2250'});
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),2220,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% West Antarctica
p2 = subplot(5,1,2);
ind = 2;
for i = 1:16
    plot(time,squeeze(bQ_all(ind,:,i)),'color',[WAIS_col .2],'linewidth',1,'marker','none'); hold on;
end
s = scatter(time,bQ(ind,:),10,WAIS_col,'filled','markerEdgeColor','none');  datetick('x')
ptch2 = shadedErrorBar(time,bQ(ind,:),1.96.*bQse(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = WAIS_col;
ptch2.patch.FaceAlpha = 0.5;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',775:25:1000,'YTickLabel',{' ','800',' ','850',' ','900',' ','950',' '},...
    'YLim',[770 975]);
pos = p2.Position;
p2.Position = [pos(1) pos(2)+0.09 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),945,'West Antarctica','color',WAIS_col,'fontname','Helvetica','fontweight','bold');

% East Antarctica
p3 = subplot(5,1,3);
ind = 3;
for i = 1:16
    plot(time,squeeze(bQ_all(ind,:,i)),'color',[EAIS_col .2],'linewidth',1,'marker','none'); hold on;
end
s = scatter(time,bQ(ind,:),10,EAIS_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,bQ(ind,:),1.96.*bQse(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = EAIS_col;
ptch2.patch.FaceAlpha = 0.5;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',920:10:990,'YTickLabel',{' ',' 940',' ','960',' ','980',' ','1000'},...
    'YLim',[915 1000]);
pos = p3.Position;
p3.Position = [pos(1) pos(2)+0.13 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),985,'East Antarctica','color',EAIS_col,'fontname','Helvetica','fontweight','bold');

% Peninsula
p4 = subplot(5,1,4);
ind = 4;
for i = 1:16
    plot(time,squeeze(bQ_all(ind,:,i)),'color',[APN_col .2],'linewidth',1,'marker','none'); hold on;
end
s = scatter(time,bQ(ind,:),10,APN_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,bQ(ind,:),1.96.*bQse(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = APN_col;
ptch2.patch.FaceAlpha = 0.5;
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YTick',250:10:300,'YTickLabel',{' ','260','270',' 280','290','300'},...
    'YLim',[250 305]);
pos = p4.Position;
p4.Position = [pos(1) pos(2)+0.17 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),295,'Peninsula','color',APN_col,'fontname','Helvetica','fontweight','bold');

% proportion observed
p5 = subplot(5,1,5);
scatter(time,bQp(1,:),8,'k','filled'); datetick('x'); hold on
scatter(time,bQp(2,:),8,WAIS_col,'filled');
scatter(time,bQp(3,:),8,EAIS_col,'filled');
scatter(time,bQp(4,:),8,APN_col,'filled');
%ylabel('Observed (%)','fontsize',10);
box on;
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' ','1998',' ','2002',' ','2006',' ',...
    '2010',' ','2014',' ','2018',' ','2022',' '},...
    'YLim',[0 110]);  
pos = p5.Position;
p5.Position = [pos(1) pos(2)+0.25 pos(3) pos(4)*0.5];

% save
export_fig('../out/pub/figures/discharge/discharge.png','-dpng','-r600');



