% plot_discharge_bed

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;
num_gates = 16;

cmap = cbrewer('qual','Set1',4);
FB_col = 'k';
FBA_col = cmap(2,:);
BM_col = cmap(3,:);
B2_col = cmap(4,:);
% [0.9290 0.6940 0.1250]

% Load data
%   - discharge
FB_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates');
FBA_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBedAdj.nc','discharge_all_gates');
BM_Q = ncread('../out/pub/discharge/nc/AIS_discharge_BedMachine.nc','discharge_all_gates');
B2_Q = ncread('../out/pub/discharge/nc/AIS_discharge_BedMap2.nc','discharge_all_gates');
%   - error
FB_E = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_error');
FBA_E = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBedAdj.nc','discharge_error');
BM_E = ncread('../out/pub/discharge/nc/AIS_discharge_BedMachine.nc','discharge_error');
B2_E = ncread('../out/pub/discharge/nc/AIS_discharge_BedMap2.nc','discharge_error');
%   - time
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% Which basins to plot
basins_to_plot = {'Antarctica','West_Antarctica_Rignot','East_Antarctica_Rignot','G-H','F-G','B-C','Cp-D','A-Ap'};
basins_labels = ["AIS", "WAIS", "EAIS", "G-H", "F-G", "B-C", "Cp-D", "A-Ap"];
bed_labels = ["FBA" "BM" "B2"];

% Get index of those basins
idx = zeros([numel(basins_to_plot),1]).*NaN;
for i = 1:numel(basins_to_plot)
    idx(i) = find(strcmp(basins_to_plot{i},basins.name)==1);
end

% Calculate difference and prepare plot data
FBA_diff = reshape((FBA_Q-FB_Q)./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
BM_diff = reshape((BM_Q-FB_Q)./BM_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
B2_diff = reshape((B2_Q-FB_Q)./B2_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
box_data{1} = FBA_diff(:,idx);
box_data{2} = BM_diff(:,idx);
box_data{3} = B2_diff(:,idx);

% plot
figure('color','w','units','inches','position',[1 1 6 2.5]);
plot([-0.5 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',bed_labels,'SecondaryLabels',basins_labels,...
    'groupLabelType','Vertical',...
    'Colors',[FBA_col; BM_col; B2_col],'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
export_fig('../out/pub/figures/bed_impact/basin_boxgroup.png','-dpng','-r600');

%% Plot Peninsula separately

% Which basins to plot
basins_to_plot = {'Peninsula_Rignot'};
basins_labels = ["APN"];
bed_labels = ["FBA" "BM" "B2"];
% Get index of those basins
idx = zeros([numel(basins_to_plot),1]).*NaN;
for i = 1:numel(basins_to_plot)
    idx(i) = find(strcmp(basins_to_plot{i},basins.name)==1);
end
% Calculate difference and prepare plot data
box_data{1} = FBA_diff(:,idx);
box_data{2} = BM_diff(:,idx);
box_data{3} = B2_diff(:,idx);
% plot
figure('color','w','units','inches','position',[1 1 0.5 2.5]);
plot([-0.5 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',bed_labels,'SecondaryLabels',basins_labels,...
    'groupLabelType','Vertical',...
    'Colors',[FBA_col; BM_col; B2_col],'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
export_fig('../out/pub/figures/bed_impact/APN_box.png','-dpng','-r600');


%% Plot E-Ep separately

% Which basins to plot
basins_to_plot = {'E-Ep'};
basins_labels = ["E-Ep"];
bed_labels = ["FBA" "BM" "B2"];
% Get index of those basins
idx = zeros([numel(basins_to_plot),1]).*NaN;
for i = 1:numel(basins_to_plot)
    idx(i) = find(strcmp(basins_to_plot{i},basins.name)==1);
end
% Calculate difference and prepare plot data
box_data{1} = FBA_diff(:,idx);
box_data{2} = BM_diff(:,idx);
box_data{3} = B2_diff(:,idx);
% plot
figure('color','w','units','inches','position',[1 1 0.5 2.5]);
plot([-0.5 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',bed_labels,'SecondaryLabels',basins_labels,...
    'groupLabelType','Vertical',...
    'Colors',[FBA_col; BM_col; B2_col],'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
export_fig('../out/pub/figures/bed_impact/E-Ep_box.png','-dpng','-r600');

%% Plot a selection of other basins in Gt

% Calculate difference and prepare plot data
FBA_diff = reshape((FBA_Q-FB_Q)./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
BM_diff = reshape((BM_Q-FB_Q)./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
B2_diff = reshape((B2_Q-FB_Q)./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
FBA_mindiff = reshape(((FBA_Q-FBA_E)-(FB_Q+FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
BM_mindiff = reshape(((BM_Q-BM_E)-(FB_Q+FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
B2_mindiff = reshape(((B2_Q-B2_E)-(FB_Q+FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
FBA_maxdiff = reshape(((FBA_Q+FBA_E)-(FB_Q-FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
BM_maxdiff = reshape(((BM_Q+BM_E)-(FB_Q-FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
B2_maxdiff = reshape(((B2_Q+B2_E)-(FB_Q-FB_E))./FB_Q.*100,[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA

% Get time/gate median
FBA_diff = nanmedian(FBA_diff,1);
BM_diff = nanmedian(BM_diff,1);
B2_diff = nanmedian(B2_diff,1);
FBA_mindiff = nanmedian(FBA_mindiff,1);
BM_mindiff = nanmedian(BM_mindiff,1);
B2_mindiff = nanmedian(B2_mindiff,1);
FBA_maxdiff = nanmedian(FBA_maxdiff,1);
BM_maxdiff = nanmedian(BM_maxdiff,1);
B2_maxdiff = nanmedian(B2_maxdiff,1);

% Sort by FBA
%   - sort
[~,iv_FBA] = sort(FBA_diff,'descend');
%   - main
FBA_diff = FBA_diff(iv_FBA);
BM_diff = BM_diff(iv_FBA);
B2_diff = B2_diff(iv_FBA);
%   - min
FBA_mindiff = FBA_mindiff(iv_FBA);
BM_mindiff = BM_mindiff(iv_FBA);
B2_mindiff = B2_mindiff(iv_FBA);
%   - max
FBA_maxdiff = FBA_maxdiff(iv_FBA);
BM_maxdiff = BM_maxdiff(iv_FBA);
B2_maxdiff = B2_maxdiff(iv_FBA);
%   - basins
FBA_basins = basins.name(iv_FBA);

% Combine
FBA_diff = [FBA_diff ; FBA_mindiff; FBA_maxdiff];
BM_diff = [BM_diff ; BM_mindiff; BM_maxdiff];
B2_diff = [B2_diff ; B2_mindiff; B2_maxdiff];

% Tabulate
FBA_T = table(FBA_basins,nanmedian(FBA_diff,1)');
BM_T = table(FBA_basins,nanmedian(BM_diff,1)');
B2_T = table(FBA_basins,nanmedian(B2_diff,1)');

% Select some basisn with large differences
basins_to_plot = {'E-Ep','Sandford_IS','Edward_VIII_IS','Denman Scott','Frost','Wilkins','Drygalski','Voyeykov','Mertz','Sulzberger','Crosson_IS','Pine Island','Shirase_IS','Dibble','West_IS','Moscow','Brunt Stancomb','Fimbul_IS','Nivl','Vigrid','Slessor','Abbot'};
basins_labels = ["E-Ep","Sandford","Ed. VIII","Denman","Frost","Wilkins","Dryg.","Voyey.","Mertz","Sulz.","Crosson","PIG","Shirase","Dibble","West","Moscow","Brunt","Fimbul","Nivl","Vigird","Slessor","Abbot"];
bed_labels = ["FBA" "BM" "B2"];
bed_labels = [" " " " " "];

% Get index of those basins
idx = zeros([numel(basins_to_plot),1]).*NaN;
set_nan = zeros([numel(basins_to_plot),1]).*NaN;
for i = 1:numel(basins_to_plot)
    idx(i) = find(strcmp(basins_to_plot{i},FBA_basins)==1,1,'first');
    if abs(nanmedian(BM_diff(:,idx(i)),1)) < 0.5
        set_nan(i) = 1;
        BM_diff(:,idx(i)) = NaN;
    end
end

% Format
clear box_data
box_data{1} = FBA_diff(:,idx);
box_data{2} = BM_diff(:,idx);
box_data{3} = B2_diff(:,idx);

% plot
figure('color','w','units','inches','position',[1 1 7.5 2]);
plot([-0.5 (numel(basins_to_plot)*5)-0.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',bed_labels,'SecondaryLabels',basins_labels,...
    'groupLabelType','Horizontal',...
    'Colors',[FBA_col; BM_col; B2_col],'GroupType','betweenGroups',...
    'BoxStyle','filled'); hold on; % 'PlotStyle','Compact',
b.axis2.XAxis.TickLabelRotation = 90;
b.axis2.XAxis.TickValues = b.axis2.XAxis.TickValues-1.5;
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2)+0.1 pos(3) pos(4).*0.8]);
boutliers = findobj(b.boxplotGroup,'Tag','Outliers');
bmedians = findobj(b.boxplotGroup,'Tag','Median');
bwhiskers = findobj(b.boxplotGroup,'tag','Whisker');
bboxes = findobj(b.boxplotGroup,'tag','Box');
for i = 1:numel(bmedians)
    % set box, whisker and outliers as blank
    set(bboxes(i),'Color','none')
    set(bwhiskers(i),'Color','none')
    try; set(boutliers(i),'Color','none'); end
    % set median color and width
    set(bmedians(i),'LineWidth',1);
    % draw box
    bx = [bmedians(i).XData(1)-0.25 bmedians(i).XData(2)+0.25];
    try
        by = [bmedians(i).YData,bboxes(i).YData,boutliers(i).YData];
    catch
        by = [bmedians(i).YData,bboxes(i).YData];
    end
    by = [min(by(:)) max(by(:))];
    p = patch([bx(1) bx(1) bx(2) bx(2) bx(1)],[by(1) by(2) by(2) by(1) by(1)],bmedians(i).Color);
    p.EdgeColor = bmedians(i).Color;
end
export_fig('../out/pub/figures/bed_impact/basin_boxgroup_percent.png','-dpng','-r600');

%% Plot top ten basin impacts for each bed type

clear
close all
clc

% basin info
basins = readBasinInfo;
num_gates = 16;

% Load data
FB_Q = ncread('AIS_discharge_FrankenBed.nc','discharge_all_gates');
FBA_Q = ncread('AIS_discharge_FrankenBedAdj.nc','discharge_all_gates');
BM_Q = ncread('AIS_discharge_BedMachine.nc','discharge_all_gates');
B2_Q = ncread('AIS_discharge_BedMap2.nc','discharge_all_gates');
time = ncread('AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1);

% Calculate difference and prepare plot data
FBA_diff = reshape((FBA_Q-FB_Q),[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
BM_diff = reshape((BM_Q-FB_Q),[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA
B2_diff = reshape((B2_Q-FB_Q),[numel(basins.name),length(time)*num_gates])'; % percent difference from FB; positive equals greater discharge with FBA

% Just do IMBIE refined basins
ind = find(basins.type_ID==2);
FBA_diff = FBA_diff(:,ind);
BM_diff = BM_diff(:,ind);
B2_diff = B2_diff(:,ind);
imbie_names = basins.name(ind);

% Sort them
[~,iv_FBA] = sort(abs(nanmedian(FBA_diff,1)),'descend');
[~,iv_BM] = sort(abs(nanmedian(BM_diff,1)),'descend');
[~,iv_B2] = sort(abs(nanmedian(B2_diff,1)),'descend');
FBA_diff = FBA_diff(:,iv_FBA);
BM_diff = BM_diff(:,iv_BM);
B2_diff = B2_diff(:,iv_B2);
FBA_basins = imbie_names(iv_FBA);
BM_basins = imbie_names(iv_BM);
B2_basins = imbie_names(iv_B2);

% Tabulate
FBA_T = table(FBA_basins,nanmedian(FBA_diff,1)');
BM_T = table(BM_basins,nanmedian(BM_diff,1)');
B2_T = table(B2_basins,nanmedian(B2_diff,1)');

% Just 10 examples
FBA_diff = FBA_diff(:,[2,3,4,11,18,29,33,5,21,45,46,65,87]); % [1,6,8,9,10,19,21,37,38,47]
BM_diff = BM_diff(:,[2,4,5,12,13,14,15]); % [2,4,8,9,11,13,14,15,18,20]
B2_diff = B2_diff(:,[2,5,6,7,8,12,13,15,28,30]); % [3,5,7,8,10,11,12,13,15,26]
FBA_basins = FBA_basins([2,3,4,11,18,29,33,5,21,45,46,65,87]); % [1,6,8,9,10,19,21,37,38,47]
BM_basins = BM_basins([2,4,5,12,13,14,15]); % [2,4,8,9,11,13,14,15,18,20]
B2_basins = B2_basins([2,5,6,7,8,12,13,15,28,30]); % [3,5,7,8,10,11,12,13,15,26]

% And sort those so they're in order of most positive to most negative
[~,iv_FBA] = sort(nanmedian(FBA_diff,1),'descend');
[~,iv_BM] = sort(nanmedian(BM_diff,1),'descend');
[~,iv_B2] = sort(nanmedian(B2_diff,1),'descend');
FBA_diff = FBA_diff(:,iv_FBA);
BM_diff = BM_diff(:,iv_BM);
B2_diff = B2_diff(:,iv_B2);
FBA_basins = FBA_basins(iv_FBA);
BM_basins = BM_basins(iv_BM);
B2_basins = B2_basins(iv_B2);

% Prepare colors
cpts = -10:.25:10;
colmap = cmocean('balance',numel(cpts));
FBA_idx = zeros([size(FBA_diff,2),1]).*NaN;
BM_idx = zeros([size(BM_diff,2),1]).*NaN;
B2_idx = zeros([size(B2_diff,2),1]).*NaN;
for i = 1:size(FBA_diff,2)
    [~,FBA_idx(i)] = findNearest(cpts,nanmedian(FBA_diff(:,i)));
end
for i = 1:size(BM_diff,2)
    [~,BM_idx(i)] = findNearest(cpts,nanmedian(BM_diff(:,i)));
end
for i = 1:size(B2_diff,2)
    [~,B2_idx(i)] = findNearest(cpts,nanmedian(B2_diff(:,i)));
end
cmap_FBA = colmap(FBA_idx,:);
cmap_BM = colmap(BM_idx,:);
cmap_B2 = colmap(B2_idx,:);

% Plot FBA
bed_labels = ["FBA"];
basin_labels = string(FBA_basins);
basin_labels(2) = "PIG";
basin_labels(3) = "Denman";
basin_labels(8) = "Brunt";
basin_labels(9) = "Borch.";
basin_labels(10) = "Jutul.";
for i = 1:size(FBA_diff,2)
    box_data{i} = FBA_diff(:,i);
end
figure('color','w','units','inches','position',[1 1 2.7 2.5]);
plot([-0.7 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',basin_labels,'SecondaryLabels',bed_labels,...
    'groupLabelType','Vertical',...
    'Colors',cmap_FBA,'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
set(gca,'YLim',[-18 25]);
export_fig('../out/pub/figures/bed_impact/FBA_box.png','-dpng','-r600');


% Plot BedMachine
bed_labels = ["BM"];
basin_labels = string(BM_basins);
basin_labels(7) = "  Hektoria";
clear box_data
for i = 1:size(BM_diff,2)
    box_data{i} = BM_diff(:,i);
end
figure('color','w','units','inches','position',[1 1 1.8 2.5]);
plot([-0.5 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',basin_labels,'SecondaryLabels',bed_labels,...
    'groupLabelType','Vertical',...
    'Colors',cmap_BM,'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
export_fig('../out/pub/figures/bed_impact/BM_box.png','-dpng','-r600');

% Plot BedMap2
bed_labels = ["B2"];
basin_labels = string(B2_basins);
basin_labels(2) = "Denman";
basin_labels(8) = "PIG";
%basin_labels(6) = "Hektoria";
clear box_data
for i = 1:size(B2_diff,2)
    box_data{i} = B2_diff(:,i);
end
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
plot([-0.5 49.5],[0 0],'k--'); hold on
b = boxplotGroup(box_data,'interGroupSpace',2,'groupLines',true,...
    'primaryLabels',basin_labels,'SecondaryLabels',bed_labels,...
    'groupLabelType','Vertical',...
    'Colors',cmap_B2,'GroupType','betweenGroups',...
    'PlotStyle','Compact','BoxStyle','filled'); hold on;
xtickangle(90)
export_fig('../out/pub/figures/bed_impact/B2_box.png','-dpng','-r600');


%% Plot time-series of discharge with different bed products, just for Antarctica

clear
close all
clc

% basin info
basins = readBasinInfo;

% Load data
FB_mean = ncread('AIS_discharge_FrankenBed.nc','discharge_mean');
FBA_mean = ncread('AIS_discharge_FrankenBedAdj.nc','discharge_mean');
BM_mean = ncread('AIS_discharge_BedMachine.nc','discharge_mean');
B2_mean = ncread('AIS_discharge_BedMap2.nc','discharge_mean');
FB_se = ncread('AIS_discharge_FrankenBed.nc','discharge_standard_error');
FBA_se = ncread('AIS_discharge_FrankenBedAdj.nc','discharge_standard_error');
BM_se = ncread('AIS_discharge_BedMachine.nc','discharge_standard_error');
B2_se = ncread('AIS_discharge_BedMap2.nc','discharge_standard_error');
time = ncread('AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1);

% colors
cmap = cbrewer('qual','Set1',4);
FB_col = 'k';
FBA_col = cmap(2,:);
BM_col = cmap(3,:);
B2_col = cmap(4,:);


% Plot discharge for each bed, with coverage
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 1;
% FrankenBed
s = scatter(time,FB_mean(ind,:),8,FB_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,FB_mean(ind,:),1.96.*FB_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = FB_col;
ptch2.patch.FaceAlpha = 0.3;
% FrankenBedAdj
s = scatter(time,FBA_mean(ind,:),8,FBA_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch3 = shadedErrorBar(time,FBA_mean(ind,:),1.96.*FBA_se(ind,:)); % 95% confidence bounds
ptch3.mainLine.Color = 'none';
ptch3.edge(1).Color = 'none';
ptch3.edge(2).Color = 'none';
ptch3.patch.FaceColor = FBA_col;
ptch3.patch.FaceAlpha = 0.3;
% BedMachine
s = scatter(time,BM_mean(ind,:),8,BM_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,BM_mean(ind,:),1.96.*BM_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = BM_col;
ptch2.patch.FaceAlpha = 0.3;
% BedMap2
s = scatter(time,B2_mean(ind,:),8,B2_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,B2_mean(ind,:),1.96.*B2_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = B2_col;
ptch2.patch.FaceAlpha = 0.3;
%
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' '},'YTick',2000:100:2500,...
    'YTickLabel',{'2000','','2200','','2400',''}); 
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),2375,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');
% save
export_fig('../out/pub/figures/bed_impact/discharge_bed_timeseries_AIS.png','-dpng','-r600');


%% Plot time-series of discharge with different bed products, just for West Antarctica



% Plot discharge for each bed, with coverage
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 2;
% FrankenBed
s = scatter(time,FB_mean(ind,:),8,FB_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,FB_mean(ind,:),1.96.*FB_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = FB_col;
ptch2.patch.FaceAlpha = 0.3;
% FrankenBedAdj
s = scatter(time,FBA_mean(ind,:),8,FBA_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch3 = shadedErrorBar(time,FBA_mean(ind,:),1.96.*FBA_se(ind,:)); % 95% confidence bounds
ptch3.mainLine.Color = 'none';
ptch3.edge(1).Color = 'none';
ptch3.edge(2).Color = 'none';
ptch3.patch.FaceColor = FBA_col;
ptch3.patch.FaceAlpha = 0.3;
% BedMachine
s = scatter(time,BM_mean(ind,:),8,BM_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,BM_mean(ind,:),1.96.*BM_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = BM_col;
ptch2.patch.FaceAlpha = 0.3;
% BedMap2
s = scatter(time,B2_mean(ind,:),8,B2_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,B2_mean(ind,:),1.96.*B2_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = B2_col;
ptch2.patch.FaceAlpha = 0.3;
%
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' '}); 
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),910,'West Antarctica','color','k','fontname','Helvetica','fontweight','bold');
% save
export_fig('../out/pub/figures/bed_impact/discharge_bed_timeseries_WAIS.png','-dpng','-r600');


%% Plot time-series of discharge with different bed products, just for East Antarctica


% Plot discharge for each bed, with coverage
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 3;
% FrankenBed
s = scatter(time,FB_mean(ind,:),8,FB_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,FB_mean(ind,:),1.96.*FB_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = FB_col;
ptch2.patch.FaceAlpha = 0.3;
% FrankenBedAdj
s = scatter(time,FBA_mean(ind,:),8,FBA_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch3 = shadedErrorBar(time,FBA_mean(ind,:),1.96.*FBA_se(ind,:)); % 95% confidence bounds
ptch3.mainLine.Color = 'none';
ptch3.edge(1).Color = 'none';
ptch3.edge(2).Color = 'none';
ptch3.patch.FaceColor = FBA_col;
ptch3.patch.FaceAlpha = 0.3;
% BedMachine
s = scatter(time,BM_mean(ind,:),8,BM_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,BM_mean(ind,:),1.96.*BM_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = BM_col;
ptch2.patch.FaceAlpha = 0.3;
% BedMap2
s = scatter(time,B2_mean(ind,:),8,B2_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,B2_mean(ind,:),1.96.*B2_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = B2_col;
ptch2.patch.FaceAlpha = 0.3;
%
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{' '}); 
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),1080,'East Antarctica','color','k','fontname','Helvetica','fontweight','bold');
% save
export_fig('../out/pub/figures/bed_impact/discharge_bed_timeseries_EAIS.png','-dpng','-r600');


%% Plot time-series of discharge with different bed products, just for Peninsula


% Plot discharge for each bed, with coverage
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 4;
% FrankenBed
s = scatter(time,FB_mean(ind,:),8,FB_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,FB_mean(ind,:),1.96.*FB_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = FB_col;
ptch2.patch.FaceAlpha = 0.3;
% FrankenBedAdj
s = scatter(time,FBA_mean(ind,:),8,FBA_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch3 = shadedErrorBar(time,FBA_mean(ind,:),1.96.*FBA_se(ind,:)); % 95% confidence bounds
ptch3.mainLine.Color = 'none';
ptch3.edge(1).Color = 'none';
ptch3.edge(2).Color = 'none';
ptch3.patch.FaceColor = FBA_col;
ptch3.patch.FaceAlpha = 0.3;
% BedMachine
s = scatter(time,BM_mean(ind,:),8,BM_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,BM_mean(ind,:),1.96.*BM_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = BM_col;
ptch2.patch.FaceAlpha = 0.3;
% BedMap2
s = scatter(time,B2_mean(ind,:),8,B2_col,'filled','markerEdgeColor','none'); hold on; datetick('x')
ptch2 = shadedErrorBar(time,B2_mean(ind,:),1.96.*B2_se(ind,:)); % 95% confidence bounds
ptch2.mainLine.Color = 'none';
ptch2.edge(1).Color = 'none';
ptch2.edge(2).Color = 'none';
ptch2.patch.FaceColor = B2_col;
ptch2.patch.FaceAlpha = 0.3;
%
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{'1996','1998','2000','2002','2004','2006','2008','2010',...
    '2012','2014','2016','2018','2020','2022'}); 
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),295,'Peninsula','color','k','fontname','Helvetica','fontweight','bold');
% save
export_fig('../out/pub/figures/bed_impact/discharge_bed_timeseries_Peninsula.png','-dpng','-r600');



