% plot_discharge_change

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Load data

% basins
basins = readBasinInfo;

% discharge
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

%% calculate trend for the full time-series

% pre-allocate
Qtr_lin = zeros([numel(basins.name),1]);
Qtr_rlin = zeros([numel(basins.name),1]);
R_SLF = zeros([numel(basins.name),1]);
P_SLF = zeros([numel(basins.name),1]);
quad = zeros([numel(basins.name),1]);
lin = zeros([numel(basins.name),1]);
icept = zeros([numel(basins.name),1]);

for i = 1:numel(basins.name)
    ts = bQ(i,:);
    if any(ts~=0)
        % Get linear fit
        [p, ~, mu] = polyfit(time(:), ts(:), 1);
        fit_ts = polyval(p, time(:), [], mu);
        Qtr_lin(i) = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
        Qtr_rlin(i) = Qtr_lin(i)/nanmedian(fit_ts).*100;
        [R_SLF(i), P_SLF(i)] = corr(time(:), ts(:), 'type', 'Pearson');
        % Get quadratic fit
        [p, ~, mu] = polyfit(time(:), ts(:), 2);
        quad(i) = p(1);
        lin(i) = p(2);
        icept(i) = p(3);
    end
end

save('../out/pub/discharge/stats/discharge_trend_1996-2023.mat','Qtr_lin','Qtr_rlin','R_SLF','P_SLF','quad','lin','icept');

%% Plot absolute trend for full time-series

% prepare colormap
cpts = -1:.025:1;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==2);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_lin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.05 pos(2)-0.075 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,'Discharge trend (Gt yr^{-2})','fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/1996-2023_discharge_trend.png','-dpng','-r600');


%% Plot relative trend for full time-series

% prepare colormap
cpts = -2.5:.025:2.5;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==2);
figure('color','none','units','inches','position',[1 1 6 6]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_rlin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
%cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
%cb.Ticks = 0:.5:1;
%cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
%cb.FontWeight = 'bold';
%pos = cb.Position;
%cb.Position = [pos(1)+0.05 pos(2)-0.075 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,{'Discharge trend','(% yr^{-1})'},'fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/1996-2023_rel_discharge_trend.png','-dpng','-r600');


%% Plot the absolute trend just on the Peninsula

% prepare colormap
cpts = -0.1:.0025:0.1;
cmap = cmocean('balance',length(cpts));

% Plot for Peninsula basins
ind = find(basins.type_ID==4);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_lin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
set(gca,'XLim',[-2.6491   -1.7795]*1e6,'YLim',[0.9740    1.6999]*1e6);
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.35 pos(2)-0.1 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,'Discharge trend (Gt yr^{-2})','fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/1996-2023_peninsula_discharge_trend.png','-dpng','-r600');


%% Plot relative trend for full time-series

% prepare colormap
cpts = -2.5:.01:2.5;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==4);
figure('color','none','units','inches','position',[1 1 6 6]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_rlin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
set(gca,'XLim',[-2.6491   -1.7795]*1e6,'YLim',[0.9740    1.6999]*1e6);
%cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
%cb.Ticks = 0:.5:1;
%cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
%cb.FontWeight = 'bold';
%pos = cb.Position;
%cb.Position = [pos(1)+0.35 pos(2)-0.1 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,{'Discharge trend','(% yr^{-1})'},'fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/1996-2023_peninsula_rel_discharge_trend.png','-dpng','-r600');



%% calculate trend for the full time-series

% pre-allocate
Qtr_lin = zeros([numel(basins.name),1]);
Qtr_rlin = zeros([numel(basins.name),1]);
R_SLF = zeros([numel(basins.name),1]);
P_SLF = zeros([numel(basins.name),1]);
quad = zeros([numel(basins.name),1]);
lin = zeros([numel(basins.name),1]);
icept = zeros([numel(basins.name),1]);

keep = time>=datenum(2016,1,1);
time = time(keep);
bQ = bQ(:,keep);
for i = 1:numel(basins.name)
    ts = bQ(i,:);
    if any(ts~=0)
        % Get linear fit
        [p, ~, mu] = polyfit(time(:), ts(:), 1);
        fit_ts = polyval(p, time(:), [], mu);
        Qtr_lin(i) = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
        Qtr_rlin(i) = Qtr_lin(i)/nanmedian(fit_ts).*100;
        [R_SLF(i), P_SLF(i)] = corr(time(:), ts(:), 'type', 'Pearson');
        % Get quadratic fit
        [p, ~, mu] = polyfit(time(:), ts(:), 2);
        quad(i) = p(1);
        lin(i) = p(2);
        icept(i) = p(3);
    end
end

save('../out/pub/figures/discharge_change/discharge_trend_2016-2023.mat','Qtr_lin','Qtr_rlin','R_SLF','P_SLF','quad','lin','icept');

%% Plot absolute trend for full time-series

% prepare colormap
cpts = -1:.025:1;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==2);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_lin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.05 pos(2)-0.075 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,'Discharge trend (Gt yr^{-2})','fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/2016-2023_discharge_trend.png','-dpng','-r600');


%% Plot relative trend for full time-series

% prepare colormap
cpts = -2.5:.025:2.5;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==2);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_rlin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.05 pos(2)-0.075 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,{'Discharge trend','(% yr^{-1})'},'fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/2016-2023_rel_discharge_trend.png','-dpng','-r600');


%% Plot the absolute trend just on the Peninsula

% prepare colormap
cpts = -0.1:.0025:0.1;
cmap = cmocean('balance',length(cpts));

% Plot for Peninsula basins
ind = find(basins.type_ID==4);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_lin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
set(gca,'XLim',[-2.6491   -1.7795]*1e6,'YLim',[0.9740    1.6999]*1e6);
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.35 pos(2)-0.1 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,'Discharge trend (Gt yr^{-2})','fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/2016-2023_peninsula_discharge_trend.png','-dpng','-r600');


%% Plot relative trend for full time-series

% prepare colormap
cpts = -2.5:.01:2.5;
cmap = cmocean('balance',length(cpts));

% Plot for imbie refined basins
ind = find(basins.type_ID==4);
figure('color','none','units','inches','position',[1 1 3 3]);
antbounds('coast','color','k'); hold on;
antbounds('coast','polyshape','facecolor','w');
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,Qtr_rlin(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
for i = 1:length(ind)
    plot(basins.x{ind(i)},basins.y{ind(i)},'k','linestyle','-','marker','none');
end
antbounds('coast','color','k'); hold on;
axis off
set(gca,'XLim',[-2.6491   -1.7795]*1e6,'YLim',[0.9740    1.6999]*1e6);
cb = colorbar('location','northoutside');
colormap(cmocean('balance'));
cb.Ticks = 0:.5:1;
cb.TickLabels = linspace(min(cpts),max(cpts),length(cb.Ticks));
cb.FontWeight = 'bold';
pos = cb.Position;
cb.Position = [pos(1)+0.35 pos(2)-0.1 pos(3)*0.25 pos(4)*0.5];
%xlabel(cb,{'Discharge trend','(% yr^{-1})'},'fontsize',10,'fontname','Helvetica','fontweight','bold');
export_fig('../out/pub/figures/discharge_change/2016-2023_peninsula_rel_discharge_trend.png','-dpng','-r600');

