% plot_discharge_examples

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;
names = basins.name;

% Load data
FB_mean = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
FB_se = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% add negligible random noise to time to help with plotting
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);



%% which shelves to plot

% shelves1 = {'Pine Island','Thwaites'}; % 100-150
% shelves2 = {'Denman Scott','Cook','Frost','Leopold and Astrid Coast'}; % 30-55
% shelves3 = {'Vincennes Bay','Kohler','Jutulstraumen'}; % 20-35
% shelves4 = {'Borchgrevink','Holmes','Ninnis'}; % 19-26
% shelves5 = {'Fleming','Fox','Prospect','Pope','Hektoria Green Evans'}; % 3.5-10
% shelves6 = {'Zonda Eureka','Skelton','Rennick','Leppard'}; % 1-5
% shelves7 = {'Victoria Land2','Lillie','Jorum','Harriott Headland'}; % ~0.2-0.7

shelves1 = {'Pine Island','Thwaites'}; % 100-150
shelves2 = {'Dotson_IS','Crosson_IS'}; % 25-40
shelves3 = {'Riiser and Brunt','Denman Scott'}; % West (a bit too much for this plot)
shelves4 = {'Frost','Vincennes Bay'}; % Cook (a bit too much discharge for this plot)
shelves5 = {'Larsen_B_IS','Ferrigno','Dibble'};
shelves6 = {'Comrie Glacier','Drygalski Glacier'};
shelves7 = {'Crane Glacier','Erskine Glacier','Flask Glacier','Leay Glacier'};
shelves8 = {'Nobile Glacier','Vogel Glacier','Boydell Glacier'};
shelves9 = {'Lawrie Glacier','Birley Glacier','Edgeworth Glacier'}; % Muller Ice Shelf (not quite enough discharge for this plot)
shelves10 = {'Bleriot Glacier','Niepce Glacier','Luke Glacier','Pyke Glacier'};
shelves11 = {'Campbell_IS','Bilgeri Glacier','Somigliana Glacier','Eltanin_Bay_IS'};
shelves12 = {'Balch Glacier','Barnes Glacier','Moser Glacier'};


%% Plot the full timeseries

% or pastels
cmap = cbrewer('qual','Set2',5);
cmap = repmat(cmap,[12,1]);
col_count = 0;
sc_even = 0;
sc_odd = 0;

% or mass budget scheme
cmap = [0.8500 0.3250 0.0980;
    0.4940 0.1840 0.5560;
    0.9290 0.6940 0.1250;
    0 0.4470 0.7410];

% Make figure
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

for i = 1:12

    if i == 1
        shelves_to_plot = shelves1;
    elseif i == 2
        shelves_to_plot = shelves2;
    elseif i == 3
        shelves_to_plot = shelves3;
    elseif i == 4
        shelves_to_plot = shelves4;
    elseif i == 5
        shelves_to_plot = shelves5;
    elseif i == 6
        shelves_to_plot = shelves6;
    elseif i == 7
        shelves_to_plot = shelves7;
    elseif i == 8
        shelves_to_plot = shelves8;
    elseif i == 9
        shelves_to_plot = shelves9;
    elseif i == 10
        shelves_to_plot = shelves10;
    elseif i == 11
        shelves_to_plot = shelves11;
    elseif i == 12
        shelves_to_plot = shelves12;
    end
    
    p = subplot(6,2,i);
    
    for j = 1:numel(shelves_to_plot)
        % increment colour
        col_count = j;
        % Get index of shelf in full basins
        if strcmp(shelves_to_plot{j},'Riiser and Brunt')
            idx = find(strcmp('Brunt Stancomb',names),1,'first');
            idx2 = find(strcmp('Riiser-Larsen',names),1,'first');
            FB_mean(idx,:) = FB_mean(idx,:) + FB_mean(idx2,:);
            FB_se(idx,:) = sqrt(FB_se(idx,:).^2 + FB_se(idx2,:).^2);
        else
            idx = find(strcmp(shelves_to_plot{j},names),1,'first');
        end
        % plot
        scatter(time,FB_mean(idx,:),8,cmap(col_count,:),'filled','markerEdgeColor','none'); hold on; datetick('x')
        ptch = shadedErrorBar(time,FB_mean(idx,:),1.96.*FB_se(idx,:)); % 95% confidence bounds
        ptch.mainLine.Color = 'none';
        ptch.edge(1).Color = 'none';
        ptch.edge(2).Color = 'none';
        ptch.patch.FaceColor = cmap(col_count,:);
        ptch.patch.FaceAlpha = 0.3;
    end
    
    % Visuals
    box on
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
        'XTick',datenum(1996:4:2024,1,1),'XTickLabel',{' '});
    pos = p.Position;
    if rem(i,2) == 0
        sc_even = sc_even+1;
        p.Position = [pos(1)+0.1 pos(2)+0.04+((sc_even-1)*0.04) pos(3).*0.8 pos(4)*0.75];
        %set(gca,'YAxisLocation','right');
    else
        sc_odd = sc_odd+1;
        p.Position = [pos(1) pos(2)+0.04+((sc_odd-1)*0.04) pos(3).*0.8 pos(4)*0.75];
    end
    
    if i == 1
        set(gca,'YTick',100:20:140);
    elseif i == 2
        set(gca,'YTick',25:5:35,'YLim',[23 39]);
    elseif i == 3
        set(gca,'YTick',38:41,'YTickLabel',{'38','39','40','41'},'YLim',[37.3 41.5]);
    elseif i == 4
        set(gca,'YTick',27:30,'YTickLabel',{'27','28','29','30'},'YLim',[25.8 30.5]);
    elseif i == 5
        set(gca,'YTick',13:16,'YTickLabel',{'13','14','15','16'},'YLim',[12.7 16.3]);
    elseif i == 6
        set(gca,'YTick',2:.5:2.5,'YTickLabel',{'2','2.5'},'YLim',[1.65 2.9]);
    elseif i == 7
        set(gca,'YTick',1:.5:2,'YTickLabel',{'1','1.5','2'},'YLim',[0.9 2.2]);
    elseif i == 8
        set(gca,'YTick',0.05:.05:0.15,'YTickLabel',{'0.05','0.1','0.15'},'YLim',[0.04 0.16]);
    elseif i == 9
        set(gca,'YTick',0.5:.5:1.5,'YTickLabel',{'0.5','1',''},'YLim',[0.3 1.5]);
    elseif i == 10
        set(gca,'YTick',0.5:0.25:1,'YTickLabel',{'','0.75','1'},'YLim',[0.56 1.05]);
    elseif i == 11
        set(gca,'YTick',0.2:0.1:0.4,'YTickLabel',{'0.2','0.3',''},'YLim',[0.15 0.4]);
    elseif i == 12
        set(gca,'YTick',0.1:0.1:0.3,'YTickLabel',{'0.1','0.2','0.3'},'YLim',[0.09 0.31]);
    end
    
    if i==11 || i == 12
        set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
        'XTick',datenum(1996:2:2024,1,1),...
        'XTickLabel',{'','1997','','2001','','2005','','2009','','2013','','2017','','2021',''}); 
        xtickangle(45)
    end

end


% save
export_fig('../out/pub/figures/discharge_examples/discharge_examples_1996-2023.png','-dpng','-r600');








% %% Plot the timeseries after 2016
% 
% col_count = 0;
% sc_even = 0;
% sc_odd = 0;
% 
% % Make figure
% figure('color','w','units','inches','position',[1 1 2 6],'visible','on');
% subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.15 .05]);
% 
% for i = 1:6
% 
%     if i == 1
%         shelves_to_plot = shelves1;
%     elseif i == 2
%         shelves_to_plot = shelves2;
%     elseif i == 3
%         shelves_to_plot = shelves3;
%     elseif i == 4
%         shelves_to_plot = shelves4;
%     elseif i == 5
%         shelves_to_plot = shelves5;
%     elseif i == 6
%         shelves_to_plot = shelves6;
%     elseif i == 7
%         shelves_to_plot = shelves7;
%     elseif i == 8
%         shelves_to_plot = shelves8;
%     end
%     
%     p = subplot(6,1,i);
%     
%     for j = 1:numel(shelves_to_plot)
%         
%         % increment colour
%         col_count = col_count+1;
%         col_count = j;
%         
%         % Get index of shelf in full basins
%         idx = find(strcmp(shelves_to_plot{j},basins.name),1,'first');
%     
%         % plot
%         scatter(time,FB_mean(idx,:),8,cmap(col_count,:),'filled','markerEdgeColor','none'); hold on; datetick('x')
%         ptch = shadedErrorBar(time,FB_mean(idx,:),1.96.*FB_se(idx,:)); % 95% confidence bounds
%         ptch.mainLine.Color = 'none';
%         ptch.edge(1).Color = 'none';
%         ptch.edge(2).Color = 'none';
%         ptch.patch.FaceColor = cmap(col_count,:);
%         ptch.patch.FaceAlpha = 0.3;
%         % plot the unsmoothed data
%         %plot(time,ns.bQ(idx,:),'color',cmap(col_count,:),'linewidth',1); 
%         disp(['Just plotted ' shelves_to_plot{j} ]);
%         disp(' ');
%                 
%     end
%     
%     box on
%     set(gca,'XLim',[datenum(2016,1,1) datenum(2023,7,1)],...
%         'XTick',datenum(2017:2:2023,1,1),'XTickLabel',{' '});
%     pos = p.Position;
% %     if rem(i,2) == 0
% %         sc_even = sc_even+1;
% %         p.Position = [pos(1) pos(2)+0.04+((sc_even-1)*0.04) pos(3) pos(4)*0.75];
% %         set(gca,'YAxisLocation','right');
% %     else
%         sc_odd = sc_odd+1;
%         p.Position = [pos(1) pos(2)+0.04+((sc_odd-1)*0.04) pos(3) pos(4)*0.75];
%     %end
%     
%     if i == 1
%         set(gca,'YLim',[128 155]);
%     elseif i == 2
%         set(gca,'YTick',32:2:40,'YLim',[33 41]);
%     elseif i ==3
%         set(gca,'YTick',14:2:22);
%     elseif i == 4
%         set(gca,'YTick',1.25:0.5:2.75);
%     elseif i == 5
%         set(gca,'YTick',0.6:0.2:1);
%     elseif i == 6
%         set(gca,'YTick',0.2:0.1:0.6,'YTickLabel',{' ','0.3','0.4','0.5',' '});
%     end
%     
%     if i==6 || i == 6
%         set(gca,'XTickLabel',{'2017','2019','2021','2023'}); 
%         xtickangle(45)
%     end
% 
% end
% 
% 
% 
% % save
% export_fig('../out/pub/figures/discharge_examples/discharge_examples_2016-2023.png','-dpng','-r600');

