% plot_firn_impact

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;
num_gates = 16;

% Load data
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time') + datenum(1950,1,1,0,0,0);
FDM_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates');
GSFC_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates_GSFC');

% Calculate relative difference between models
firn_diff = (FDM_Q-GSFC_Q)./FDM_Q.*100;

% Prepare plotting
cmap = colorcet('Gouldian','N',num_gates);

%% Plot

% Make figure
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(5,1,1);
ind = 1;
for i = 1:num_gates
    scatter(time,squeeze(firn_diff(ind,:,i)),8,cmap(i,:),'filled','markerEdgeColor','none'); 
    if i == 1; hold on; datetick('x'); end
end
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '});
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),0.42,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% West Antarctica
p2 = subplot(5,1,2);
ind = 2;
for i = 1:num_gates
    scatter(time,squeeze(firn_diff(ind,:,i)),8,cmap(i,:),'filled','markerEdgeColor','none'); 
    if i == 1; hold on; datetick('x'); end
end
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YAxisLocation','right',...
    'YLim',[0.36 0.51]);
pos = p2.Position;
p2.Position = [pos(1) pos(2)+0.1 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),0.48,'West Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% East Antarctica
p3 = subplot(5,1,3);
ind = 3;
for i = 1:num_gates
    scatter(time,squeeze(firn_diff(ind,:,i)),8,cmap(i,:),'filled','markerEdgeColor','none'); 
    if i == 1; hold on; datetick('x'); end
end
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '},...
    'YLim',[0.085 0.24]);
pos = p3.Position;
p3.Position = [pos(1) pos(2)+0.15 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),0.205,'East Antarctica','color','k','fontname','Helvetica','fontweight','bold');

% Peninsula
p4 = subplot(5,1,4);
ind = 4;
for i = 1:num_gates
    scatter(time,squeeze(firn_diff(ind,:,i)),8,cmap(i,:),'filled','markerEdgeColor','none'); 
    if i == 1; hold on; datetick('x'); end
end
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,8,1)],...
    'XTick',datenum(1996:2:2024,1,1),...
    'XTickLabel',{'1996','1998','2000','2002','2004','2006','2008','2010',...
    '2012','2014','2016','2018','2020','2022'},...
    'YAxisLocation','right',...
    'YTick',0.8:.1:1.2);
pos = p4.Position;
p4.Position = [pos(1) pos(2)+0.2 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),1.15,'Peninsula','color','k','fontname','Helvetica','fontweight','bold');

export_fig('../out/pub/figures/firn_impact/firn.png','-dpng','-r600');
close

%% Plot one with a colorbar
% Make figure
figure('color','w','units','inches','position',[1 1 8 6],'visible','on');
subplot = @(m,n,p) subtightplot (m, n, p,[.01 0.01],[.05 .05],[.1 .1]);

% Plot all Antarctica
p1 = subplot(3,1,1);
ind = 1;
for i = 1:num_gates
    scatter(time,squeeze(firn_diff(ind,:,i)),8,cmap(i,:),'filled','markerEdgeColor','none'); 
    if i == 1; hold on; datetick('x'); end
end
box on
set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
    'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '});
pos = p1.Position;
p1.Position = [pos(1) pos(2)+0.05 pos(3) pos(4)*0.75];
text(datenum(1998,7,1),0.39,'Antarctica','color','k','fontname','Helvetica','fontweight','bold');
cb = colorbar;
colormap(cmap);
caxis([0 3000]);
export_fig('../out/pub/figures/firn_impact/firn_colorbar.png','-dpng','-r600');
close


