% plot_firn_overview

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Load data

FDM2D = load('../out/pub/reference_grids/FAC_clim_2D.mat');
GSFC2D = load('../out/int/reference_grids/FAC_clim_2D_GSFC.mat');
FDM = load('../out/int/gate_data/FAC_migrate_0m.mat','fac_monthly_clim','fac_monthly','fac_time');
GSFC = load('../out/int/gate_data/FAC_GSFC_migrate_0m.mat','fac_monthly_clim','fac_monthly','fac_time');

% get limits
[~,x,y] = geoimread('../out/pub/reference_grids/FrankenBed_WGS84.tif');
xlims = [min(x(:)),max(x(:))];
ylims = [min(y(:)),max(y(:))];

% set time for monthly data
monthly_clim_time = datenum(1991,1:12,15) - datenum(1991,1,15); % arbitrary time, to give Jan-Dec#

% get lat/lon
[FDM2D.lat, FDM2D.lon] = ps2ll(FDM2D.fac_x,FDM2D.fac_y);
[GSFC2D.lat, GSFC2D.lon] = ps2ll(GSFC2D.x,GSFC2D.y);

% mask helps with visualising
mask = bedmachine_interp('mask',FDM2D.fac_x,FDM2D.fac_y);
isice = single(mask~=0 & isfinite(FDM2D.fac_clim_2D));
isice(isice==0)=NaN;
mask = bedmachine_interp('mask',GSFC2D.x,GSFC2D.y);
isiceGSFC = single(mask~=0 & isfinite(GSFC2D.fac_clim_2D));
isiceGSFC(isiceGSFC==0)=NaN;

% interpolate to same grid
GSFC2D.fac_clim_2D_interp = interp2(GSFC2D.x,GSFC2D.y,GSFC2D.fac_clim_2D,FDM2D.fac_x,FDM2D.fac_y);



%% Plot climatology

% Plot FDM climatology
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
pcolorps(FDM2D.lat,FDM2D.lon,FDM2D.fac_clim_2D.*isice); shading interp
caxis([0 30]);
cmocean('ice');
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/firn_overview/FDM_2D.png','-dpng','-r600');
close

% Plot GSFC climatology
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
pcolorps(GSFC2D.lat,GSFC2D.lon,GSFC2D.fac_clim_2D.*isiceGSFC); shading interp
caxis([0 30]);
cmocean('ice');
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/firn_overview/GSFC_2D.png','-dpng','-r600');
close

% Plot FAC colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
pcolorps(FDM2D.lat,FDM2D.lon,FDM2D.fac_clim_2D.*isice);
caxis([0 30]);
cmocean('ice');
cb = colorbar('location','southoutside');
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2)-0.15 cbpos(3)*0.8 cbpos(4)*0.75];
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/firn_overview/FAC_colorbar.png','-dpng','-r600');
close

% Plot FAC difference
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
pcolorps(FDM2D.lat,FDM2D.lon,FDM2D.fac_clim_2D - GSFC2D.fac_clim_2D_interp);
caxis([-10 10]);
cmocean('balance','pivot',0);
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/firn_overview/FDM_minus_GSFC_2D.png','-dpng','-r600');
close

% Difference colorbar
figure('color','w','units','inches','position',[1 1 2.5 2.5]);
antbounds('coast','color','k'); hold on
pcolorps(FDM2D.lat,FDM2D.lon,FDM2D.fac_clim_2D - GSFC2D.fac_clim_2D_interp);
caxis([-10 10]);
cmocean('balance','pivot',0);
cb = colorbar('location','southoutside');
cbpos = cb.Position;
cb.Position = [cbpos(1) cbpos(2)-0.15 cbpos(3)*0.8 cbpos(4)*0.75];
axis off
set(gca,'XLim',xlims,'YLim',ylims);
antbounds('coast','color','k');
antbounds('gl','color','k');
export_fig('../out/pub/figures/firn_overview/FAC_diff_colorbar.png','-dpng','-r600');
close


%% Plot monthly climatology for both

figure('color','w','units','inches','position',[1 1 3.5 1]);
plot(monthly_clim_time,nanmean(FDM.fac_monthly_clim,1),'color',[0    0.4470    0.7410],'linewidth',2); datetick('x','mmm'); 
yyaxis right
plot(monthly_clim_time,nanmean(GSFC.fac_monthly_clim,1),'color',[0.8500    0.3250    0.0980],'linewidth',2);
box on
set(gca,'XLim',[min(monthly_clim_time) max(monthly_clim_time)]);
ax = gca;
ax.YAxis(2).Color = [0.8500    0.3250    0.0980];
xtickangle(45);
export_fig('../out/pub/figures/firn_overview/monthly_FAC_clim.png','-dpng','-r600');

%% Plot histogram of monthly differences

d = nanmean(FDM.fac_monthly_clim,2) - nanmean(GSFC.fac_monthly_clim,2);
figure('color','w','units','inches','position',[1 1 1.5 1.5]);
h1 = histogram(nanmean(FDM.fac_monthly_clim,2),'binwidth',0.5,'edgecolor','none','facealpha',0.6); hold on
h2 = histogram(nanmean(GSFC.fac_monthly_clim,2),'binwidth',0.5,'edgecolor','none','facealpha',0.6);
export_fig('../out/pub/figures/firn_overview/FAC_hist.png','-dpng','-r600');





