% plot_flux_gates

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% load flux gates
g = shaperead('../out/pub/gates/flux_gates.shp');

% Set coordinates
[~,x,y] = geoimread('../out/pub/reference_grids/FrankenBed.tif');
x = min(x):500:max(x);
y = max(y):-500:min(y);
xlims = [min(x(:)),max(x(:))];
ylims = [min(y(:)),max(y(:))];
[X,Y] = meshgrid(x,y);

% mask helps with visualising
mask = bedmachine_interp('mask',X,Y);
mask = single(mask~=0);
mask(mask==0)=NaN;

% prep MOA
load('../out/pub/figures/flux_gates/modismoa_xy');
[modis_X,modis_Y] = meshgrid(modis_x,modis_y);
moa = imread('moa750_2014_hp1_v01.tif', 'PixelRegion', {[1 6542],[234 8056]});
moa = interp2(modis_X,modis_Y,single(moa),X,Y);
moa(mask==0 | isnan(mask))=NaN;
moa=uint16(moa);
RGB = mat2im(moa,gray(256),[1 17500]); 

%% Plot antarctic wide

cmap = colorcet('Gouldian','N',16);
figure('color','w','units','inches','position',[1 1 5 5]);
da = daspect; 
da = [1 1 da(3)]; 
antbounds('coast','color','none'); hold on
hm = image(x,y,RGB); axis xy
set(hm,'alphadata',moa>0)
uistack(hm,'bottom') 
ax = axis;
axis xy 
daspect(da)
% plot gates
for i = 1:16
    plot(g.X{i},g.Y{i},'color',cmap(i,:),'linewidth',1);
end
axis off
% plot boxes for zoom plots
xplot = [-1.6174   -1.5698]*1e6;
yplot = [-2.7722   -2.3754]*1e5;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [1.6501    1.7267]*1e6;
yplot = [6.8084    7.4480]*1e5;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [-2.4368   -2.3861]*1e6;
yplot = [1.2454    1.2877]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [-6.5957   -5.4778]*1e5;
yplot = [5.4988    6.4320]*1e5;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [1.3507    1.4011]*1e6;
yplot = [1.6720    1.7141]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [-5.6097   -0.3007]*1e4;
yplot = [1.9714    2.0157]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [-2.1303   -2.0670]*1e6;
yplot = [8.6020    9.1305]*1e5;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [-8.2878   -7.7813]*1e5;
yplot = [-1.1993   -1.1571]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [4.4592    4.7477]*1e5;
yplot = [-1.7349   -1.7108]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
xplot = [2.2555    2.2963]*1e6;
yplot = [-1.0265   -0.9924]*1e6;
plot([xplot(1) xplot(1) xplot(2) xplot(2) xplot(1)],[yplot(1) yplot(2) yplot(2) yplot(1) yplot(1)],'r');
export_fig('../out/pub/figures/flux_gates/gates_AIS.png','-dpng','-r600');


% Plot PIG zoom
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-1.6174   -1.5698]*1e6;
yplot = [-2.7722   -2.3754]*1e5;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',10,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_PIG.png','-dpng','-r600');


% Plot Amery zoom
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [1.6501    1.7267]*1e6;
yplot = [6.8084    7.4480]*1e5;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',10,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_Amery.png','-dpng','-r600');


% Plot zome of LarsenB
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-2.4368   -2.3861]*1e6;
yplot = [1.2454    1.2877]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',35,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_LB.png','-dpng','-r600');


% Plot Recovery
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-6.5957   -5.4778]*1e5;
yplot = [5.4988    6.4320]*1e5;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',10,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_recovery.png','-dpng','-r600');


% Plot Shirase
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [1.3507    1.4011]*1e6;
yplot = [1.6720    1.7141]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',20,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_shirase.png','-dpng','-r600');


% Plot Jutulstraumen
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-5.6097   -0.3007]*1e4;
yplot = [1.9714    2.0157]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+5; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',15,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_jutulstraumen.png','-dpng','-r600');


% Plot Wordie
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-2.1303   -2.0670]*1e6;
yplot = [8.6020    9.1305]*1e5;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+1; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',25,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_wordie.png','-dpng','-r600');


% Plot Sulzberger
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [-8.2878   -7.7813]*1e5;
yplot = [-1.1993   -1.1571]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+1; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','lc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',25,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_sulzberger.png','-dpng','-r600');


% plot mariner
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [4.4592    4.7477]*1e5;
yplot = [-1.7349   -1.7108]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+1; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','ulc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',20,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_mariner.png','-dpng','-r600');


% plot Totten
figure('color','w','units','inches','position',[1 1 2 2]);
antbounds('coast','color','none'); hold on
xplot = [2.2555    2.2963]*1e6;
yplot = [-1.0265   -0.9924]*1e6;
mapwidth = (max([xplot(2)-xplot(1), yplot(2)-yplot(1)])/1000)+1; % 50 km buffer
[lat_plot,lon_plot] = ps2ll(xplot,yplot);
modismoa(mean(lat_plot),mean(lon_plot),mapwidth,'resolution',125,'contrast','ulc');
measures('velocity',mean(lat_plot),mean(lon_plot),'color',[1.00 0.54 0.00],'mapwidthkm',mapwidth,...
    'arrowdensity',15,'linewidth',1);
for i = 1:16
    [gate_lat,gate_lon] = ps2ll(g.gate_x_migrate{i},g.gate_y_migrate{i});
    plotm(gate_lat,gate_lon,'color',cmap(i,:),'linewidth',1);
end
axis off
export_fig('../out/pub/figures/flux_gates/gates_totten.png','-dpng','-r600');
