% plot_reference_velocity

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../out'));

%% Plot velocity time-series

% load flux gates
g = shaperead('../out/pub/gates/flux_gates.shp');
gate_x = g(end).X;
gate_y = g(end).Y;
clear g

load('../out/int/gate_data/prepped_vel.mat','time_vel');
raw = load('../out/int/gate_data/prepped_sp_SID_corrected.mat');
glob = load('../out/int/gate_data/global_outliers_removed.mat');
loc = load('../out/int/gate_data/local_outliers_removed.mat');
filled = load('../out/int/gate_data/gap_filled.mat');
sm = load('../out/int/gate_data/smoothed_vel.mat');
time = time_vel;

% Get cross-gate velocity for finding pixels to plot
load('../out/int/gate_data/gate_vel_filled_migrate_0m_SID_corrected.mat','vx_filled','vy_filled','time_vel')
load('../out/int/gate_data/reference_gate_data_migrate_0m.mat','gate_theta');
gate_theta = repmat(gate_theta,[1,length(time_vel)]);
sp = abs(vx_filled.*sin(gate_theta) - vy_filled.*cos(gate_theta)); % use the cross-gate velocity to find outliers

% load basins
basins = readBasinInfo;
count = 0;
idx = ones([2000,1]).*-9999;
basins_to_plot = cell([2000,1]);
time_use = time>datenum(2015,1,1);
for i = 1:numel(basins.name)
    if basins.type_ID(i) == 2 % IMBIE refined
        count = count+1;
        in = find(inpoly2([gate_x(:),gate_y(:)],[basins.x{i},basins.y{i}]));
        prop_isf = sum(isfinite(sp(in,time_use)),2)./sum(time_use).*100;
        sp_tmp = nanmean(sp(in,time_use),2); % time-average
        sp_tmp(prop_isf<80) = NaN;
        [~,fastest] = nanmax(sp_tmp);
        if isempty(fastest)
            sp_tmp = nanmean(sp(in,:),2);
            [~,fastest] = nanmax(prop_isf);
        end
        if ~isempty(fastest)
            idx(count) = in(fastest);
            basins_to_plot{count} = basins.name{i};
        end
    elseif basins.type_ID(i) == 4 && contains(basins.name{i},'unnamed')==0
        in = find(inpoly2([gate_x(:),gate_y(:)],[basins.x{i},basins.y{i}]));
        if sum(in)>0
            count = count+1;
            prop_isf = sum(isfinite(sp(in,time_use)),2)./sum(time_use).*100;
            sp_tmp = nanmean(sp(in,time_use),2);
            sp_tmp(prop_isf<80) = NaN;
            [~,fastest] = nanmax(sp_tmp);
            if isempty(fastest)
                sp_tmp = nanmean(sp(in,time_use),2);
                [~,fastest] = nanmax(prop_isf);
            end
            if ~isempty(fastest)
                idx(count) = in(fastest);
                basins_to_plot{count} = basins.name{i};
            end
        end
    end
end

% remove extra rows
remove = idx==-9999;
idx(remove) = [];
basins_to_plot(remove) = [];

% plot
for i = 1:length(idx)
    
    % make figure
%     if strcmp(basins_to_plot{i},'Pine Island')==1 || strcmp(basins_to_plot{i},'Ferrigno')==1 || strcmp(basins_to_plot{i},'Amery')==1 || strcmp(basins_to_plot{i},'Denman Scott')==1
%         figure('color','w','units','inches','position',[1 1 2.6 1])
%     else
        figure('color','w','units','inches','position',[1 1 2 1])
    %end
    
    % plot data
    scatter(time,raw.sp(idx(i),:),7,'ko'); hold on; datetick('x'); % raw
    %scatter(time,glob.sp_global_clean1(idx,:),3,'r^');          % global clean 1
    scatter(time,glob.sp_global_clean2(idx(i),:),5,'ro','filled'); % global clean 2
    %scatter(time,loc.sp_local_clean1(idx,:),3,'bv');            % local clean 1
    scatter(time,loc.sp_local_clean2(idx(i),:),5,'bs','filled');   % local clean 2
    plot(time,filled.sp_filled(idx(i),:),'color',[.5 .5 .5],'linestyle','--'); % filled
    plot(time,sm.sp_filled(idx(i),:),'color','k','linestyle','-'); % filled and smoothed 
    
    % set visuals
    box on
    set(gca,'fontsize',8,'fontname','Helvetica',...
        'XLim',[datenum(2015,1,1) datenum(2023,8,1)],...
        'XTick',datenum(2015:2:2023,7,1),'XTickLabel',{'','2017','','2021',''});
    
    % save
    export_fig(['../out/pub/figures/reference_velocity/basin/p80_sp_cleaning_timeseries_' basins_to_plot{i} '_' num2str(idx(i)) '.png'],'-dpng','-r600');
    close
    
end

% index of time-series to plot
basins_to_plot = {'Pine Island','Cook','Denman Scott','Ferrigno','Jutulstraumen',...
    'Shirase Glacier','WilmaRobertDowner','Fleming','Cadman Glacier','Trooz Glacier',...
    'Amery','Sulzberger','Land','Aviator','Rennick','Borchgrevink','Broad Valley Glacier',...
    'LarsenC','Thwaites','Getz','Dotson'};
idx = [194959;107844;69836;208858;6238;24914;39482;221938;232227;232852;51651;170848;175537;126429;115287;242025;252187;191631;180351;189363];


%% Plot velocity map

% velocity
load('../out/pub/reference_grids/reference_velocity_200m.mat','vx','vy');
load('../out/pub/reference_grids/reference_thickness_200m.mat','x','y');
sp = hypot(vx,vy);
clear vx vy

% BedMachine mask
[X,Y] = meshgrid(x,y);
mask = bedmachine_interp('mask',X,Y);
mask = single(ismember(mask,[1 2 3 4]) & isfinite(sp));
mask(mask==0)=NaN;
clear X Y 

% plot
figure('color','none','units','inches','position',[1 1 3.5 3.5]);
antbounds('coast','k'); hold on;
imagescn(x,y,log10(sp).*mask);
rgbmap('white','ice blue','ocean blue','tan','red','mahogany','black',455);
caxis(log10([1 3000]))
set(gca,'fontsize',10);
axis off
antbounds('coast','k');
antbounds('gl','k'); 
scatter(gate_x(idx),gate_y(idx),12,'y','filled');
export_fig('../out/pub/figures/reference_velocity/reference_velocity.png','-dpng','-r600');

% plot a zoomed in version on the peninsula
set(gca,'XLim',[-2.7401   -1.7774].*1e6,'YLim',[0.8401    1.6437].*1e6);
export_fig('../out/pub/figures/reference_velocity/reference_velocity_peninsula.png','-dpng','-r600');

% Get colorbar
cb = colorbar;
cb.Ticks = log10([1 10 100 1000 3000]);
cb.TickLabels = {'1','10','100','1000','3000'};
export_fig('../out/pub/figures/reference_velocity/colorbar.png','-dpng','-r600');
