% migrate_AIS_flux_gate

clear 
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% main

% Load initial flux gate
load('../out/int/gates/initial_flux_gate.mat');

% Convert flux gates to mask
[~,x,y] = geoimread('D:\work\Fellowship_Leeds\Data\Velocity\Antarctica\ENVEO\multiyear\ENVEO_antarctica_iv_s1_all_v20210908/antarctica_iv_200m_s1_all_v20210908_mag.tif');
[X,Y] = meshgrid(x,y);
in = inpoly2([X(:),Y(:)],[gate_x(:),gate_y(:)]);
grounded = single(zeros(size(X)));
grounded(in) = 1;
grounded = logical(grounded);
clear in x y

% Buffer mask
migration_distance = 0:200:3000; % metres
migration_pixels = migration_distance./200; 
gate_x_migrate = cell([length(migration_pixels),1]);
gate_y_migrate = cell([length(migration_pixels),1]);
gate_x_migrate{1} = gate_x;
gate_y_migrate{1} = gate_y;
X = X';
Y = Y';
for i = 2:length(migration_pixels)
    disp(['Migrating gates ' num2str(migration_distance(i)) ' metres']);
    % Buffer mask
    g2 = imerode(grounded,strel('disk',i));
    g2 = imfill(g2,'holes');
    % Get boundary coordinates
    B = bwboundaries(g2,8);
    % Only keep two longest boundaries
    len = zeros([numel(B),1]).*NaN;
    for j = 1:numel(B)
        len(j) = size(B{j},1);
    end
    [~,iv] = sort(len,'descend');
    % Loop through the two largest boundaries (should be AIS and Wilkins Island)
    for j = 1:2
        Bxy = B{iv(j)};
        tmp_x = zeros([size(Bxy,1),1]).*NaN;
        tmp_y = zeros([size(Bxy,1),1]).*NaN;
        for ii = 1:size(Bxy,1)
            tmp_x(ii) = X(Bxy(ii,2),Bxy(ii,1));
            tmp_y(ii) = Y(Bxy(ii,2),Bxy(ii,1));
        end
        % Make points regularly spaced at 200m
        total_length = arclength(tmp_x(:),tmp_y(:)); % total length of the transect in metres
        xy = interparc(0:(200/total_length):1,tmp_x(:),tmp_y(:),'linear');
        tmp_x = xy(:,1);
        tmp_y = xy(:,2);
        if j == 1
            new_x = [tmp_x(:);NaN];
            new_y = [tmp_y(:);NaN];
        else
            new_x = [new_x(:);tmp_x(:);NaN];
            new_y = [new_y(:);tmp_y(:);NaN];
        end
    end
    % save
    gate_x_migrate{i} = new_x;
    gate_y_migrate{i} = new_y;
end

% plot
% cmap = parula(numel(gate_x_migrate));
% plot(gate_x,gate_y,'k'); hold on
% for i = 1:numel(gate_x_migrate)
%     plot(gate_x_migrate{i},gate_y_migrate{i},'color',cmap(i,:));
% end

compression_factor = 5;
g.gate_x_migrate = gate_x_migrate;
g.gate_y_migrate = gate_y_migrate;
save_flux_gates(g,migration_distance,compression_factor)



    