function save_flux_gates(g,migration_distance,compression_factor)

% matfile
gate_x_migrate = g.gate_x_migrate;
gate_y_migrate = g.gate_y_migrate;
save('../out/pub/gates/flux_gates_migrated.mat','gate_x_migrate','gate_y_migrate','migration_distance');


gates_to_netcdf(g,migration_distance,'flux_gates.nc',compression_factor);
gates_to_shapefile(g,migration_distance,'flux_gates.shp');

end


%% Function: gates_to_shapefile
function gates_to_shapefile(gates,migration_distance,outfile)

S = struct();
for i = 1:length(migration_distance)
	S(i).Geometry = 'Line';
    S(i).X = gates.gate_x_migrate{i};
    S(i).Y = gates.gate_y_migrate{i};
	S(i).distance = migration_distance(i);
end
    
% Save
shapewrite(S,['../out/pub/gates/' outfile ]);
str = "PROJCS[""WGS_84_Antarctic_Polar_Stereographic"",GEOGCS[""GCS_WGS_1984"",DATUM[""D_WGS_1984"",SPHEROID[""WGS_1984"",6378137,298.257223563]],PRIMEM[""Greenwich"",0],UNIT[""Degree"",0.017453292519943295]],PROJECTION[""Stereographic_South_Pole""],PARAMETER[""standard_parallel_1"",-71],PARAMETER[""central_meridian"",0],PARAMETER[""false_easting"",0],PARAMETER[""false_northing"",0],UNIT[""Meter"",1]]";
outprj = [extractBefore(outfile,'.shp') '.prj'];
writelines(str,['../out/pub/gates/' outprj ]);

end

%% Function gates_to_netcdf
function gates_to_netcdf(gates,migration_distance,outfile,compression_factor)

% Get gate info
all_gate_x = padcat(gates.gate_x_migrate{:})';
all_gate_y = padcat(gates.gate_y_migrate{:})';

% set full outfile
outfile = ['../out/pub/gates/' outfile ];

% make netcdf
cmode = netcdf.getConstant('NETCDF4');
cmode = bitor(cmode,netcdf.getConstant('NC_WRITE'));
command = ['rm -f ' outfile]; system(command);
ncid = netcdf.create(outfile,cmode); 
% Set global attributes
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'Conventions','ACDD-1.3');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'title','Flux gates for Antarctic grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'summary','Flux gates for Antarctic grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_name','Benjamin Davison');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_email','b.davison@leeds.ac.uk');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'institution','University of Leeds');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'source','https://doi.org/10.5281/zenodo.10051894');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'product_version','1.0');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'keywords','Antarctic Ice Sheet; grounding line discharge; flux gates');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'date_modified', datestr(datetime('now'),'yyyymmddTHHMMSS'));
%   - create dimensions
dimidGateXLen = netcdf.defDim(ncid,'coordinate',size(all_gate_x,2));
dimidGate = netcdf.defDim(ncid,'gate',length(migration_distance));
%   - Define gate x coordinates variable
GateXVarid = netcdf.defVar(ncid,'gate_x','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,GateXVarid,false,true,compression_factor);
netcdf.putAtt(ncid,GateXVarid,'long_name','gate x coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateXVarid,'standard_name','gate x coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateXVarid ,'units','m');
netcdf.putAtt(ncid,GateXVarid,'coverage_content_type','coordinate'); % (image, thematicClassification, physicalMeasurement, auxiliaryInformation, qualityInformation, referenceInformation, modelResult, or coordinate).
netcdf.putAtt(ncid,GateXVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,GateXVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,GateXVarid,all_gate_x);
%   - Define gate y coordinates variable
GateYVarid = netcdf.defVar(ncid,'gate_y','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,GateYVarid,false,true,compression_factor);
netcdf.putAtt(ncid,GateYVarid,'long_name','gate y coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateYVarid,'standard_name','gate y coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateYVarid,'coverage_content_type','coordinate');
netcdf.putAtt(ncid,GateYVarid ,'units','m');
netcdf.putAtt(ncid,GateYVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,GateYVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,GateYVarid,all_gate_y);
%   - Define gate distance variable
GateDistVarid = netcdf.defVar(ncid,'distance','NC_FLOAT',dimidGate);
netcdf.putAtt(ncid,GateDistVarid,'long_name','distance upstream from seaward gate');
netcdf.putAtt(ncid,GateDistVarid,'standard_name','distance');
netcdf.putAtt(ncid,GateDistVarid,'coverage_content_type','referenceInformation');
netcdf.putAtt(ncid,GateDistVarid ,'units','m');
netcdf.putVar(ncid,GateDistVarid,migration_distance);

% close netcdf
netcdf.close(ncid);

end