% calc_smb_correction

clear
close all
clc

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/RACMO/Antarctica/2022_update'));
end

%% load flux gates

load('../out/pub/gates/flux_gates_migrated.mat');
migration_distance = 0:200:3000; % metres

%% SMB

% Get info 
fn = 'RACMO2.3p2_ERA5_ANT27_smb_monthly_1979_01_2021_12.nc';
smb_time = datenum(1950,1,1) + ncread(fn,'time');
lat = ncread(fn,'lat');
lon = ncread(fn,'lon');
[x,y] = ll2ps(lat,lon);
clear lat lon 

% Load
smb = ncread(fn,'smb');
smb(smb<0.01 & smb>-0.01)=NaN;
smb = permute(smb,[1,2,4,3]);

% Get long-term mean in every pixel
idx = find(smb_time>=datenum(1979,1,1) & smb_time<datenum(2009,1,1));
smb_avg = nanmean(smb(:,:,idx),3);
nanval = smb_avg(1);
smb_avg(smb_avg==nanval) = NaN;

% Fill gaps in long term average
smb_avg([1,end],:) = 0;
smb_avg(:,[1,end]) = 0;
smb_avg = regionfill(smb_avg,isnan(smb_avg));

% Interpolate to gate
F = scatteredInterpolant(x(:),y(:),smb_avg(:));
for i = 1:numel(gate_x_migrate)
    gate_x = gate_x_migrate{i};
    gate_y = gate_y_migrate{i};
    smb_rate = F(gate_x,gate_y);
    smb_rate = -((smb_rate.*(1000/917))./1000.*-12); % convert to metres ice equivalent per year
    % Account for time taken for ice parcels to reach true grounding line
    if i == 1
        gate_smb = smb_rate.*3; % first gate is 3 years of ice flow upstream of grounding line
    else
        load(['../out/int/gate_data/reference_gate_data_migrate_' num2str(migration_distance(i)) 'm.mat'],'gate_ctv');
        too_slow = gate_ctv<=200; % if ice is flowing slowly, then we might end up with some extremely large corrections, which are probably unrealistic
        t = migration_distance(i)./gate_ctv; % years to reach gate 1
        gate_smb = smb_rate.*(t+3); % negative equals thinning
        gate_smb(too_slow) = smb_rate(too_slow).*3; % keep the original correction in slow-flowing areas
    end
    save(['../out/int/gate_data/downstream_smb_correction_' num2str(migration_distance(i)) 'm.mat'],'gate_smb');
end

