function compile_ice_velocity(migration_distance)

% add paths to libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
end

%% Load flux gate

load('../out/pub/gates/flux_gates_migrated.mat');
migration_distances = 0:200:3000; % metres
migration_pixels = find(migration_distances == migration_distance); % metres
gate_x = gate_x_migrate{migration_pixels};
gate_y = gate_y_migrate{migration_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrate


%% Load velocity 

% MEaSUREs annual data, 1x1 km
%   - get measures coordinates
filename = ['Antarctica_ice_velocity_2000_2001_1km_v01.1.nc'];
xM = ncread(filename,'x');
yM = ncread(filename,'y');
%   - pre-allocate output
vxM = zeros([length(gate_x),length([2000,2005:2019])]).*NaN;
vyM = zeros([length(gate_x),length([2000,2005:2019])]).*NaN;
vxM_err = zeros([length(gate_x),length([2000,2005:2019])]).*NaN;
vyM_err = zeros([length(gate_x),length([2000,2005:2019])]).*NaN;
timeM = datenum([2000,2005:2019],12,30); % annual products are averaged between July 1st and June 30th each year. Dec 30th is mid-date in non-leap year
sourceM = ones([length([2000,2005:2019]),1]);
counter = 1;
% loop through annual products and extract
for i = [2000,2005:2019] % these are available up to 2020 now, but we have higher resolution options after 2015 
    if i == 2000 || i >= 2017
        filename = ['Antarctica_ice_velocity_' num2str(i) '_' num2str(i+1) '_1km_v01.1.nc'];
    else
        filename = ['Antarctica_ice_velocity_' num2str(i) '_' num2str(i+1) '_1km_v01.nc'];
    end
    % vx
    data = double(flipud(rot90(ncread(filename,'VX'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vxM(:,counter) = data;
    % vy
    data = double(flipud(rot90(ncread(filename,'VY'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vyM(:,counter) = data;
    % vx error
    data = double(flipud(rot90(ncread(filename,'ERRX'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vxM_err(:,counter) = data;
    % vy error
    data = double(flipud(rot90(ncread(filename,'ERRY')))); 
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vyM_err(:,counter) = data;
    % increment counter
    counter=counter+1;
end

% ENVEO monthly data
%   - get filelist
if ispc
    nc_list = dir('D:/work/Fellowship_Leeds/Data/Velocity/Antarctica/ENVEO/monthly/*.nc');
else
    nc_list = dir('/resstore/b0133/Data/Velocity/ENVEO/monthly/*.nc');
end
%   - Get mid-date of all netcdf files
timeS1 = zeros([numel(nc_list),1]).*NaN;
for i = 1:numel(nc_list)
    nc_file = nc_list(i).name;
    Y = str2double(nc_file(1:4));
    M = str2double(nc_file(5:6));
    D = str2double(nc_file(7:8));
    timeS1(i) = datenum(Y,M,D) + (datenum(Y,M+1,D)-datenum(Y,M,D))/2;
end
%   - Load coordinates and get index of gate locations
xS1 = ncread([nc_list(i).folder '/' nc_list(i).name],'x');
yS1 = ncread([nc_list(i).folder '/' nc_list(i).name],'y');
%   - pre-allocate output
vxS1 = zeros([length(gate_x),numel(nc_list)]).*NaN;
vyS1 = zeros([length(gate_x),numel(nc_list)]).*NaN;
vxS1_err = zeros([length(gate_x),numel(nc_list)]).*NaN;
vyS1_err = zeros([length(gate_x),numel(nc_list)]).*NaN;
sourceS1 = ones([numel(nc_list),1]).*2;
%   - Loop through nc files and load data at gate locations
for i = 1:numel(nc_list)
    % Vx
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_easting_velocity'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vxS1(:,i) = data;
    % Vy
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_northing_velocity'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vyS1(:,i) = data;
    % Vx error
    data = double(rot90(flipud(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_easting_stddev'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vxS1_err(:,i) = data;
    % Vy error
    data = double(rot90(flipud(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_northing_stddev'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vyS1_err(:,i) = data;
end

% Merged 1996 data
%   - load
load('ASE_1996/ASE_1996_merged.mat')
%   - extract at gate
vxERS = interp2(x_1996,y_1996,vx_1996,gate_x,gate_y,'linear');
vyERS = interp2(x_1996,y_1996,vy_1996,gate_x,gate_y,'linear');
timeERS = datenum(1996,1,1) + 365/2;
vxERS_err = abs(vxERS).*0.1; % assume 10% velocity error
vyERS_err = abs(vyERS).*0.1; % assume 10% velocity error
sourceERS = 3;

% ITSLIVE annual velocity
%   - get filelist
if ispc
    nc_list1 = dir('D:\work\Fellowship_Leeds\Data\Velocity\Antarctica\ITSLIVE/*_19*.nc');
    nc_list2 = dir('D:\work\Fellowship_Leeds\Data\Velocity\Antarctica\ITSLIVE/*_20*.nc');
    nc_list = [nc_list1;nc_list2];
else
    nc_list1 = dir('/resstore/b0133/Data/Velocity/ITSLIVE/*_19*.nc');
    nc_list2 = dir('/resstore/b0133/Data/Velocity/ITSLIVE/*_20*.nc');
    nc_list = [nc_list1;nc_list2];
    clear nc_list1 nc_list2
end
%   - Get mid-date of all netcdf files
timeI = zeros([numel(nc_list),1]).*NaN;
for i = 1:numel(nc_list)
    nc_file = nc_list(i).name;
    Y = str2double(nc_file(11:14));
    timeI(i) = datenum(Y,1,1) + (datenum(Y,12,31)-datenum(Y,1,1))/2;
end
%   - Load coordinates and get index of gate locations
xI = ncread([nc_list(i).folder '/' nc_list(i).name],'x');
yI = ncread([nc_list(i).folder '/' nc_list(i).name],'y');
%   - pre-allocate output
vxI = zeros([length(gate_x),length(timeI)]).*NaN;
vyI = zeros([length(gate_x),length(timeI)]).*NaN;
vxI_err = zeros([length(gate_x),length(timeI)]).*NaN;
vyI_err = zeros([length(gate_x),length(timeI)]).*NaN;
%   - Loop through nc files and load data at gate locations
sourceI = ones([length(timeI),1]).*4;
for i = 1:numel(nc_list)
    % Vx
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vx'))));
    data(abs(data(:))>20000) = NaN;
    vxI(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vy
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vy'))));
    data(abs(data(:))>20000) = NaN;
    vyI(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vx error
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vx_err'))));
    data(abs(data)>20000) = NaN;
    vxI_err(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vy error
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vy_err'))));
    data(abs(data)>20000) = NaN;
    vyI_err(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
end

% MEaSUREs 1995-2001 mosaic
%   - info
filename = 'antarctica_ice_velocity_1995-2001_450m_v01.0.nc';
timeM95 = datenum(1995,7,1) + (datenum(2001,6,30)-datenum(1995,7,1))/2;
xM95 = ncread(filename,'x');
yM95 = ncread(filename,'y');
%   - vx
data = ncread(filename,'VX');
data = flipud(double(rot90(data)));
vxM95 = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
%   - vy
data = ncread(filename,'VY');
data = flipud(double(rot90(data)));
vyM95 = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
% vx err
data = ncread(filename,'ERRX');
data = flipud(double(rot90(data)));
vxM95_err = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
% vy err
data = ncread(filename,'ERRY');
data = flipud(double(rot90(data)));
vyM95_err = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
sourceM95 = 5;

% MEaSUREs 2007-2009 mosaic
%   - info
filename = 'antarctica_ice_velocity_2007-2009_450m_v01.0.nc';
timeM08 = datenum(2007,7,1) + (datenum(2009,6,30)-datenum(2007,7,1))/2;
xM08 = ncread(filename,'x');
yM08 = ncread(filename,'y');
%   - vx
data = ncread(filename,'VX');
data = flipud(double(rot90(data)));
vxM08 = interp2(xM08,yM08,data,gate_x,gate_y,'linear');
%   - vy
data = ncread(filename,'VY');
data = flipud(double(rot90(data)));
vyM08 = interp2(xM08,yM08,data,gate_x,gate_y,'linear');
% vx err
data = ncread(filename,'ERRX');
data = flipud(double(rot90(data)));
vxM08_err = interp2(xM08,yM08,data,gate_x,gate_y,'linear');
% vy err
data = ncread(filename,'ERRY');
data = flipud(double(rot90(data)));
vyM08_err = interp2(xM08,yM08,data,gate_x,gate_y,'linear');
sourceM08 = 5;


% MEaSUREs 2014-2017 mosaic
%   - info
filename = 'antarctica_ice_velocity_2014-2017_450m_v01.0.nc';
timeM15 = datenum(2014,7,1) + (datenum(2017,6,30)-datenum(2014,7,1))/2;
xM15 = ncread(filename,'x');
yM15 = ncread(filename,'y');
%   - vx
data = ncread(filename,'VX');
data = flipud(double(rot90(data)));
vxM15 = interp2(xM15,yM15,data,gate_x,gate_y,'linear');
%   - vy
data = ncread(filename,'VY');
data = flipud(double(rot90(data)));
vyM15 = interp2(xM15,yM15,data,gate_x,gate_y,'linear');
% vx err
data = ncread(filename,'ERRX');
data = flipud(double(rot90(data)));
vxM15_err = interp2(xM15,yM15,data,gate_x,gate_y,'linear');
% vy err
data = ncread(filename,'ERRY');
data = flipud(double(rot90(data)));
vyM15_err = interp2(xM15,yM15,data,gate_x,gate_y,'linear');
sourceM15 = 5;


% SID ice velocity
disp('Processing SID');
load(['../out/int/gate_data/reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_fd');
SID_list = dir('/resstore/b0133/SID/Antarctica/IV/S1/output/mosaic/monthly_corrected/**/vx_corrected.tif');
% Get times
SID_dates = zeros([numel(SID_list),2]).*NaN;
for i = 1:numel(SID_list)
    d = extractAfter(SID_list(i).folder,'monthly_corrected/');
    SID_dates(i,:) = [datenum(d(1:8),'yyyymmdd') , datenum(d(10:17),'yyyymmdd')];
end
timeSID = nanmean(SID_dates,2);
% Get image coordinates
[~,xSID,ySID] = geoimread([SID_list(1).folder '/vx_corrected.tif']);
% Pre-allocate output
vxSID = zeros([length(gate_x),numel(SID_list)]).*NaN;
vySID = zeros([length(gate_x),numel(SID_list)]).*NaN;
vxSID_err = zeros([length(gate_x),numel(SID_list)]).*NaN;
vySID_err = zeros([length(gate_x),numel(SID_list)]).*NaN;
sourceSID = ones([numel(SID_list),1]).*6;
% Loop through new files and extract at gate
for i = 1:numel(SID_list)
    disp(['Processing month ' num2str(i) ' of ' num2str(numel(SID_list)) ]);
    % vx
    data = double(geoimread([SID_list(i).folder '/vx_corrected.tif']));
    vxSID(:,i) = interp2(xSID,ySID,data,gate_x,gate_y,'linear');
    % vy
    data = double(geoimread([SID_list(i).folder '/vy_corrected.tif']));
    vySID(:,i) = interp2(xSID,ySID,data,gate_x,gate_y,'linear');
    % error
    data = double(geoimread(['/resstore/b0133/SID/Antarctica/IV/S1/output/mosaic/monthly/' datestr(SID_dates(i,1),'yyyymmdd') '_' datestr(SID_dates(i,2),'yyyymmdd') '/err_clean.tif']));
    sp_err = interp2(xSID,ySID,data,gate_x,gate_y,'linear');
    [tmp_vx,tmp_vy] = compass2cart(gate_fd(isfinite(sp_err)),sp_err(isfinite(sp_err)));
    [tmp_vx,tmp_vy] = uv2vxvy(gate_x(isfinite(sp_err)),gate_y(isfinite(sp_err)),tmp_vx,tmp_vy);
    vxSID_err(isfinite(sp_err),i) = abs(tmp_vx);
    vySID_err(isfinite(sp_err),i) = abs(tmp_vy);
end
clear tmp_vx tmp_vy sp_err data xSID ySID


% ITSLIVE ASE simulated velocity
%   - get filelist
Isim_list = dir('/resstore/b0133/Data/Velocity/ITSLIVE_ASE_sim/*.vx.tif');
%   - Get mid-date of all netcdf files
timeIsim = zeros([numel(Isim_list),1]).*NaN;
for i = 1:numel(Isim_list)
    sim_file = Isim_list(i).name;
    Y = str2double(sim_file(9:12));
    timeIsim(i) = datenum(Y,1,1) + (datenum(Y,12,31)-datenum(Y,1,1))/2;
end
%   - Load coordinates and get index of gate locations
[~,x_sim,y_sim] = geoimread([Isim_list(1).folder '/' Isim_list(1).name]);
[X_sim,Y_sim] = meshgrid(x_sim,y_sim);
%   - pre-allocate output
vxIsim = zeros([length(gate_x),length(timeI)]).*NaN;
vyIsim = zeros([length(gate_x),length(timeI)]).*NaN;
%   - Loop through nc files and load data at gate locations
sourceIsim = ones([length(timeI),1]).*8;
for i = 1:numel(nc_list)
    % Vx
    data = double(geoimread([Isim_list(i).folder '/' Isim_list(i).name]));
    vxIsim(:,i) = interp2(X_sim,Y_sim,data,gate_x,gate_y,'linear');
    % Vy
    n = extractBefore(Isim_list(i).name,'vx');
    n = [n 'vy.tif'];
    data = double(geoimread([Isim_list(i).folder '/' n]));
    vyIsim(:,i) = interp2(X_sim,Y_sim,data,gate_x,gate_y,'linear');
end
vxIsim_err = abs(vxIsim).*0.1;
vyIsim_err = abs(vyIsim).*0.1;


%% Concatenate velocity measurements

% concatenate
vx_raw = [vxM, vxS1, vxI, vxERS, vxM95, vxM08, vxM15, vxSID, vxIsim];
vy_raw = [vyM, vyS1, vyI, vyERS, vyM95, vyM08, vyM15, vySID, vyIsim];
vxE_raw = [vxM_err, vxS1_err, vxI_err, vxERS_err, vxM95_err, vxM08_err, vxM15_err, vxSID_err, vxIsim_err];
vyE_raw = [vyM_err, vyS1_err, vyI_err, vyERS_err, vyM95_err, vyM08_err, vyM15_err, vySID_err, vyIsim_err];
time_vel = [timeM(:)', timeS1(:)', timeI(:)', timeERS, timeM95, timeM08, timeM15, timeSID(:)', timeIsim(:)'];
source_vel = [sourceM(:)', sourceS1(:)', sourceI(:)', sourceERS, sourceM95, sourceM08, sourceM15, sourceSID(:)', sourceIsim(:)'];

% Sort
[~,iv] = sort(time_vel,'ascend');
time_vel = time_vel(iv);
vx_raw = vx_raw(:,iv);
vy_raw = vy_raw(:,iv);
vxE_raw = vxE_raw(:,iv);
vyE_raw = vyE_raw(:,iv);
source_vel = source_vel(iv);



%% Save raw velocity timeseries

save(['../out/int/gate_data/gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm_compiled.mat'],'vx_raw','vy_raw','vxE_raw','vyE_raw','source_vel','time_vel');

