function extract_reference_vel_thickness_bed(migrated_pixels)

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
	addpath(genpath('../'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
    addpath(genpath('/resstore/b0133/Data/DEMs'));
	addpath(genpath('../'));
end  

%% Load flux gate

load('../out/pub/gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrated

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Velocity and flow direction

load('../out/pub/reference_grids/reference_velocity_200m.mat','vx','vy');
load('../out/pub/reference_grids/reference_thickness_200m.mat','x','y');
[X,Y] = meshgrid(x,y);

fd = zeros(size(vx)).*NaN; % pre-allocate array
isf = isfinite(vx); % get indices of finite values
[vx,vy] = vxvy2uv(X,Y,vx,vy); % convert vx and vy to u and v
tmp = cart2compass(vx(isf),vy(isf)); % calculate flow direction for finite pixels
fd(isf) = tmp; % insert into to 2D grid
[vx,vy] = uv2vxvy(X,Y,vx,vy); % convert u and v back to vx and vy
clear tmp isf

% interpolate flow direction to gate locations
gate_fd = interp2(X,Y,fd,gate_x,gate_y);
clear fd

% interpolate velocity to gate locations
gate_vx = interp2(X,Y,vx,gate_x,gate_y);
gate_vy = interp2(X,Y,vy,gate_x,gate_y);

% also get angle of flux gate
gate_theta = zeros(size(gate_x)).*NaN;
s = regionprops(~isnan(gate_x),gate_x,'PixelIdxList');
for i = 1:numel(s)
    sect_x = gate_x(s(i).PixelIdxList);
    sect_y = gate_y(s(i).PixelIdxList);
    [sect_lat,sect_lon] = ps2ll(sect_x,sect_y);
    d = pathdistps(sect_lat(:),sect_lon(:)); 
    dx = gradient(d); 
    fx = gradient(sect_x(:),d); 
    fy = gradient(sect_y(:),d);
    gate_theta(s(i).PixelIdxList) = atan2(fy,fx);
end

% Cross-gate velocity
gate_ctv = abs(gate_vx.*sin(gate_theta) - gate_vy.*cos(gate_theta));
clear theta vx vy

% vx/vy error
load('../out/pub/reference_grids/reference_velocity_200m.mat','vx_err','vy_err');
gate_vx_err = interp2(X,Y,vx_err,gate_x,gate_y);
gate_vy_err = interp2(X,Y,vy_err,gate_x,gate_y);
gate_ctv_err = abs(gate_vx_err.*sin(gate_theta) - gate_vy_err.*cos(gate_theta));
clear vx_err vy_err

% Also get vx/vy directly from measures IPY velocities - in the end I
% didn't use this, but it helped me do some tests early on
[gate_vxM,gate_vyM] = measures_interp('velocity',gate_x,gate_y);
gate_vxM_err = (measures_interp('error',gate_x,gate_y))./2;
gate_vyM_err = gate_vxM_err;
s = regionprops(~isnan(gate_x),gate_x,'PixelIdxList');
for i = 1:numel(s)
    vx = gate_vxM(s(i).PixelIdxList);
    vy = gate_vyM(s(i).PixelIdxList);
    vx = interp1gap(vx);
    vy = interp1gap(vy);
    vx = fillmissing(vx,'previous');
    vy = fillmissing(vy,'previous');
    vx = fillmissing(vx,'next');
    vy = fillmissing(vy,'next');
    gate_vxM(s(i).PixelIdxList) = vx;
    gate_vyM(s(i).PixelIdxList) = vy;
end
gate_vxM_err(isnan(gate_vxM_err)) = abs(gate_vxM(isnan(gate_vxM_err))).*0.1;
gate_vyM_err(isnan(gate_vyM_err)) = abs(gate_vyM(isnan(gate_vyM_err))).*0.1;
gate_ctvM = abs(gate_vxM.*sin(gate_theta) - gate_vyM.*cos(gate_theta));
gate_ctvM_err = abs(gate_vxM_err.*sin(gate_theta) - gate_vyM_err.*cos(gate_theta));

% %% Deformation - I attempted to remove 'too slow' ice using modelled ice
% deformation, but it didn't work super well
% 
% % load deformation at gate
% load(['deformation/gate_deformation_migrate_' num2str(migration_distance) 'm.mat']);
% 
% % calculate easting and northing deformation velocities
% gate_vxd = zeros(size(gate_vx)).*NaN;
% gate_vyd = zeros(size(gate_vy)).*NaN;
% isf = isfinite(Vd_gate) & isfinite(gate_fd);
% gate_sp = hypot(gate_vx,gate_vy);
% [gate_vxd(isf),gate_vyd(isf)] = compass2cart(gate_fd(isf),gate_sp(isf));
% [gate_vxd,gate_vyd] = uv2vxvy(gate_x,gate_y,gate_vxd,gate_vyd);
% 
% % calculate cross-gate deformation
% gate_ctvd = abs(gate_vxd.*sin(gate_theta) - gate_vyd.*cos(gate_theta));
% 
% % replace observed velocities with deformation velocities where observed
% % velocities are too slow
% too_slow = gate_ctv < gate_ctvd;
% orig_ctv = gate_ctv;
% orig_vx = gate_vx;
% orig_vy = gate_vy;
% gate_ctv(too_slow) = gate_ctvd(too_slow);
% gate_vx(too_slow) = gate_vxd(too_slow);
% gate_vy(too_slow) = gate_vyd(too_slow);
% gate_ctv_err(too_slow) = VdE_gate(too_slow);
% deformation_corrected = too_slow;
% gate_ctvd_err = VdE_gate;


%% Thickness

% merged bed (bedmachine, H+F, Cui), REMA surface
load('../out/pub/reference_grids/reference_thickness_200m.mat');
gate_H_raw = interp2(X,Y,H,gate_x,gate_y);
gate_H_raw_err = interp2(X,Y,H_err,gate_x,gate_y); % this already includes 1 m of surface error
clear H H_err

% Bedmachine
%gate_H_BM = bedmachine_interp('thickness',gate_x,gate_y); % now calculating from REMA surface and bed to be consistent
gate_H_BM_err = bedmachine_interp('errbed',gate_x,gate_y)+1; % plus 1 m for surface error

% Bedmap2
% gate_H_B2 = bedmap2_interp(gate_x,gate_y,'thickness'); % now calculating from REMA surface and bed to be consistent
gate_H_B2_err = bedmap2_interp(gate_x,gate_y,'beduncertainty')+1; % plus 1 m for surface error


%% Bed
% all given in metres relative to sea level as defined by the g104c geoid

% merged bed (bedmachine, H+F, Cui)
load('../out/pub/reference_grids/FrankenBed.mat');
[X,Y] = meshgrid(x,y);
gate_bed_raw = interp2(X,Y,bed,gate_x,gate_y);
clear bed
load('../out/pub/reference_grids/FrankenBed_error.mat');
gate_bed_raw_err = interp2(X,Y,bed_err,gate_x,gate_y);

% bedmachine bed
gate_bed_BM = wgs2gl04c(gate_x,gate_y,bedmachine_interp('bed',gate_x,gate_y,'datum','wgs84')); % bed elevation relative to WGS84 ellipsoid
gate_bed_BM_err = bedmachine_interp('errbed',gate_x,gate_y);

% Bedmap2
gate_bed_B2 = bedmap2_interp(gate_x,gate_y,'bed'); 
gate_bed_B2_err = bedmap2_interp(gate_x,gate_y,'beduncertainty'); 

%% Surface

gate_surf = gate_bed_raw + gate_H_raw; % essentially REMA surface

%% Get bedmachine and bedmap2 thickness from surface and bed

gate_H_BM = gate_surf - gate_bed_BM;
gate_H_B2 = gate_surf - gate_bed_B2;

%% Check for unrealistic thickness

gate_H_raw(gate_H_raw<0) = 0;
gate_H_BM(gate_H_BM<0) = 0;
gate_H_B2(gate_H_B2<0) = 0;

% check and set the errors
gate_H_raw_err(isinf(gate_H_raw_err) | gate_H_raw_err<=0 | gate_H_raw_err>1e3 | isnan(gate_H_raw_err)) = 30; % check for and reset unphysical errors;
gate_ctv_err(isinf(gate_ctv_err) | gate_ctv_err<0 | gate_ctv_err>1e3 | isnan(gate_ctv_err)) = abs(gate_ctv(isinf(gate_ctv_err) | gate_ctv_err<0 | gate_ctv_err>1e3 | isnan(gate_ctv_err))).*0.1; % check for and reset unphysical errors;

% set gate nans
gate_theta(gate_nan) = NaN;
gate_fd(gate_nan) = NaN;
gate_vx(gate_nan) = NaN;
gate_vy(gate_nan) = NaN;
gate_vx_err(gate_nan) = NaN;
gate_vy_err(gate_nan) = NaN;
gate_ctv(gate_nan) = NaN;
gate_ctv_err(gate_nan) = NaN;
gate_vxM(gate_nan) = NaN;
gate_vyM(gate_nan) = NaN;
gate_vxM_err(gate_nan) = NaN;
gate_vyM_err(gate_nan) = NaN;
gate_ctvM(gate_nan) = NaN;
gate_ctvM_err(gate_nan) = NaN;
gate_H_raw(gate_nan) = NaN;
gate_H_raw_err(gate_nan) = NaN;
gate_H_BM(gate_nan) = NaN;
gate_H_BM_err(gate_nan) = NaN;
gate_bed_raw(gate_nan) = NaN;
gate_bed_raw_err(gate_nan) = NaN;
gate_bed_BM(gate_nan) = NaN;
gate_bed_BM_err(gate_nan) = NaN;
gate_bed_B2(gate_nan) = NaN;
gate_bed_B2_err(gate_nan) = NaN;
gate_surf(gate_nan) = NaN;
save(['../out/int/gate_data/reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_theta','gate_fd','gate_surf',...
    'gate_vx','gate_vx_err','gate_vy','gate_vy_err','gate_ctv','gate_ctv_err',...
    'gate_vxM','gate_vyM','gate_vxM_err','gate_vyM_err','gate_ctvM','gate_ctvM_err',...
    'gate_H_raw','gate_H_raw_err','gate_bed_raw','gate_bed_raw_err',...
    'gate_H_BM','gate_H_BM_err','gate_bed_BM','gate_bed_BM_err',...
    'gate_H_B2','gate_H_B2_err','gate_bed_B2','gate_bed_B2_err');

% I saved all these when I was keeping deformation information
% save(['reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_theta','gate_fd','gate_surf',...
%     'gate_vx','gate_vx_err','gate_vy','gate_vy_err','gate_ctv','gate_ctv_err',...
%     'orig_ctv','orig_vx','orig_vy',...
%     'gate_vxM','gate_vyM','gate_vxM_err','gate_vyM_err','gate_ctvM','gate_ctvM_err',...
%     'gate_H_raw','gate_H_raw_err','gate_bed_raw','gate_bed_raw_err',...
%     'gate_H_BM','gate_H_BM_err','gate_bed_BM','gate_bed_BM_err',...
%     'gate_H_B2','gate_H_B2_err','gate_bed_B2','gate_bed_B2_err',...
%     'gate_vxd','gate_vyd','gate_ctvd','gate_ctvd_err',...
%     'deformation_corrected');


%%%%%%%
% Some other stuff I did trying to recreate the thickness adjustment in
% Mankoff et al. (2020) Greenland solid ice discharge. It 'worked', but the
% velocity-thickness distribution for Antarctica looks very different* to
% Greenland, so it didn't really make sense to use that approach here
%   *at least if you are including ice flowing slower than 100 m/yr, which
%   I think you should for Antarctica
% %% Plot the distribution and adjust reference thickness estimates
% % here, I have arbitraily picked 30 m ice as being too thin. Ice columns 
% % thinner than this are adjusted based on the surface speed.
% 
% % Find erroneous thickness estimates
% too_thin = gate_H_raw<30;
% 
% % only correct areas flowing relatively fast
% isf = isfinite(gate_ctv);
% fast = gate_ctv>=200;
% 
% % Plot the initial distribution
% figure('color','w','units','inches','position',[1 1 8 3]);
% % 'fast' ice
% subplot(1,3,1)
% binscatter((gate_ctv(isf & fast & ~too_thin)),(gate_H_raw(isf & fast & ~too_thin)));
% set(gca,'ColorScale','log');
% set(gca,'XScale','log');
% set(gca,'YScale','log');
% caxis([1 1000])
% colormap('parula')
% title('fast');
% xlabel('Velocity (m yr^{-1})');
% ylabel('Thickness (m)');
% axis square
% title('fast flowing (>200 m/yr)');
% 
% % adjust 'fast' ice
% X = log10(gate_ctv(isf & fast & ~too_thin));
% Y = log10(gate_H_raw(isf & fast & ~too_thin));
% R = corrcoef(X(:),Y(:));
% [rho,pval] = corr(X(:),Y(:));
% p = polyfit(X(:),Y(:),1);
% fitted_H = 10.^(polyval(p,log10(gate_ctv)));
% gate_H_adj = gate_H_raw;
% gate_H_adj(too_thin & fast) = fitted_H(too_thin & fast);
% 
% % plot the relationship between cross-track velocity and fitted thickness
% % for fast flowing ice
% subplot(1,3,2);
% binscatter(gate_ctv(isf & too_thin & fast),fitted_H(isf & too_thin & fast))
% title('CTV vs fitted H relationship');
% xlabel('Velocity (m yr^{-1})');
% ylabel('Thickness (m)');
% set(gca,'ColorScale','log');
% 
% % and plot the adjusted 'fast' data
% subplot(1,3,3)
% binscatter((gate_ctv(isf & fast)),(gate_H_adj(isf & fast)));
% set(gca,'ColorScale','log');
% set(gca,'XScale','log');
% set(gca,'YScale','log');
% caxis([1 1000])
% colormap('parula')
% title('adjusted fast flowing ice');
% xlabel('Velocity (m yr^{-1})');
% ylabel('Thickness (m)');
% axis square
% 
% % save the figure with the stage
% export_fig(['figures/thickness_adj/binscatter_reference_thickness_adjustment_stages_' num2str(migration_distance) 'm.png'],'-dpng','-r300');
% 
% % Plot the original and adjusted for full speed range
% figure('color','w','units','inches','position',[1 1 6 4]);
% % original thickness
% subplot(1,2,1)
% binscatter((gate_ctv(isf)),(gate_H_raw(isf)));
% set(gca,'ColorScale','log');
% set(gca,'XScale','log');
% set(gca,'YScale','log');
% caxis([1 1000])
% colormap('parula')
% title('original thickness, all speeds');
% xlabel('Velocity (m yr^{-1})');
% ylabel('Thickness (m)');
% axis square
% % adjusted
% subplot(1,2,2)
% binscatter((gate_ctv(isf)),(gate_H_adj(isf)));
% set(gca,'ColorScale','log');
% set(gca,'XScale','log');
% set(gca,'YScale','log');
% caxis([1 1000])
% colormap('parula')
% title('adjusted thickness, all speeds');
% xlabel('Velocity (m yr^{-1})');
% ylabel('Thickness (m)');
% axis square
% % save
% export_fig(['figures/thickness_adj/binscatter_reference_thickness_adjustment_raw_vs_adjusted_' num2str(migration_distance) 'm'],'-dpng','-r300');
% 
% 
% %% Save
% 
% % make sure there are no zeros in the new or original thickness 
% gate_H_raw(gate_H_raw<0) = 0;
% thin = gate_H_adj<0;
% gate_H_adj(thin) = gate_H_raw(thin); % set them back to the original thickness
% 
% % Check the adjustments
% adj = gate_H_adj ~= gate_H_raw;
% figure('color','w'); antbounds('coast','color','none'); hold on
% plot(gate_x,gate_y,'k');
% scatter(gate_x(adj),gate_y(adj),5,'r','filled');
% export_fig(['figures/thickness_adj/adjusted_locations_migrate_' num2str(migration_distance) 'm.png']);

% % check and set the errors
% gate_H_err(isinf(gate_H_err) | gate_H_err<=0 | gate_H_err>1e3 | isnan(gate_H_err)) = 30; % check for and reset unphysical errors;
% gate_H_adj_err = gate_H_err;
% gate_H_adj_err(adj) = gate_H_adj(adj).*0.5; % set error to 50% of the adjusted thickness where we have adjusted the thickness
% gate_H_adj_err(isinf(gate_H_adj_err) | gate_H_adj_err<=0 | gate_H_adj_err>1e3 | isnan(gate_H_adj_err)) = 30; % check for and reset unphysical errors;
% gate_ctv_err(isinf(gate_ctv_err) | gate_ctv_err<0 | gate_ctv_err>1e3 | isnan(gate_ctv_err)) = abs(gate_ctv(isinf(gate_ctv_err) | gate_ctv_err<0 | gate_ctv_err>1e3 | isnan(gate_ctv_err))).*0.1; % check for and reset unphysical errors;
% 
% % set some names etc
% gate_H_raw_err = gate_H_err;
% gate_bed_raw = gate_bed_raw; % merged bed
% gate_bed_raw_err = gate_bed_err;
% gate_bed_adj = gate_surf - gate_H_adj; % although we change the thickness not the bed, this might make it easier later when we incorporate a time-varying surface
% gate_bed_adj_err = gate_bed_raw_err;
% 
% % set gate nans
% gate_theta(gate_nan) = NaN;
% gate_fd(gate_nan) = NaN;
% gate_vx(gate_nan) = NaN;
% gate_vy(gate_nan) = NaN;
% gate_vx_err(gate_nan) = NaN;
% gate_vy_err(gate_nan) = NaN;
% gate_ctv(gate_nan) = NaN;
% gate_ctv_err(gate_nan) = NaN;
% gate_vxM(gate_nan) = NaN;
% gate_vyM(gate_nan) = NaN;
% gate_vxM_err(gate_nan) = NaN;
% gate_vyM_err(gate_nan) = NaN;
% gate_ctvM(gate_nan) = NaN;
% gate_ctvM_err(gate_nan) = NaN;
% gate_H_raw(gate_nan) = NaN;
% gate_H_raw_err(gate_nan) = NaN;
% gate_H_adj(gate_nan) = NaN;
% gate_H_adj_err(gate_nan) = NaN;
% gate_H_BM(gate_nan) = NaN;
% gate_H_BM_err(gate_nan) = NaN;
% gate_bed_raw(gate_nan) = NaN;
% gate_bed_raw_err(gate_nan) = NaN;
% gate_bed_adj(gate_nan) = NaN;
% gate_bed_adj_err(gate_nan) = NaN;
% gate_bed_BM(gate_nan) = NaN;
% gate_bed_BM_err(gate_nan) = NaN;
% gate_bed_B2(gate_nan) = NaN;
% gate_bed_B2_err(gate_nan) = NaN;
% gate_surf(gate_nan) = NaN;
% save(['reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_theta','gate_fd','gate_surf',...
%     'gate_vx','gate_vx_err','gate_vy','gate_vy_err','gate_ctv','gate_ctv_err',...
%     'gate_vxM','gate_vyM','gate_vxM_err','gate_vyM_err','gate_ctvM','gate_ctvM_err',...
%     'gate_H_raw','gate_H_raw_err','gate_bed_raw','gate_bed_raw_err',...
%     'gate_H_adj','gate_H_adj_err','gate_bed_adj','gate_bed_adj_err',...
%     'gate_H_BM','gate_H_BM_err','gate_bed_BM','gate_bed_BM_err',...
%     'gate_H_B2','gate_H_B2_err','gate_bed_B2','gate_bed_B2_err',...
%     'deformation_corrected');


