function extract_FAC_GEMB(migrated_pixels)

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/GEMB'));
end

%% Load flux gate

load('../out/pub/gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrated

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Load GEMB data

% Filename
filelist = dir('/resstore/b0133/Data/GEMB/*mesh.nc');

% Get coordinates
x = ncread([filelist(1).folder '/' filelist(1).name],'x');
y = ncread([filelist(1).folder '/' filelist(1).name],'y');
[X,Y] = meshgrid(x,y);
mask = ncread([filelist(1).folder '/' filelist(1).name],'icemask');

% Get time
t = [];
for i = 1:numel(filelist)
    t = [t ; ncread([filelist(i).folder '/' filelist(i).name],'t')];
    if i == 1
        zs = ncread([filelist(i).folder '/' filelist(i).name],'FAC');
    else
        tmp = ncread([filelist(i).folder '/' filelist(i).name],'FAC');
        zs = cat(1,zs,tmp);
    end
end
time = datenum(1992,1:length(t),15); 

%% Make long-term and monthly climatologies for gap filling and routine updates

% Make 30-year climatology
fac_clim_2D = squeeze(nanmean(zs,1)); 
if migrated_pixels == 1
	save('../out/int/reference_grids/fac_clim_2D_GEMB.mat','x','y','fac_clim_2D');
end

% Make monthly climatologies
dt_time = datetime(time,'convertFrom','datenum');
zs_monthly_clim_2D = zeros([size(zs,2),size(zs,3),12]).*NaN;
for i = 1:12
    idx = ismember(month(dt_time),i);
    tmp = squeeze(zs(idx,:,:)); % all jans, febs, marchs etc...
    zs_monthly_clim_2D(:,:,i) = squeeze(nanmean(tmp,1));
end
clear idx tmp

% Fill gaps in climatologies using regionfill
%   - constrain region fill by setting the edge values
fac_clim_2D([1,end],:) = 0;
fac_clim_2D(:,[1,end]) = 0;
fac_clim_2D = regionfill(fac_clim_2D,isnan(fac_clim_2D));
if migrated_pixels == 1
	save('../out/int/reference_grids/fac_clim_2D_GEMB_filled.mat','x','y','fac_clim_2D');
end
for i = 1:12
    tmp = (zs_monthly_clim_2D(:,:,i));
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    zs_monthly_clim_2D(:,:,i) = tmp;
end
clear tmp

% interpolate climatolgoical mean
fac_clim = interp2(X,Y,fac_clim_2D',gate_x,gate_y);
% pre-allocate monthly climatology for this gate
fac_monthly_clim = zeros([length(gate_x),12]).*NaN;
% loop through months
for j = 1:12
    tmp = (zs_monthly_clim_2D(:,:,j));
    fac_monthly_clim(:,j) = interp2(X,Y,tmp',gate_x,gate_y);
    fac_monthly_clim(gate_nan,j) = NaN;
end
clear tmp

% pre-allocate monthly timeseries for this gate
fac_monthly = zeros([length(gate_x),length(time)]).*NaN;
for j = 1:length(time)
    tmp = squeeze(zs(j,:,:));
    tmp = tmp';
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    fac_monthly(:,j) = interp2(X,Y,tmp,gate_x,gate_y);
    fac_monthly(gate_nan,j) = NaN;
end

% Save
fac_time = time;
save(['../out/int/gate_data/FAC_GEMB_migrate_' num2str(migration_distance) 'm.mat'],'fac_clim','fac_monthly_clim','fac_monthly','fac_time');

    


