function extract_FAC_GSFC(migrated_pixels)

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/GSFC'));
end

%% Load flux gate

load('../out/pub/gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrated

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Load RACMO data

% Filename
fn='gsfc_fdm_v1_2_1_ais_June22.nc';

% Time
time = datenum(double(ncread(fn,'time')),1,1); % every 5 days from 4th Jan 1980 to 26th June 2022

% Get grids
x = double(ncread(fn,'x'));
y = double(ncread(fn,'y'));

% Read gridded data
zs = ncread(fn,'FAC');

%% Make long-term and monthly climatologies for gap filling and routine updates

% Make 30-year climatology
idx = find(time>=datenum(1979,1,1) & time<=datenum(2009,1,1));
fac_clim_2D = nanmean(zs(:,:,idx),3); 

% Make monthly climatologies
dt_time = datetime(time(idx),'convertFrom','datenum');
zs_trim = zs(:,:,idx);
zs_monthly_clim_2D = zeros([size(zs,1),size(zs,2),12]).*NaN;
for i = 1:12
    idx = ismember(month(dt_time),i);
    tmp = zs_trim(:,:,idx); % all jans, febs, marchs etc...
    zs_monthly_clim_2D(:,:,i) = nanmean(tmp,3);
end
clear zs_trim idx tmp

% Fill gaps in climatologies using regionfill
%   - constrain region fill by setting the edge values
fac_clim_2D([1,end],:) = 0;
fac_clim_2D(:,[1,end]) = 0;
fac_clim_2D = regionfill(fac_clim_2D,isnan(fac_clim_2D));
for i = 1:12
    tmp = zs_monthly_clim_2D(:,:,i);
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    zs_monthly_clim_2D(:,:,i) = tmp;
end
clear tmp

% Convert daily FAC to monthly
dt_time = datetime(time,'convertFrom','datenum');
TT = timetable(dt_time(:),cube2rect(zs));
TT = retime(TT,'monthly','mean');
zs = rect2cube(TT.Var1,size(zs));
mtime = datenum(TT.Time);
fac_time = mtime;

    
% climatological fac
% interpolate climatological mean
F = scatteredInterpolant(x(:),y(:),fac_clim_2D(:));
fac_clim = F(gate_x,gate_y);
fac_clim(gate_nan) = NaN;
% pre-allocate monthly climatology for this gate
fac_monthly_clim = zeros([length(gate_x),12]).*NaN;
% loop through months
for j = 1:12
    tmp = zs_monthly_clim_2D(:,:,j);
    F.Values = tmp(:);
    fac_monthly_clim(:,j) = F(gate_x,gate_y);
    fac_monthly_clim(gate_nan,j) = NaN;
end
clear tmp

% pre-allocate monthly timeseries for this gate
fac_monthly = zeros([length(gate_x),length(mtime)]).*NaN;
for j = 1:length(mtime)
    tmp = zs(:,:,j);
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    F.Values = tmp(:);
    fac_monthly(:,j) = F(gate_x,gate_y);
    fac_monthly(gate_nan,j) = NaN;
end

% Save
if migrated_pixels == 1
	save('../out/int/reference_grids/fac_clim_2D_GSFC.mat','fac_clim_2D','x','y');
end
save(['../out/int/gate_data/FAC_GSFC_migrate_' num2str(migration_distance) 'm.mat'],'fac_clim','fac_monthly_clim','fac_monthly','fac_time');
    


