% extract_dHdt_quadratic
% Code written by Benjamin Davison, but thickness change data and error
% definition produced by Thomas Slater
%

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%
%y = ax^2 + bx + c 
%to the altimetry time series in 5 x 5 km regions – please find attached a map of the acceleration term and two example time series at pixels on the grounding line of Pine Island and Thwaites Glaciers (which I think shows the value of reconstructing the height change in this way!).

%A couple of notes:
% -	When reconstructing the time series use e.g. x = [0:1/12:32] for t = 1991-2023

fn = '../out/pub/reference_grids/sec_quadratic_1992_2023.nc';
x = ncread(fn,'x');
y = ncread(fn,'y');
[X,Y] = meshgrid(x,y);
quad = flipud(rot90(ncread(fn,'sec_quadratic')));
lin = flipud(rot90(ncread(fn,'sec_linear')));
icept = flipud(rot90(ncread(fn,'sec_icept')));
quad_err = flipud(rot90(ncread(fn,'sec_quadratic_uncertainty')));
lin_err = flipud(rot90(ncread(fn,'sec_linear_uncertainty')));
icept_err = flipud(rot90(ncread(fn,'sec_icept_uncertainty')));
input_start_time = flipud(rot90(ncread(fn,'input_dh_start_time'))) + 1991; % year
input_end_time = flipud(rot90(ncread(fn,'input_dh_end_time'))) + 1991; % year
time_coverage = flipud(rot90(ncread(fn,'sec_time_coverage'))); % years
num_pts = flipud(rot90(ncread(fn,'num_pts_in_sec')));

% Expand to edges to avoid any NaNs
quad([1,end],:) = 0;
quad(:,[1,end]) = 0;
lin([1,end],:) = 0;
lin(:,[1,end]) = 0;
icept([1,end],:) = 0;
icept(:,[1,end]) = 0;
quad_err([1,end],:) = 0;
quad_err(:,[1,end]) = 0;
lin_err([1,end],:) = 0;
lin_err(:,[1,end]) = 0;
icept_err([1,end],:) = 0;
icept_err(:,[1,end]) = 0;
filled = isnan(quad);
quad = regionfill(quad,isnan(quad));
lin = regionfill(lin,isnan(lin));
icept = regionfill(icept,isnan(icept));
quad_err = regionfill(quad_err,isnan(quad_err));
lin_err = regionfill(lin_err,isnan(lin_err));
icept_err = regionfill(icept_err,isnan(icept_err));
input_start_time(filled) = nanmin(input_start_time(:));
t = 1:1/12:32; % years from 1991
t_sampling_original = 140/365;
t_sampling_hires = 1/12;
dH_time = datenum(1991+t,1,15); % monthly from 1991
num_years = (dH_time(end)-dH_time(1))/365.25;

% A PIG test
% r = 439;
% c = 248;
% t = 1:1/12:32; % years from 1991
% dH_time = datenum(1991+t,1,15);
% y = quad(r,c)*t.^2 + lin(r,c).*t + icept(r,c);
% y_err = quad_err(r,c)*t.^2 + lin_err(r,c).*t + icept_err(r,c);

%% Extract dHdt at flux gate

% load flux gates
load('../out/pub/gates/flux_gates_migrated.mat');
migration_distance = 0:200:3000; % metres

% loop through flux gates
for i = 1:numel(gate_x_migrate)
    
    % Get gate
    gate_x = gate_x_migrate{i};
    gate_y = gate_y_migrate{i};
    gate_nan = isnan(gate_x);
    
    % Extract components at each gate pixel
    gate_quad = interp2(X,Y,quad,gate_x,gate_y);
    gate_lin = interp2(X,Y,lin,gate_x,gate_y);
    gate_icept = interp2(X,Y,icept,gate_x,gate_y);
    gate_quad_err = interp2(X,Y,quad_err,gate_x,gate_y);
    gate_lin_err = interp2(X,Y,lin_err,gate_x,gate_y);
    gate_icept_err = interp2(X,Y,icept_err,gate_x,gate_y);
    gate_start_time = interp2(X,Y,input_start_time,gate_x,gate_y,'nearest');
    gate_end_time = interp2(X,Y,input_end_time,gate_x,gate_y,'nearest');
    gate_time_coverage = interp2(X,Y,time_coverage,gate_x,gate_y,'nearest');
    gate_num_pts = interp2(X,Y,num_pts,gate_x,gate_y,'nearest');
    gate_filled = interp2(X,Y,single(filled),gate_x,gate_y,'nearest');
    
    % Calculate dH timeseries: PIG test point: 194850
    gate_dH = (gate_quad.*t.^2) + (gate_lin.*t) + gate_icept;
    gate_dH_upper = ((gate_quad+gate_quad_err).*t.^2) + ((gate_lin+gate_lin_err).*t) + (gate_icept+gate_icept_err);
    gate_dH_lower = ((gate_quad-gate_quad_err).*t.^2) + ((gate_lin-gate_lin_err).*t) + (gate_icept-gate_icept_err);
    gate_dH_err = (t_sampling_hires  / t_sampling_original) .* (((gate_dH_upper - gate_dH) + (gate_dH - gate_dH_lower)) ./ 2);
    
    % Set reference time to May 9th 2015 (time of reference thickness)
    [~,idx] = findNearest(dH_time, datenum(2015,5,9));
    gate_dH = gate_dH - gate_dH(:,idx);
    
    % Keep static (reference) thickness south of 81.5
    gate_dH(gate_start_time>=2010) = 0;
    gate_dH_err(gate_start_time>=2010) = 0;
    
    % Set nans
    gate_quad(gate_nan,:) = NaN;
    gate_lin(gate_nan,:) = NaN;
    gate_icept(gate_nan,:) = NaN;
    gate_quad_err(gate_nan,:) = NaN;
    gate_lin_err(gate_nan,:) = NaN;
    gate_icept_err(gate_nan,:) = NaN;
    gate_start_time(gate_nan,:) = NaN;
    gate_end_time(gate_nan,:) = NaN;
    gate_time_coverage(gate_nan,:) = NaN;
    gate_num_pts(gate_nan,:) = NaN;
    gate_filled(gate_nan,:) = NaN;
    gate_dH(gate_nan,:) = NaN;
    gate_dH_err(gate_nan,:) = NaN;
    
    % Save this gate
    save(['../out/int/gate_data/gate_quadratic_dH_ts_' num2str(migration_distance(i)) 'm.mat'],...
        'gate_quad','gate_lin','gate_icept','gate_quad_err','gate_lin_err','gate_icept_err',...
        'gate_start_time','gate_end_time','gate_time_coverage','gate_num_pts','gate_filled',...
        'gate_dH','gate_dH_err');
    
    % Save to cell arrays so we can load them all at once 
    gate_quad_all{i} = gate_quad;
    gate_lin_all{i} = gate_lin;
    gate_icept_all{i} = gate_icept;
    gate_quad_err_all{i} = gate_quad_err;
    gate_lin_err_all{i} = gate_lin_err;
    gate_icept_err_all{i} = gate_icept_err;
    gate_start_time_all{i} = gate_start_time;
    gate_end_time_all{i} = gate_end_time;
    gate_time_coverage_all{i} = gate_time_coverage;
    gate_num_pts_all{i} = gate_num_pts;
    gate_filled_all{i} = gate_filled;
    gate_dH_all{i} = gate_dH;
    gate_dH_err_all{i} = gate_dH_err;
    
end

% Save data for all gates
save('../out/int/gate_data/gate_quadratic_dH_ts_all_gates.mat',...
        'gate_quad_all','gate_lin_all','gate_icept_all',...
        'gate_quad_err_all','gate_lin_err_all','gate_icept_err_all',...
        'gate_start_time_all','gate_end_time_all','gate_time_coverage_all',...
        'gate_num_pts_all','gate_filled_all',...
        'gate_dH_all','gate_dH_err_all','-v7.3');
    
clear gate* migration_distance idx i 
    
    
%% Extract dH in each basin

disp(' ');
disp('Processing basins...')
    
load('../out/int/basins/all_basins.mat');

% % Set fit to zero south of 81.5 - don't do this here because we're
% interested in mass change
% quad(input_start_time>=2010) = 0;
% lin(input_start_time>=2010) = 0;
% icept(input_start_time>=2010) = 0;
% quad_err(input_start_time>=2010) = 0;
% lin_err(input_start_time>=2010) = 0;
% icept_err(input_start_time>=2010) = 0;

% Just get dH from 1997 to 2021 (overlap of discharge, RACMO and dHdt)
idx = find(dH_time>=datenum(1997,1,1) & dH_time<=datenum(2021,12,31));
num_years = (dH_time(idx(end))-dH_time(idx(1)))/365.25;
idx = idx([1,end]);

% pre-allocate
basin_dH = zeros([numel(basins.name),1]).*NaN;
basin_dH_err = zeros([numel(basins.name),1]).*NaN;
basin_dH_Gt = zeros([numel(basins.name),1]).*NaN;
basin_dH_err_Gt = zeros([numel(basins.name),1]).*NaN;

% set to double
X = double(X);
Y = double(Y);

% Loop through basins
for i = 1:numel(basins.name)
    in = inpoly2([X(:),Y(:)],[basins.x{i},basins.y{i}]);
    if sum(in)==0 || sum(isfinite(quad(in))) == 0
        d = sqrt((basins.centroid(i,1)-X(:)).^2 + (basins.centroid(i,2)-Y(:)).^2);
        d(isnan(quad(:))) = NaN;
        in = find(d(:) == nanmin(d(:)),1,'first');
    end
    basin_quad = quad(in(:));
    basin_lin = lin(in(:));
    basin_icept = icept(in(:));
    basin_quad_err = quad_err(in(:));
    basin_lin_err = lin_err(in(:));
    basin_icept_err = icept_err(in(:));
    tmp_dH = (basin_quad.*t(idx).^2) + (basin_lin.*t(idx)) + basin_icept;
    tmp_dH_upper = ((basin_quad+basin_quad_err).*t(idx).^2) + ((basin_lin+basin_lin_err).*t(idx)) + (basin_icept+basin_icept_err);
    tmp_dH_lower = ((basin_quad-basin_quad_err).*t(idx).^2) + ((basin_lin-basin_lin_err).*t(idx)) + (basin_icept-basin_icept_err);
    tmp_dH_err = (t_sampling_hires  / t_sampling_original) .* (((tmp_dH_upper - tmp_dH) + (tmp_dH - tmp_dH_lower)) ./ 2);
    tmp_dH = tmp_dH(:,end)-tmp_dH(:,1); % total thickness change in each basin pixel
    tmp_err = sqrt(tmp_dH_err(:,end).^2 + tmp_dH_err(:,1).^2); 
    basin_dH(i) = nanmean(tmp_dH(:)); % total thickness change across the whole basin
    basin_dH_err(i) = rssq(tmp_err); 
    basin_dH_Gt(i) = basin_dH(i).*basins.area(i)*1e-9; % mass loss due to thickness change
    basin_dH_err_Gt(i) = basin_dH_err(i).*basins.area(i)*1e-9;
end

% Plot the average dHdt in each imbie refined basin
basin_dH_Gtyr = basin_dH_Gt./num_years;
ind = find(basins.type_ID==2);
cpts = 25:-.1:-25;
cmap = cmocean('balance',length(cpts));
% fill basins
figure('color','w');
antbounds('coast','k'); hold on
axis off
antbounds('gl','k');
plot_basins('imbie refined','k'); 
plot_basins('imbie refined','polyshape','facecolor',[1 1 1]);
for i = 1:numel(ind)
    [~,color_ind] = findNearest(cpts,basin_dH_Gtyr(ind(i)));
    fill(basins.x{ind(i)}(1:end-1),basins.y{ind(i)}(1:end-1),cmap(color_ind,:),'edgecolor','none');
end
plot_basins('imbie refined','k'); 
cb = colorbar;
colormap(cmocean('-balance'));
cb.Ticks = 0:.25:1;
cb.TickLabels = linspace(-25,25,length(cb.Ticks));
ylabel(cb,'MB (Gt/yr)');
export_fig('../out/int/mass_balance/basin_dH_Gtyr.png','-dpng','-r300');

% Save
save('../out/pub/mass_balance/basin_quadratic_dH.mat','basin_dH','basin_dH_err','basin_dH_Gt','basin_dH_err_Gt');


    