% genFrankenBed

clear
close all
clc

%% Preliminaries

% addpaths to data and libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Bed

% Load BedMachine bed
[BM_bed,BM_x,BM_y] = bedmachine_data('bed','xy','datenum','wgs84'); % bedmachine bed elevation is relative to the EIGEN-EC4 geoid, so first convert that to WGS84
[BM_X,BM_Y] = meshgrid(BM_x,BM_y);
BM_bed = wgs2gl04c(BM_X,BM_Y,BM_bed); % Convert bed elevations to those relative to the g104c reference frame

% Replace with Princess Elizabeth Land Bed - https://essd.copernicus.org/articles/12/2765/2020/essd-12-2765-2020.html
%   - load
[new_bed,new_x,new_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/Cui_2020_PEL/Bed_elevation.tif'); % this is relative to the WGS84 datum
new_bed(abs(new_bed)>20000) = NaN;
[new_x,new_y] = meshgrid(new_x,new_y);
%   - Convert bed elevations to those relative to the g104c reference frame
new_bed = wgs2gl04c(new_x,new_y,new_bed);
%   - Interpolate PEL bed to BedMachine grid
new_bed = interp2(new_x,new_y,new_bed,BM_X,BM_Y);
%   - Reset BedMachine value to PEL and Huss values where appropriate
BM_bed(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% Replace with Huss Peninsula data - https://tc.copernicus.org/articles/8/1261/2014/
%   - load the 100 m REMA surface DEM
[REMA_dem,REMA_x,REMA_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/REMA/REMA_100m_peninsula_dem_filled.tif'); 
REMA_dem(REMA_dem==-9999)=NaN;
[REMA_x,REMA_y] = meshgrid(REMA_x,REMA_y);
REMA_dem = wgs2gl04c(REMA_x,REMA_y,REMA_dem); % convert to elevations above the g104c geoid
%   - load H&F thickness
[new_bed,new_x,new_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/Huss_2013_Peninsula/SOM/thickness/thickness.tif');
new_bed = double(new_bed);
new_bed(new_bed==-9999) = NaN;
new_bed(new_bed==0) = NaN;
[new_x,new_y] = meshgrid(new_x,new_y);
%   - interpolate REMA surface to H&F grid
REMA_dem = interp2(REMA_x,REMA_y,REMA_dem,new_x,new_y);
%   - calculate bed elevation relative to g104c geoid
new_bed = REMA_dem - new_bed;
%   - interpolate Huss bed to BedMachine grid
new_bed = interp2(new_x,new_y,new_bed,BM_X,BM_Y);
%   - Overwrite BedMachine value to H&F values where appropriate
BM_bed(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% clear variables to save space
clear new_bed new_x new_y REMA_dem REMA_x REMA_y

%% Save
bed = BM_bed;
x = BM_x;
y = BM_y;
geoid = 'g104c';
save('../out/pub/reference_grids/FrankenBed.mat','bed','x','y','geoid');

% Also save as geotiff
xlimits = [min(x(:)) max(x(:))]; 
ylimits = [min(y(:)) max(y(:))]; 
raster_size = size(bed); 
R = maprefcells(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); % https://uk.mathworks.com/help/map/ref/maprefpostings.html
tiffTags = struct('Compression',Tiff.Compression.LZW);
geotiffwrite('../out/pub/reference_grids/FrankenBed.tif',bed,R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);

%% Repeat with error

% Load BedMachine bed
[BM_bed_err,BM_x,BM_y] = bedmachine_data('errbed','xy');
[BM_X,BM_Y] = meshgrid(BM_x,BM_y);

% Replace with Huss Peninsula data
%   - load
[new_bed,new_x,new_y] = geoimread('D:/work/Fellowship_Leeds/Data/Elevation/Antarctica/Huss_2013_Peninsula/SOM/uncertainty/uncertainty.tif');
new_bed = double(new_bed);
new_bed(new_bed==-9999) = NaN;
[new_x,new_y] = meshgrid(new_x,new_y);
%   - interpolate Huss bed to BedMachine grid
new_bed = interp2(new_x,new_y,new_bed,BM_X,BM_Y);
%   - Reset BedMachine value to PEL and Huss values where appropriate
BM_bed_err(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% clear variables to save space
clear new_bed new_X new_Y new_x new_y

bed_err = BM_bed_err;
x = BM_x;
y = BM_y;
save('../out/pub/reference_grids/FrankenBed_error.mat','bed_err','x','y');

% Also save as geotiff
xlimits = [min(x(:)) max(x(:))]; 
ylimits = [min(y(:)) max(y(:))]; 
raster_size = size(bed_err); 
R = maprefcells(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); % https://uk.mathworks.com/help/map/ref/maprefpostings.html
tiffTags = struct('Compression',Tiff.Compression.LZW);
geotiffwrite('../out/pub/reference_grids/FrankenBed_error.tif',bed_err,R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);




