% genRefVelocityThickness

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
    addpath(genpath('../'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
    addpath(genpath('/resstore/b0133/Data/ice_shelf_basal_melt_rates'));
	addpath(genpath('/resstore/b0133/Data/DEMs/Antarctica'));
    addpath(genpath('../'));
end

%{
% Start with ENVEO multi-year mosaic
%   - load raw data
[vx,x,y] = geoimread('antarctica_iv_200m_s1_all_v20210908_vxyz.tif');
err = geoimread('antarctica_iv_200m_s1_all_v20210908_std.tif');
sp = geoimread('antarctica_iv_200m_s1_all_v20210908_mag.tif');
[X,Y] = meshgrid(x,y);
%   - set nans
isn = abs(vx(:,:,1))>20000 | sp>20000;
vx(isn)=NaN;
err(isn)=NaN;
sp(isn)=NaN;
%   - convert to m/yr
vx=vx.*365.25;
err=err.*365.25;
sp=sp.*365.25;
%   - extract vel components
vy=vx(:,:,2);
vx=vx(:,:,1);
[vx,vy] = vxvy2uv(X,Y,vx,vy);
fd = zeros(size(vx)).*NaN;
fd(isfinite(vx)) = cart2compass(vx(isfinite(vx)),vy(isfinite(vy)));
vx_err = zeros(size(vx)).*NaN;
vy_err = zeros(size(vy)).*NaN;
[vx_err(isfinite(sp)),vy_err(isfinite(sp))] = compass2cart(fd(isfinite(sp)),err(isfinite(sp)));
[vx_err,vy_err] = uv2vxvy(X,Y,vx_err,vy_err);
vx_err = abs(vx_err);
vy_err = abs(vy_err);
[vx,vy] = uv2vxvy(X,Y,vx,vy);
clear isn sp fd

% fill gaps with multi-year mosaic
fn = 'antarctica_ice_velocity_450m_v2.nc';
vx_ref = flipud(rot90(ncread(fn,'VX')));
vy_ref = flipud(rot90(ncread(fn,'VY')));
vx_err_ref = flipud(rot90(ncread(fn,'ERRX')));
vy_err_ref = flipud(rot90(ncread(fn,'ERRY')));
x_ref = ncread(fn,'x');
y_ref = ncread(fn,'y');
[X_ref,Y_ref] = meshgrid(x_ref,y_ref);
vx_ref = interp2(X_ref,Y_ref,vx_ref,X,Y);
vy_ref = interp2(X_ref,Y_ref,vy_ref,X,Y);
vx_err_ref = interp2(X_ref,Y_ref,vx_err_ref,X,Y);
vy_err_ref = interp2(X_ref,Y_ref,vy_err_ref,X,Y);
% set 'ocean' from IPY data to NaN, because enveo isn't masked 
isn = isnan(vx_ref) | isnan(vy_ref);
vx(isn) = NaN;
vy(isn) = NaN;
vx_err(isn) = NaN;
vy_err(isn) = NaN;
% Set some edge and interior slow values to nan
isn = hypot(vx,vy) < hypot(vx_ref,vy_ref).*0.5  | hypot(vx,vy)+500 < hypot(vx_ref,vy_ref);
vx(isn) = NaN;
vy(isn) = NaN;
vx_err(isn) = NaN;
vy_err(isn) = NaN;
% fill gaps with IPY data
isn = isnan(vx) | isnan(vy);
vx(isn) = vx_ref(isn);
vy(isn) = vy_ref(isn);
vx_err(isn) = vx_err_ref(isn);
vy_err(isn) = vy_err_ref(isn);
clear *_ref fn isn

% Indices of missing data: 
indm = ~isfinite(vx) | ~isfinite(vy);% | ~isfinite(vx_err) | ~isfinite(vy_err); 
vx(indm) = nan; 
vy(indm) = nan; 
%vx_err(indm) = nan;
%vy_err(indm) = nan;
clear indm

vx = double(vx); 
vy = double(vy); 
vx_err = double(vx_err);
vy_err = double(vy_err);

% Fill any nan holes in the velocity field, but don't fill the ocean: 
L = bwlabel(isnan(vx)); % Label the nan regions again, and the ocean will be L=1.  
vx = regionfill(vx,L>1); 
vy = regionfill(vy,L>1);
vx_err = regionfill(vx_err,L>1);
vy_err = regionfill(vy_err,L>1);
clear L

% load('initial_vel.mat','X','Y','x','y','vx_err','vy_err','vx','vy');
isn = isnan(vx_err(:)) | isnan(vy_err(:));
vx_err(isn) = abs(vx(isn)).*0.1;
vy_err(isn) = abs(vy(isn)).*0.1;

% Save intermediate files here as a checkpoint in case we run out of memory
% and have to restart
save('../out/int/reference_grids/initial_vel.mat','vx','vy','vx_err','vy_err','X','Y','x','y','-v7.3');
clear vx_err vy_err
%}

load('../out/int/reference_grids/initial_vel.mat','vx','vy','x','y','X','Y');

%% Reference thickness

% Reference surface
disp('loading reference surface')
[surf,R] = readgeoraster('rema_mosaic_100m_v2.0_filled_cop30_dem.tif');
[surf_x,surf_y] = pixcenters(R,size(surf));
[surf_X,surf_Y] = meshgrid(surf_x,surf_y);
surf = wgs2gl04c(surf_X,surf_Y,surf); 
surf = interp2(surf_X,surf_Y,surf,X,Y);
clear surf_* R
figure('color','w'); imagescn(surf); export_fig('../out/int/reference_grids/surf.png','-dpng','-r300'); close

% Remove firn air content from surface
disp('applying firn correction');
load('../out/pub/reference_grids/fac_clim_2D.mat')
fac_clim_2D = griddata(fac_x(:),fac_y(:),fac_clim_2D(:),X,Y); % 1 km grid
figure('color','w'); imagescn(fac_clim_2D); export_fig('../out/int/reference_grids/FAC.png','-dpng','-r300'); close
surf = surf-fac_clim_2D;
surf(surf<=0) = NaN;
figure('color','w'); imagescn(surf); export_fig('../out/int/reference_grids/surf_postFAC.png','-dpng','-r300'); close
clear fac_clim_2D fac_x fac_y

% Reference bed
disp('loading reference bed')
b = load('../out/pub/reference_grids/FrankenBed.mat'); % already relative to the g104c geoid
load('../out/pub/reference_grids/FrankenBed_error.mat','bed_err');
[b.X,b.Y] = meshgrid(b.x,b.y);
bed = interp2(b.X,b.Y,b.bed,X,Y);
bed_err = interp2(b.X,b.Y,bed_err,X,Y);
figure('color','w'); imagescn(bed); export_fig('../out/int/reference_grids/bed.png','-dpng','-r300'); close
clear b

% Reference thickness
disp('calculating initial thickness, before extruding')
H = surf-bed;
clear surf bed
H_err = sqrt(bed_err.^2 + 1); % assume 1 m surface error
clear bed_err
H_err(H<=0) = NaN;
H(H<=0) = NaN;
figure('color','w'); imagescn(H); export_fig('../out/int/reference_grids/H.png','-dpng','-r300'); close

% Fill gaps in initial thickness
disp('filling initial thickness gaps');
save('../out/int/reference_grids/initial_H_before_filling.mat','H','H_err','-v7.3');
L = bwlabel(isnan(H)); % Label the nan regions, and the ocean will be L=1.  
figure('color','w'); imagescn(L); export_fig('../out/int/reference_grids/L.png','-dpng','-r300'); close
figure('color','w'); imagescn(L>1); export_fig('../out/int/reference_grids/L_GT1.png','-dpng','-r300'); close
H = regionfill(H,L>1); 
H_err = regionfill(H_err,L>1);
save('../out/int/reference_grids/initial_H.mat','H','H_err','-v7.3');
figure('color','w'); imagescn(H); export_fig('../out/int/reference_grids/H_after_filling.png','-dpng','-r300'); close


%% Extend velocity along flowlines

% downscale and inpaint, weighting towards thicker ice
sc = 1/4; % scale for resizing velocity (for flow *directions* only) 
[vx_r,x_r,y_r] = demresize(vx,x,y,sc); 
vy_r = imresize(vy,sc);
v = hypot(vx,vy);
H=double(H);
H_r = imresize(H,sc); 
% inpaint
Hvx_r = inpaint_nans(H_r.*vx_r,4); 
Hvy_r = inpaint_nans(H_r.*vy_r,4); 
Hv_r = hypot(Hvx_r,Hvy_r); 
% Displacement vectors will be used for the flow directions when extrapolating terminus speeds. 
disp('interpolating')
dx = interp2(x_r,y_r,Hvx_r./Hv_r,X,Y); 
dy = interp2(x_r,y_r,Hvy_r./Hv_r,X,Y); 
%clear Hv_r
%clear Hv_err_r
% plot
% figure
% imagescn(x_r,y_r,hypot(Hvx_r,Hvy_r))
% hold on
% bedmachine
% q = quiversc(x_r,y_r,Hvx_r,Hvy_r,'k','density',300); 
% q.AutoScaleFactor = 3;

% create streamlines
disp('calculating velocity')
% Use the perimeter of the velocity measurements as the seed locations: 
perim = bwperim(isfinite(v));
xseed = X(perim); 
yseed = Y(perim); 
[row,col] = find(perim); 
disp('creating streamlines')
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.4 5000]);
% Loop through each seed location to extrapolate terminus velocity and ice shelf name along flowlines:  
disp('extrapolating terminus velocities')
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
disp('concatenating cell arrays')
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
disp('getting seed locations and velocities')
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
% Remove NaNs: 
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
% Grid up the streamline data:  
disp('gridding data')
%clear XY m1 m2 v1 v2 v_err1 v_err2 M V V_err
vg = gridbin(xx,yy,vv,x,y); % gridbin is on my GitHub. It bins the average velocity observation in each grid cell. It's not as beautiful as gridfit, but it's the only way to deal with nearly a billion scattered data points.   
% Wherever gridbin gives us data, overwrite tmpvx, tmpvy, and tmpvs:  
disp('overwriting original data with extrapolated data')
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
% save
save('../out/int/reference_grids/vel_extrude_stage_1_fast.mat','vx','vy','vg','x_r','y_r','Hvx_r','Hvy_r','xseed','yseed','X','Y','v','perim','row','col','dx','dy','-v7.3');

% Repeat with denser grid
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.2 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
vg = gridbin(xx,yy,vv,x,y);
% Overwrite anythinng that was written by the previous coarse solution:
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
save('../out/int/reference_grids/vel_extrude_stage_2_fast.mat','vx','vy','-v7.3');

% and again
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.1 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% M = cell2nancat(XY);
% V = cell2nancat(V);
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
vg = gridbin(xx,yy,vv,x,y);
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
save('../out/int/reference_grids/vel_extrude_stage_3_fast.mat','vx','vy','-v7.3');


% and again
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.01 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% M = cell2nancat(XY);
% V = cell2nancat(V);
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
vg = gridbin(xx,yy,vv,x,y);
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
save('../out/int/reference_grids/vel_extrude_stage_4_fast.mat','vx','vy','-v7.3');


% and again
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.02 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
vg = gridbin(xx,yy,vv,x,y);
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
save('../out/int/reference_grids/vel_extrude_stage_5_fast.mat','vx','vy','-v7.3');


% and again
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.04 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k))*0+1; % dummy to make the rest easier
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
v2 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
    v2{i} = [V{i}(:,2);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = [vertcat(v1{:}),vertcat(v2{:})];
% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);
vg = gridbin(xx,yy,vv,x,y);
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 
save('../out/int/reference_grids/vel_extrude_stage_6_fast.mat','vx','vy','-v7.3');


% Fill holes in the velocity data: 
vx = regionfill(vx,isnan(vx)); 
vy = regionfill(vy,isnan(vy)); 
save('../out/int/reference_grids/vel_extrude_stage_7_fast.mat','vx','vy','-v7.3');
clear vg xx yy vv V M XY

% Assume vx error and vy error and 10% of speed where we have extrapolated
% (typically much greater than the published errors)
load('../out/int/reference_grids/initial_vel.mat','vx_err','vy_err');
isn = isnan(vx_err(:)) | isnan(vy_err(:));
vx_err(isn) = abs(vx(isn)).*0.1;
vy_err(isn) = abs(vy(isn)).*0.1;

% Save
save('../out/pub/reference_grids/reference_velocity_200m.mat','vx','vy','vx_err','vy_err','x','y','-v7.3')
xlimits = double([min(x(:)) max(x(:))]); 
ylimits = double([min(y(:)) max(y(:))]); 
raster_size = size(vx); 
R = maprefpostings(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); 
tiffTags = struct('Compression',Tiff.Compression.Deflate);
geotiffwrite('../out/pub/reference_grids/reference_vx.tif',single(vx),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);
geotiffwrite('../out/pub/reference_grids/reference_vy.tif',single(vy),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);
geotiffwrite('../out/pub/reference_grids/reference_vx_error.tif',single(vx_err),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);
geotiffwrite('../out/pub/reference_grids/reference_vy_error.tif',single(vy_err),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);


% Plot
figure
imagescn(x,y,hypot(vx,vy))
cmocean thermal
hgl = bedmachine('gl','color','k');
hold on
axis off
set(gca,'colorscale','log')
clim([1.5 4000])
export_fig('../out/int/reference_grids/reference_speed.png','-dpng','-r300');

%% Extrude thickness

% load velocity
load('initial_vel.mat','vx','vy','x','y'); % start with non-extrapolated speeds
sc = 1/4; % scale for resizing velocity (for flow *directions* only) 
[vx_r,x_r,y_r] = demresize(vx,x,y,sc); 
vy_r = imresize(vy,sc); 
clear vx vy
H=double(H);
Hf = filt2(H,1000,5e3,'lp'); 
H_r = imresize(H,sc); 
% inpaint
Hvx_r = inpaint_nans(H_r.*vx_r,4); 
Hvy_r = inpaint_nans(H_r.*vy_r,4); 
%  
% % round 1
% %load('initial_H.mat');
% %H=double(H);
disp('starting round 1')
perim = bwperim(imfill(H>=10,'holes'));
xseed = X(perim); 
yseed = Y(perim); 
[row,col] = find(perim); 
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.4 5000]);
V = XY; 
V_err = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
   V_err{k}(:,1) = Hf_err(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf);
H_err(isf) = hg_err(isf);
save('../out/int/reference_grids/H_extrude_stage1_fast.mat','H','hg','perim','X','Y','xseed','yseed','-v7.3');

% load('H_extrude_stage1_fast.mat');
% round 2
disp('starting round 2');
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.2 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf); 
save('../out/int/reference_grids/H_extrude_stage2_fast.mat','H','-v7.3');

% round 3
disp('starting round 3');
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.1 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf); 
save('../out/int/reference_grids/H_extrude_stage3_fast.mat','H','-v7.3');


% round 4
disp('starting round 4');
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.01 5000]);
V = XY; 
V_err = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf); 
save('../out/int/reference_grids/H_extrude_stage4_fast.mat','H','-v7.3');


% round 5
disp('starting round 5');
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.02 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf); 
save('../out/int/reference_grids/H_extrude_stage5_fast.mat','H','-v7.3');


% round 6
disp('starting round 6');
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.04 5000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end
% Concatenate the cells into nan-separated arrays: 
m1 = cell([numel(XY),1]);
m2 = cell([numel(XY),1]);
v1 = cell([numel(XY),1]);
for i = 1 : numel(XY)
    m1{i} = [XY{i}(:,1);NaN];
    m2{i} = [XY{i}(:,2);NaN];
    v1{i} = [V{i}(:,1);NaN];
end
M = [vertcat(m1{:}),vertcat(m2{:})];
V = vertcat(v1{:});
% M = cell2nancat(XY);
% V = cell2nancat(V);
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);
hg = gridbin(xx,yy,hh,x,y);
isf = isfinite(hg);
H(isf) = hg(isf); 
save('../out/int/reference_grids/H_extrude_stage6_fast.mat','H','-v7.3');
%load('H_extrude_stage6_fast.mat');

% finalise
H = regionfill(H,isnan(H)); 
H(H<=0) = 1; % don't allow negative thickness, in case that somehow happens during infilling
isn = isnan(H_err);
H_err(isn) = H(isn).*0.1;
isn = H_err<30 & isn==1;
H_err(isn) = 30;

%% Save

save('../out/pub/reference_grids/reference_thickness_200m.mat','H','H_err','x','y','-v7.3');
xlimits = double([min(x(:)) max(x(:))]); 
ylimits = double([min(y(:)) max(y(:))]); 
raster_size = size(vx); 
R = maprefpostings(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); 
tiffTags = struct('Compression',Tiff.Compression.Deflate);
geotiffwrite('../out/pub/reference_grids/reference_thickness.tif',single(H),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);
geotiffwrite('../out/pub/reference_grids/reference_thickness_error.tif',single(H_err),R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);

