% calc_corrections_impact

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;

% load data
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

%% Get corrections for Antarctica
ind = 1;
corrections.SMB = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','SMB_correction_all_gates'),3);
corrections.firn = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','FDM_firn_correction_all_gates'),3);
corrections.dH = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','dH_correction_all_gates'),3);
corrections.net = corrections.firn + corrections.SMB + corrections.dH;
AIS_SMB = corrections.SMB(ind,:);
AIS_firn = corrections.firn(ind,:);
AIS_dH = corrections.dH(ind,:);
AIS_net = corrections.net(ind,:);

% Net change
disp(['AIS net change in 1996: ' num2str(AIS_net(1)) ' Gt/yr']);
disp(['AIS net change in 2023: ' num2str(AIS_net(end)) ' Gt/yr']);
disp(' ')

% Firn change (IMAU FDM)
disp(['AIS firn change: ' num2str(nanmean(AIS_firn)) ' Gt/yr']);
disp(['with a stddev of: ' num2str(nanstd(AIS_firn)) ' Gt/yr']);
disp(' ')

% Surface elevation
disp(['surface elev changes cause an overall decrease in discharge of ' num2str(AIS_dH(end)-AIS_dH(1)) ' Gt/yr from 1996 to 2023']);
disp(' ');

% gate-to-grounding line SMB changes
disp(['AIS SMB change: ' num2str(nanmin(AIS_SMB)) ' to ' num2str(nanmax(AIS_SMB)) ' Gt/yr']);


%% Regional

% Firn change (IMAU FDM)
WAIS_firn = corrections.firn(2,:);
EAIS_firn = corrections.firn(3,:);
APN_firn = corrections.firn(4,:);

WAIS_firn_prop = WAIS_firn./nanmean(bQ(2,:)).*100;
EAIS_firn_prop = EAIS_firn./nanmean(bQ(3,:)).*100;
APN_firn_prop = APN_firn./nanmean(bQ(4,:)).*100;
disp(['WAIS firn change: ' num2str(nanmean(WAIS_firn)) ' Gt/yr or ' num2str(WAIS_firn_prop) ]);
disp(['EAIS firn change: ' num2str(nanmean(EAIS_firn)) ' Gt/yr or ' num2str(EAIS_firn_prop)]);
disp(['APN firn change: ' num2str(nanmean(APN_firn)) ' Gt/yr or ' num2str(APN_firn_prop)]);
disp(' ')


%% Biggest difference between IMAU FDM and GSFC-FDM

FDM_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates');
GSFC_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates_GSFC');
FDM_Q = nanmean(FDM_Q,3); % simple gate-average
GSFC_Q = nanmean(GSFC_Q,3); % simple gate-average
FDM_Q = nanmean(FDM_Q,2); % time-average
GSFC_Q = nanmean(GSFC_Q,2); % time-average
firn_diff = (FDM_Q-GSFC_Q)./FDM_Q.*100; % percent difference in each basin

disp(['Choice of firn model causes ' num2str(firn_diff(1)) ' % change in AIS discharge']);
disp(['Choice of firn model causes ' num2str(firn_diff(4)) ' % change in Peninsula discharge']);
idx = find(strcmp('Moser Glacier',basins.name)==1);
disp(['Choice of firn model causes ' num2str(firn_diff(idx)) ' % change in Moser Glacier discharge']);

% Sort
[~,iv] = sort(abs(firn_diff),'descend'); % sort with absolute, so we have large pos and neg differneces at the top of the list
firn_diff = firn_diff(iv);
names = basins.name(iv);
T = table(names,firn_diff,'VariableNames',{'Basin','Difference (%)'});








