% get_top_contributors

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

% basin info
basins = readBasinInfo;

% Load data
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
bQse = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% add negligible random noise to time to help with plotting
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);

% Sort based on discharge in S1 period
use = time>datenum(2016,1,1);
basin_idx = find(basins.type_ID == 2);
AIS_tot = nanmean(bQ(1,use),2); % Antarctic total, averaged from 2016
time = time(use);
bQ = bQ(basin_idx,use);
bQse = bQse(basin_idx,use);
names = basins.name(basin_idx);

% Get average and proportion
bQse = rssq(bQse,2);
bQ = nanmean(bQ,2);
err = 1.96.*bQse;
prop = bQ./AIS_tot.*100;

% Sort
[bQ,iv] = sort(bQ,'descend');
names = names(iv);
T = table(names,bQ,err,prop,'VariableNames',{'Basin','DischargeGtyr','ErrorGtyr','Proportion'});


%% PIG stats

% re-load full timeseries
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
bQse = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);
basins = readBasinInfo;
err = 1.96.*bQse;
idx = find(strcmp('Pine Island',basins.name)==1,1,'first');

% PIG  discharge
disp(['PIG discharge in 1996 was: ' num2str(bQ(idx,1)) ' +/- ' num2str(err(idx,1)) ' Gt/yr ']);
disp(['PIG discharge in ' datestr(time(end),'mmm yyyy') ' was: ' num2str(bQ(idx,end)) ' +/- ' num2str(err(idx,end)) ' Gt/yr ']);
disp(' ');






