% print_Antarctica_discharge

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../'));

%% Print

% load data
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
bQse = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
bQp = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_coverage');
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);
bQp(isnan(bQp)) = 0;

% add negligible random noise to time to help with plotting
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);

% Get regional discharge
AIS = bQ(1,:);
WAIS = bQ(2,:);
EAIS = bQ(3,:);
APN = bQ(4,:);

% And error
AISe = 1.96.*bQse(1,:);
WAISe = 1.96.*bQse(2,:);
EAISe = 1.96.*bQse(3,:);
APNe = 1.96.*bQse(4,:);


%% Antarctic wide

% AIS July 1996 discharge
disp(['Antarctic discharge in 1996 was: ' num2str(AIS(1)) ' +/- ' num2str(AISe(1)) ' Gt/yr ']);
disp(' ')

% AIS June 2023 discharge
disp(['Antarctic discharge in ' datestr(time(end),'mmm yyyy') ' was: ' num2str(AIS(end)) ' +/- ' num2str(AISe(end)) ' Gt/yr ']);
disp(' ');

% First 13 years compared to second 13 years
idx1 = find(time>datenum(2009,1,1),1,'first');
idx2 = find(time>datenum(2022,6,1),1,'first');
change1 = AIS(idx1)- AIS(1);
err1 = rssq([AISe(idx1),AISe(1)]);
change2 = AIS(idx2)-AIS(idx1);
err2 = rssq([AISe(idx1),AISe(idx2)]);
disp(['1996-2009: discharge increased by: ' num2str(change1) ' +/- ' num2str(err1) ' Gt/yr ']);
disp(['2009-2022: discharge increased by: ' num2str(change2) ' +/- ' num2str(err2) ' Gt/yr ']);
disp(' ')

% Trend
[p, ~, mu] = polyfit(time(:), AIS(:), 1);
fit_ts = polyval(p, time(:), [], mu);
AIS_tr = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
AIS_rtr = AIS_tr/nanmedian(fit_ts).*100;
[R_AIS, P_AIS] = corr(time(:), AIS(:), 'type', 'Pearson');
disp(['Overall, Antarctic discharge has a trend of ' num2str(AIS_tr) ' Gt/yr/yr, with a p-val of ' num2str(P_AIS) ]);
disp(['or ' num2str(AIS_rtr) ' % of avg per yr per yr' ]);
disp(' ')
disp(' ')

%% West Antarctica

% WAIS July 1996 discharge
disp(['West Antarctic discharge in 1996 was: ' num2str(WAIS(1)) ' +/- ' num2str(WAISe(1)) ' Gt/yr ']);
disp(' ')

% WAIS June 2023 discharge
disp(['West Antarctic discharge in ' datestr(time(end),'mmm yyyy') ' was: ' num2str(WAIS(end)) ' +/- ' num2str(WAISe(end)) ' Gt/yr ']);
disp(' ');

% Trend
[p, ~, mu] = polyfit(time(:), WAIS(:), 1);
fit_ts = polyval(p, time(:), [], mu);
WAIS_tr = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
WAIS_rtr = WAIS_tr/nanmedian(fit_ts).*100;
[R_WAIS, P_WAIS] = corr(time(:), WAIS(:), 'type', 'Pearson');
disp(['Overall, West Antarctic discharge has a trend of ' num2str(WAIS_tr) ' Gt/yr/yr, with a p-val of ' num2str(P_WAIS) ]);
disp(['or ' num2str(WAIS_rtr) ' % of avg per yr per yr' ]);
disp(' ')
disp(' ')

%% East Antarctica

% EAIS July 1996 discharge
disp(['East Antarctic discharge in 1996 was: ' num2str(EAIS(1)) ' +/- ' num2str(EAISe(1)) ' Gt/yr ']);
disp(' ')

% EAIS June 2023 discharge
disp(['East Antarctic discharge in ' datestr(time(end),'mmm yyyy') ' was: ' num2str(EAIS(end)) ' +/- ' num2str(EAISe(end)) ' Gt/yr ']);
disp(' ');

% Trend
[p, ~, mu] = polyfit(time(:), EAIS(:), 1);
fit_ts = polyval(p, time(:), [], mu);
EAIS_tr = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
EAIS_rtr = EAIS_tr/nanmedian(fit_ts).*100;
[R_EAIS, P_EAIS] = corr(time(:), EAIS(:), 'type', 'Pearson');
disp(['Overall, East Antarctic discharge has a trend of ' num2str(EAIS_tr) ' Gt/yr/yr, with a p-val of ' num2str(P_EAIS) ]);
disp(['or ' num2str(EAIS_rtr) ' % of avg per yr per yr' ]);
disp(' ')
disp(' ')


%% Peninsula

% APN July 1996 discharge
disp(['Peninsula discharge in 1996 was: ' num2str(APN(1)) ' +/- ' num2str(APNe(1)) ' Gt/yr ']);
disp(' ')

% APN June 2023 discharge
idx = find(time>=datenum(2023,4,1) & time<=datenum(2023,10,1));
disp(['Peninsula discharge in ' datestr(time(end),'mmm yyyy') ' was: ' num2str(nanmean(APN(idx))) ' +/- ' num2str(rssq(APNe(idx))) ' Gt/yr ']);
disp(' ');

% Trend
[p, ~, mu] = polyfit(time(:), APN(:), 1);
fit_ts = polyval(p, time(:), [], mu);
APN_tr = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
APN_rtr = APN_tr/nanmedian(fit_ts).*100;
[R_APN, P_APN] = corr(time(:), APN(:), 'type', 'Pearson');
disp(['Overall, Peninsula discharge has a trend of ' num2str(APN_tr) ' Gt/yr/yr, with a p-val of ' num2str(P_APN) ]);
disp(['or ' num2str(APN_rtr) ' % of avg per yr per yr' ]);
disp(' ')
disp(' ')

