function FrankenBedAdj_to_netcdf(gates,migration_distance,outfile,compression_factor)

% Get gate info
all_gate_x = padcat(gates.gate_x_migrate{:})';
all_gate_y = padcat(gates.gate_y_migrate{:})';
len = max(size(all_gate_x));

% Set full outfile
ns = 0;
if contains(outfile,'_ns')
	ns = 1;
end

% set full outfile
outfile = ['../out/pub/derived/' outfile ];

% make netcdf
cmode = netcdf.getConstant('NETCDF4');
cmode = bitor(cmode,netcdf.getConstant('NC_WRITE'));
command = ['rm -f ' outfile]; system(command);
ncid = netcdf.create(outfile,cmode); 
% Set global attributes
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'Conventions','ACDD-1.3');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'title','Thickness data for FrankenBedAdj');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'summary','Thickness data for FrankenBedAdj');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_name','Benjamin Davison');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_email','b.davison@leeds.ac.uk');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'institution','University of Leeds');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'source','https://doi.org/10.5281/zenodo.10051894');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'product_version','1.0');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'keywords','Antarctic Ice Sheet; grounding line discharge; flux gates; ice thickness');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'date_modified', datestr(datetime('now'),'yyyymmddTHHMMSS'));
%   - create dimensions
dimidGateXLen = netcdf.defDim(ncid,'coordinate',size(all_gate_x,2));
dimidGate = netcdf.defDim(ncid,'gate',length(migration_distance));
%   - Define gate x coordinates variable
GateXVarid = netcdf.defVar(ncid,'gate_x','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,GateXVarid,false,true,compression_factor);
netcdf.putAtt(ncid,GateXVarid,'long_name','gate x coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateXVarid,'standard_name','gate x coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateXVarid ,'units','m');
netcdf.putAtt(ncid,GateXVarid,'coverage_content_type','coordinate'); % (image, thematicClassification, physicalMeasurement, auxiliaryInformation, qualityInformation, referenceInformation, modelResult, or coordinate).
netcdf.putAtt(ncid,GateXVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,GateXVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,GateXVarid,all_gate_x);
%   - Define gate y coordinates variable
GateYVarid = netcdf.defVar(ncid,'gate_y','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,GateYVarid,false,true,compression_factor);
netcdf.putAtt(ncid,GateYVarid,'long_name','gate y coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateYVarid,'standard_name','gate y coordinates in EPSG 3031');
netcdf.putAtt(ncid,GateYVarid ,'units','m');
netcdf.putAtt(ncid,GateYVarid,'coverage_content_type','coordinate');
netcdf.putAtt(ncid,GateYVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,GateYVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,GateYVarid,all_gate_y);
%   - Define gate distance variable
GateDistVarid = netcdf.defVar(ncid,'distance','NC_FLOAT',dimidGate);
netcdf.putAtt(ncid,GateDistVarid,'long_name','distance upstream from seaward gate');
netcdf.putAtt(ncid,GateDistVarid,'standard_name','distance');
netcdf.putAtt(ncid,GateDistVarid,'coverage_content_type','referenceInformation');
netcdf.putAtt(ncid,GateDistVarid ,'units','m');
netcdf.putVar(ncid,GateDistVarid,migration_distance);

% Get thickness info
sz = size(zeros([len,length(migration_distance)]));
H = buildThicknessStack(sz,'H_new',migration_distance,ns);
delH = buildThicknessStack(sz,'H_change',migration_distance,ns);
%   - Thickness at gate with FrankenBedAdj
HAllVarid = netcdf.defVar(ncid,'FrankenBedAdj_all_gates','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,HAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,HAllVarid,'long_name','Reference ice thickness with FrankenBedAdj');
netcdf.putAtt(ncid,HAllVarid,'standard_name','FrankenBedAdj ice thickness');
netcdf.putAtt(ncid,HAllVarid,'coverage_content_type','physicalMeasurement');
netcdf.putAtt(ncid,HAllVarid ,'units','m');
netcdf.putAtt(ncid,HAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,HAllVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,HAllVarid,H');
%   - Thickness change at gate with FrankenBedAdj
DelHAllVarid = netcdf.defVar(ncid,'Adj_all_gates','NC_DOUBLE',[dimidGate dimidGateXLen]);
netcdf.defVarDeflate(ncid,DelHAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,DelHAllVarid,'long_name','Change in thickness applied to create FrankenBedAdj');
netcdf.putAtt(ncid,DelHAllVarid,'standard_name','Change in thickness');
netcdf.putAtt(ncid,DelHAllVarid,'coverage_content_type','physicalMeasurement');
netcdf.putAtt(ncid,DelHAllVarid ,'units','m');
netcdf.putAtt(ncid,DelHAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,DelHAllVarid ,'coordinates','gate coordinate');
netcdf.putVar(ncid,DelHAllVarid,delH');

% close netcdf file
netcdf.close(ncid);

end


%% buildDischargeStack(sz,'bQ');
function out = buildThicknessStack(sz,var,migration_distance,ns)

    out = zeros(sz).*NaN;
    for kk = 1:length(migration_distance)
	    % - load data
		if ns == 1
            tmp = load(['../out/int/derived/thickness_adjustment_' num2str(migration_distance(kk)) 'm_ns.mat'],var);
		else
            tmp = load(['../out/int/derived/thickness_adjustment_' num2str(migration_distance(kk)) 'm.mat'],var);
		end
        tmp = tmp.(var);
	    % - build stack
        out(1:length(tmp),kk) = tmp;
    end

end