function append_ice_velocity(migration_distance)

% add paths to libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
end

%% Load flux gate

g = load('../out/pub/gates/flux_gates_migrated.mat');
migration_distances = 0:200:3000; % metres
migration_pixels = find(migration_distances == migration_distance); % metres
gate_x = g.gate_x_migrate{migration_pixels};
gate_y = g.gate_y_migrate{migration_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear g


%% Load raw velocity

load(['../out/int/gate_data/gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm_compiled.mat']);
load(['../out/int/gate_data/reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_fd');

%% Extract new monthly velocities

% Get list of velocity mosaics
vx_list = dir('/resstore/b0133/SID/Antarctica/IV/S1/output/mosaic/monthly_corrected/**/vx_corrected.tif');

% Get times
dates = zeros([numel(vx_list),2]).*NaN;
for i = 1:numel(vx_list)
    d = extractAfter(vx_list(i).folder,'monthly_corrected/');
    dates(i,:) = [datenum(d(1:8),'yyyymmdd') , datenum(d(10:17),'yyyymmdd')];
end
md = nanmean(dates,2);

% Get dates since we last updated the velocity timeseries
keep = md>time_vel(end);
if sum(keep)==0; quit; end % quit matlab if there are no new dates
dates = dates(keep,:);
md = md(keep);
vx_list = vx_list(keep);

% Get image coordinates
[~,x,y] = geoimread([vx_list(1).folder '/vx_corrected.tif']);

% Pre-allocate output
vx = zeros([length(gate_x),numel(vx_list)]).*NaN;
vy = zeros([length(gate_x),numel(vx_list)]).*NaN;
vx_err = zeros([length(gate_x),numel(vx_list)]).*NaN;
vy_err = zeros([length(gate_x),numel(vx_list)]).*NaN;
source = ones([numel(vx_list),1]).*6;

% Loop through new files and extract at gate
for i = 1:numel(vx_list)
    disp(['Processing month ' num2str(i) ' of ' num2str(numel(vx_list)) ]);
    % vx
    data = double(geoimread([vx_list(i).folder '/vx_corrected.tif']));
    vx(:,i) = interp2(x,y,data,gate_x,gate_y,'linear');
    % vy
    data = double(geoimread([vx_list(i).folder '/vy_corrected.tif']));
    vy(:,i) = interp2(x,y,data,gate_x,gate_y,'linear');
    % error
    data = double(geoimread(['/resstore/b0133/SID/Antarctica/IV/S1/output/mosaic/monthly/' datestr(dates(i,1),'yyyymmdd') '_' datestr(dates(i,2),'yyyymmdd') '/err_clean.tif']));
    sp_err = interp2(x,y,data,gate_x,gate_y,'linear');
    [tmp_vx,tmp_vy] = compass2cart(gate_fd(isfinite(sp_err)),sp_err(isfinite(sp_err)));
    [tmp_vx,tmp_vy] = uv2vxvy(gate_x(isfinite(sp_err)),gate_y(isfinite(sp_err)),tmp_vx,tmp_vy);
    vx_err(isfinite(sp_err),i) = abs(tmp_vx);
    vy_err(isfinite(sp_err),i) = abs(tmp_vy);
end
clear tmp_vx tmp_vy sp_err data X Y x y

% Save new velocities
%save(['gate_vel_linear_migrate_' num2str(migration_distance) 'm_append_SID_corrected.mat'],'vx','vy','vx_err','vy_err','md','dates','vx_list','source');

%% Append new velocities

% Concatenate
vx_raw = [vx_raw, vx];
vy_raw = [vy_raw, vy];
vxE_raw = [vxE_raw, vx_err];
vyE_raw = [vyE_raw, vy_err];
time_vel = [time_vel, md(:)'];
source_vel = [source_vel, source(:)'];

% Sort
[~,iv] = sort(time_vel,'ascend');
time_vel = time_vel(iv);
vx_raw = vx_raw(:,iv);
vy_raw = vy_raw(:,iv);
vxE_raw = vxE_raw(:,iv);
vyE_raw = vyE_raw(:,iv);
source_vel = source_vel(:,iv);

%% Save updated raw velocity timeseries

% overwrite original velocities so that the dataset grows each month
save(['../out/int/gate_data/gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm_compiled.mat'],'vx_raw','vy_raw','vxE_raw','vyE_raw','source_vel','time_vel');

quit;
