function balance_discharge_to_netcdf(basins,balance_discharge,outfile)

% Get basin info
names = basins.name; 
type = basins.type; 
type_ID = basins.type_ID;

% Set full outfile
if contains(outfile,'all')
    outfile = ['../out/int/discharge/balance/' outfile ];
else
    outfile = ['../out/pub/discharge/balance/' outfile ];
end

% make netcdf
cmode = netcdf.getConstant('NETCDF4');
cmode = bitor(cmode,netcdf.getConstant('NC_WRITE'));
command = ['rm -f ' outfile]; system(command);
ncid = netcdf.create(outfile,cmode); 
% Set global attributes
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'Conventions','ACDD-1.3');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'title','Antarctic Ice Sheet balance discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'summary',['Balance flux (discharge) for each Antarctic Ice Sheet'...
    ' glacier and drainage basin.']);
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_name','Benjamin Davison');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_email','b.davison@leeds.ac.uk');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'institution','University of Leeds');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'source','https://doi.org/10.5281/zenodo.10051894');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'product_version','1.0');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'keywords','Antarctic Ice Sheet; grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'date_modified', datestr(datetime('now'),'yyyymmddTHHMMSS'));
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'comment','Balance discharge is assumed to equal the climatological (1979-2008) mean surface mass balance');
%   - create dimensions
dimidBasinCount = netcdf.defDim(ncid,'basin',numel(names)); 
%   - Define basin name variable
BasinsNameVarid = netcdf.defVar(ncid,'basin_name','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsNameVarid,'long_name','Ice sheet drainage basin names');
netcdf.putAtt(ncid,BasinsNameVarid,'standard_name','names');
netcdf.putAtt(ncid,BasinsNameVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsNameVarid,names);
%   - Define basin type variable
BasinsTypeVarid = netcdf.defVar(ncid,'basin_type','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeVarid,'long_name','Basin Type (Full ice sheet, MEaSUREs regional, MEaSUREs glaciers, Zwally, Cook, ice shelf, Ice Sheet Rignot, Ice Sheet Zwally)');
netcdf.putAtt(ncid,BasinsTypeVarid,'standard_name','type');
netcdf.putAtt(ncid,BasinsTypeVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeVarid,type);
%   - Define basin type ID variable
BasinsTypeIDVarid = netcdf.defVar(ncid,'basin_type_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeIDVarid,'long_name','Basin Type ID (full ice sheet==0, MEaSUREs regional==1, MEaSUREs glaciers==2, Zwally==3, Cook==4, ice shelf==5, ice_sheet_Rignot==6, ice_sheet_Zwally==7)');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'standard_name','type_id');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'coverage_content_type','referenceInformation'); % (image, thematicClassification, physicalMeasurement, auxiliaryInformation, qualityInformation, referenceInformation, modelResult, or coordinate).
netcdf.putAtt(ncid,BasinsTypeIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeIDVarid,type_ID);
%   - Define basin ID variable
BasinsIDVarid = netcdf.defVar(ncid,'basin_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsIDVarid,'long_name','Basin ID');
netcdf.putAtt(ncid,BasinsIDVarid,'standard_name','ID');
netcdf.putAtt(ncid,BasinsIDVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsIDVarid,1:length(type_ID));
%   - Define RACMO balance discharge variable
QBalRACMOVarid = netcdf.defVar(ncid,'balance_discharge_RACMO','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalRACMOVarid,'long_name','Balance discharge from RACMO2.3p2 (1979-2008)');
netcdf.putAtt(ncid,QBalRACMOVarid,'standard_name','balance_discharge_RACMO');
netcdf.putAtt(ncid,QBalRACMOVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalRACMOVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalRACMOVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalRACMOVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalRACMOVarid,balance_discharge.Qbal_RACMO);
%   - Define RACMO balance discharge error variable
QBalRACMOErrVarid = netcdf.defVar(ncid,'balance_discharge_RACMO_error','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalRACMOErrVarid,'long_name','Balance discharge error from RACMO2.3p2 (1979-2008)');
netcdf.putAtt(ncid,QBalRACMOErrVarid,'standard_name','balance_discharge_RACMO_error');
netcdf.putAtt(ncid,QBalRACMOErrVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalRACMOErrVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalRACMOErrVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalRACMOErrVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalRACMOErrVarid,balance_discharge.Qbal_err_RACMO);
%   - Define HIRHAM balance discharge variable
QBalHIRHAMVarid = netcdf.defVar(ncid,'balance_discharge_HIRHAM','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalHIRHAMVarid,'long_name','Balance discharge from HIRHAM5 (1979-2008)');
netcdf.putAtt(ncid,QBalHIRHAMVarid,'standard_name','balance_discharge_HIRHAM');
netcdf.putAtt(ncid,QBalHIRHAMVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalHIRHAMVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalHIRHAMVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalHIRHAMVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalHIRHAMVarid,balance_discharge.Qbal_HIRHAM);
%   - Define HIRHAM balance discharge error variable
QBalHIRHAMErrVarid = netcdf.defVar(ncid,'balance_discharge_HIRHAM_error','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalHIRHAMErrVarid,'long_name','Balance discharge error from HIRHAM5 (1979-2008)');
netcdf.putAtt(ncid,QBalHIRHAMErrVarid,'standard_name','balance_discharge_HIRHAM_error');
netcdf.putAtt(ncid,QBalHIRHAMErrVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalHIRHAMErrVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalHIRHAMErrVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalHIRHAMErrVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalHIRHAMErrVarid,balance_discharge.Qbal_err_HIRHAM);
%   - Define MAR balance discharge variable
QBalMARVarid = netcdf.defVar(ncid,'balance_discharge_MAR','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalMARVarid,'long_name','Balance discharge from MAR (1980-2008)');
netcdf.putAtt(ncid,QBalMARVarid,'standard_name','balance_discharge_MAR');
netcdf.putAtt(ncid,QBalMARVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalMARVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalMARVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalMARVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalMARVarid,balance_discharge.Qbal_MAR);
%   - Define MAR balance discharge error variable
QBalMARErrVarid = netcdf.defVar(ncid,'balance_discharge_MAR_error','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalMARErrVarid,'long_name','Balance discharge error from MAR (1980-2008)');
netcdf.putAtt(ncid,QBalMARErrVarid,'standard_name','balance_discharge_MAR_error');
netcdf.putAtt(ncid,QBalMARErrVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalMARErrVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalMARErrVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalMARErrVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalMARErrVarid,balance_discharge.Qbal_err_MAR);
%   - Define ensemble balance discharge variable
QBalEnsVarid = netcdf.defVar(ncid,'balance_discharge_ensemble','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalEnsVarid,'long_name','Balance discharge from three-model mean (1979-2008)');
netcdf.putAtt(ncid,QBalEnsVarid,'standard_name','balance_discharge_ensemble');
netcdf.putAtt(ncid,QBalEnsVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalEnsVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalEnsVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalEnsVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalEnsVarid,balance_discharge.Qbal_ens);
%   - Define ensemble balance discharge error variable
QBalEnsErrVarid = netcdf.defVar(ncid,'balance_discharge_ensemble_error','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,QBalEnsErrVarid,'long_name','Balance discharge error from three-model mean (1979-2008)');
netcdf.putAtt(ncid,QBalEnsErrVarid,'standard_name','balance_discharge_ensemble_error');
netcdf.putAtt(ncid,QBalEnsErrVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QBalEnsErrVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QBalEnsErrVarid ,'_FillValue',single(NaN));
netcdf.putAtt(ncid,QBalEnsErrVarid ,'coordinates','basin');
netcdf.putVar(ncid,QBalEnsErrVarid,balance_discharge.Qbal_err_ens);

% close netcdf file
netcdf.close(ncid);

end
