function basins_to_netcdf(basins,outfile,compression_factor)

% Get basin info
names = string([basins.name]); 
type = string([basins.type]); 
type_ID = [basins.type_ID]; 
basin_x = padcat(basins.x{:})';
basin_y = padcat(basins.y{:})';
basin_centroid_x = basins.centroid(:,1);
basin_centroid_y = basins.centroid(:,2);

% Make sure dimensions are correct
if size(basin_x,1)>size(basin_x,2)
    basin_x = basin_x';
    basin_y = basin_y';
end

% Set full outfile
if contains(outfile,'all')
    outfile = ['../out/int/basins/' outfile ];
else
    outfile = ['../out/pub/basins/' outfile ];
end

% make netcdf
cmode = netcdf.getConstant('NETCDF4');
cmode = bitor(cmode,netcdf.getConstant('NC_WRITE'));
command = ['rm -f ' outfile]; system(command);
ncid = netcdf.create(outfile,cmode); 
% Set global attributes
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'Conventions','ACDD-1.3');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'title','Basins for Antarctic grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'summary','Basins for Antarctic grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_name','Benjamin Davison');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_email','b.davison@leeds.ac.uk');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'institution','University of Leeds');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'source','https://doi.org/10.5281/zenodo.10051894');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'product_version','1.0');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'keywords','Antarctic Ice Sheet; grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'date_modified', datestr(datetime('now'),'yyyymmddTHHMMSS'));
%   - create dimensions
dimidBasinCount = netcdf.defDim(ncid,'basin',numel(names)); 
dimidBasinXLen = netcdf.defDim(ncid,'coordinate',size(basin_x,2)); 
%   - Define basin name variable
BasinsNameVarid = netcdf.defVar(ncid,'basin_name','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsNameVarid,'long_name','Ice sheet drainage basin names');
netcdf.putAtt(ncid,BasinsNameVarid,'standard_name','names');
netcdf.putAtt(ncid,BasinsNameVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsNameVarid,names);
%   - Define basin type variable
BasinsTypeVarid = netcdf.defVar(ncid,'basin_type','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeVarid,'long_name','Basin Type (Full ice sheet, MEaSUREs regional, MEaSUREs glaciers, Zwally, Cook, ice shelf, Ice Sheet Rignot, Ice Sheet Zwally)');
netcdf.putAtt(ncid,BasinsTypeVarid,'standard_name','type');
netcdf.putAtt(ncid,BasinsTypeVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeVarid,type);
%   - Define basin type ID variable
BasinsTypeIDVarid = netcdf.defVar(ncid,'basin_type_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeIDVarid,'long_name','Basin Type ID (full ice sheet==0, MEaSUREs regional==1, MEaSUREs glaciers==2, Zwally==3, Cook==4, ice shelf==5, ice_sheet_Rignot==6, ice_sheet_Zwally==7)');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'standard_name','type_id');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'coverage_content_type','referenceInformation'); % (image, thematicClassification, physicalMeasurement, auxiliaryInformation, qualityInformation, referenceInformation, modelResult, or coordinate).
netcdf.putAtt(ncid,BasinsTypeIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeIDVarid,type_ID);
%   - Define basin ID variable
BasinsIDVarid = netcdf.defVar(ncid,'basin_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsIDVarid,'long_name','Basin ID');
netcdf.putAtt(ncid,BasinsIDVarid,'standard_name','ID');
netcdf.putAtt(ncid,BasinsIDVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsIDVarid,1:length(type_ID));
%   - Define basin x coordinates variable
BasinsXVarid = netcdf.defVar(ncid,'perim_x','NC_DOUBLE',[dimidBasinCount dimidBasinXLen]);
netcdf.defVarDeflate(ncid,BasinsXVarid,false,true,compression_factor);
netcdf.putAtt(ncid,BasinsXVarid,'long_name','Basin perimeter x coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsXVarid,'standard_name','Basin perimeter x coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsXVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsXVarid ,'units','m');
netcdf.putAtt(ncid,BasinsXVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,BasinsXVarid ,'coordinates','basin coordinate');
netcdf.putVar(ncid,BasinsXVarid,basin_x);
%   - Define basin y coordinates variable
BasinsYVarid = netcdf.defVar(ncid,'perim_y','NC_DOUBLE',[dimidBasinCount dimidBasinXLen]);
netcdf.defVarDeflate(ncid,BasinsYVarid,false,true,compression_factor);
netcdf.putAtt(ncid,BasinsYVarid,'long_name','Basin perimeter y coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsYVarid,'standard_name','Basin perimeter y coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsYVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsYVarid ,'units','m');
netcdf.putAtt(ncid,BasinsYVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,BasinsYVarid ,'coordinates','basin coordinate');
netcdf.putVar(ncid,BasinsYVarid,basin_y);
%   - Define basin centroid x coordinates variable
BasinsCenXVarid = netcdf.defVar(ncid,'centroid_x','NC_DOUBLE',dimidBasinCount);
netcdf.defVarDeflate(ncid,BasinsCenXVarid,false,true,compression_factor);
netcdf.putAtt(ncid,BasinsCenXVarid,'long_name','Basin centroid x coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsCenXVarid,'standard_name','Basin centroid x coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsCenXVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsCenXVarid ,'units','m');
netcdf.putAtt(ncid,BasinsCenXVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,BasinsCenXVarid ,'coordinates','basin');
netcdf.putVar(ncid,BasinsCenXVarid,basin_centroid_x);
%   - Define basin centroid y coordinates variable
BasinsCenYVarid = netcdf.defVar(ncid,'centroid_y','NC_DOUBLE',dimidBasinCount);
netcdf.defVarDeflate(ncid,BasinsCenYVarid,false,true,compression_factor);
netcdf.putAtt(ncid,BasinsCenYVarid,'long_name','Basin centroid y coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsCenYVarid,'standard_name','Basin centroid y coordinates in EPSG 3031');
netcdf.putAtt(ncid,BasinsCenYVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsCenYVarid ,'units','m');
netcdf.putAtt(ncid,BasinsCenYVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,BasinsCenYVarid ,'coordinates','basin');
netcdf.putVar(ncid,BasinsCenYVarid,basin_centroid_y);

% close netcdf file
netcdf.close(ncid);

end