function basins_to_shapefile(basins,outfile)

% Get basin info
type_ID = [basins.type_ID]; 
ID = 1:length(type_ID);

% Make a geoshape for each type of basin
unique_basin_type = unique(type_ID);

% Set full outfile
if contains(outfile,'all')
    outstub = '../out/int/basins/all_';
    typestub = '.shp';
else
    outstub = '../out/pub/basins/';
    typestub = '.shp';
end

for i = 1:length(unique_basin_type)
    
    % Get index of this type
    type_idx = find(type_ID==unique_basin_type(i));
    
    % Prepare structure
    S = struct();
    for j = 1:length(type_idx)
        S(j).Geometry = 'polygon';
        S(j).X = basins.x{type_idx(j)};
        S(j).Y = basins.y{type_idx(j)};
        S(j).centroid_x = basins.centroid(type_idx(j),1);
        S(j).centroid_y = basins.centroid(type_idx(j),2);
        S(j).name = basins.name{type_idx(j)};
        S(j).ID = ID(type_idx(j));
    end
    
    % Save
    if unique_basin_type(i) == 0
        outname = [ outstub 'ice_sheet' typestub ];
    elseif unique_basin_type(i) == 1
        outname = [ outstub 'MEaSUREs_regional_basins' typestub ];
    elseif unique_basin_type(i) == 2
        outname = [ outstub 'MEaSUREs_glacier_basins' typestub ];
    elseif unique_basin_type(i) == 3
        outname = [ outstub 'Zwally_basins' typestub ];
    elseif unique_basin_type(i) == 4
        outname = [ outstub 'Cook_basins' typestub ];
    elseif unique_basin_type(i) == 5
        outname = [ outstub 'ice_shelf_basins' typestub ];
    elseif unique_basin_type(i) == 6
        outname = [ outstub 'ice_sheet_Rignot' typestub ];
    elseif unique_basin_type(i) == 7
        outname = [ outstub 'ice_sheet_Zwally' typestub ];
    end
    shapewrite(S,outname)
    str = "PROJCS[""WGS_84_Antarctic_Polar_Stereographic"",GEOGCS[""GCS_WGS_1984"",DATUM[""D_WGS_1984"",SPHEROID[""WGS_1984"",6378137,298.257223563]],PRIMEM[""Greenwich"",0],UNIT[""Degree"",0.017453292519943295]],PROJECTION[""Stereographic_South_Pole""],PARAMETER[""standard_parallel_1"",-71],PARAMETER[""central_meridian"",0],PARAMETER[""false_easting"",0],PARAMETER[""false_northing"",0],UNIT[""Meter"",1]]";
    outprj = [extractBefore(outname,'.shp') '.prj'];
    writelines(str,outprj);
    
end

end
    