function discharge_to_csv(H_dataset,basins,migration_distance,outfile,keep)

% Time and velocity source
load('../out/int/discharge/basin/basin_discharge_migrate_0m_FrankenBed_all_basins.mat','time','velocity_source');
dt_time = datetime(time,'convertFrom','datenum');

% Get basin info
names = char(string([basins.name])); 
type = char(string([basins.type])); 
type_ID = [basins.type_ID]; 
basin_ID = 1:length(type_ID);
basin_x = basins.centroid(:,1);
basin_y = basins.centroid(:,2);

% Prepare table info
[unitnames{1:numel(basins.name)}] = deal('Gt/yr');
[varDesc{1:numel(basins.name)}] = deal('Basin ID: ');
tmp_ID = cellstr(num2str(basin_ID(:)));
varDesc = strcat(varDesc(:),tmp_ID);

% Build the basin info table
Tinfo = table(basin_ID(:),type,type_ID,basin_x,basin_y,names,...
		'VariableNames',{'basin_ID','basin_type','basin_type_ID',...
        'basin_centroid_x','basin_centroid_y','Basin name'});
TinfoC = table2cell(Tinfo);
Tinfo = cell2table(TinfoC','RowNames',Tinfo.Properties.VariableNames);

% Set full outfile
ns = 0;
if contains(outfile,'_ns')
	ns = 1;
end

if contains(outfile,'all')
    outstub = ['../out/int/discharge/csv/' H_dataset '/' ];
    if ns == 1
        typestub = '_all_basins_ns.csv';
    else
        typestub = '_all_basins.csv';
    end
else
    outstub = ['../out/pub/discharge/csv/' H_dataset '/' ];
    if ns == 1
        typestub = '_ns.csv';
    else
        typestub = '.csv';
    end
end


% MAIN ESTIMATE (IMAU FDM and all corrections)
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_discharge_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_IMAU' typestub ];
    QE_csvname = [outstub 'AIS_discharge_error_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_IMAU' typestub ];
    P_csvname = [outstub 'AIS_discharge_coverage_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_IMAU' typestub ];
    dischargeToCSV(Tinfo,Q(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
    dischargeToCSV(Tinfo,QE(:,:,i),dt_time,names,unitnames,varDesc,QE_csvname);
    dischargeToCSV(Tinfo,p(:,:,i),dt_time,names,unitnames,varDesc,P_csvname);
end
% Calculate gate-mean quantities
bQ = wmean(Q,1./QE,'dim',3,'omitnan');
bQse = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE = rssq(QE,3);
bQp = wmean(p,1./QE,'dim',3,'omitnan');
% Save gate-mean discharge variables to csv
Q_csvname = [outstub 'AIS_discharge_' H_dataset '_IMAU' typestub ];
QE_csvname = [outstub 'AIS_discharge_error_' H_dataset '_IMAU' typestub ];
Qse_csvname = [outstub 'AIS_discharge_standard_error_' H_dataset '_IMAU' typestub ];
P_csvname = [outstub 'AIS_discharge_coverage_' H_dataset '_IMAU' typestub ];
dischargeToCSV(Tinfo,bQ,dt_time,names,unitnames,varDesc,Q_csvname);
dischargeToCSV(Tinfo,bQE,dt_time,names,unitnames,varDesc,QE_csvname);
dischargeToCSV(Tinfo,bQse,dt_time,names,unitnames,varDesc,Qse_csvname);
dischargeToCSV(Tinfo,bQp,dt_time,names,unitnames,varDesc,P_csvname);



% GSFC ESTIMATE
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ_GSFC',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE_GSFC',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp_GSFC',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_discharge_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GSFC' typestub ];
    QE_csvname = [outstub 'AIS_discharge_error_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GSFC' typestub ];
    P_csvname = [outstub 'AIS_discharge_coverage_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GSFC' typestub ];
    dischargeToCSV(Tinfo,Q(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
    dischargeToCSV(Tinfo,QE(:,:,i),dt_time,names,unitnames,varDesc,QE_csvname);
    dischargeToCSV(Tinfo,p(:,:,i),dt_time,names,unitnames,varDesc,P_csvname);
end
% Calculate gate-mean quantities
bQ = wmean(Q,1./QE,'dim',3,'omitnan');
bQse = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE = rssq(QE,3);
bQp = wmean(p,1./QE,'dim',3,'omitnan');
% Save gate-mean discharge variables to csv
Q_csvname = [outstub 'AIS_discharge_' H_dataset '_GSFC' typestub ];
QE_csvname = [outstub 'AIS_discharge_error_' H_dataset '_GSFC' typestub ];
Qse_csvname = [outstub 'AIS_discharge_standard_error_' H_dataset '_GSFC' typestub ];
P_csvname = [outstub 'AIS_discharge_coverage_' H_dataset '_GSFC' typestub ];
dischargeToCSV(Tinfo,bQ,dt_time,names,unitnames,varDesc,Q_csvname);
dischargeToCSV(Tinfo,bQE,dt_time,names,unitnames,varDesc,QE_csvname);
dischargeToCSV(Tinfo,bQse,dt_time,names,unitnames,varDesc,Qse_csvname);
dischargeToCSV(Tinfo,bQp,dt_time,names,unitnames,varDesc,P_csvname);


% GEMB ESTIMATE
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ_GEMB',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE_GEMB',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp_GEMB',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_discharge_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GEMB' typestub ];
    QE_csvname = [outstub 'AIS_discharge_error_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GEMB' typestub ];
    P_csvname = [outstub 'AIS_discharge_coverage_gate_' num2str(migration_distance(i)) 'm_' H_dataset '_GEMB' typestub ];
    dischargeToCSV(Tinfo,Q(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
    dischargeToCSV(Tinfo,QE(:,:,i),dt_time,names,unitnames,varDesc,QE_csvname);
    dischargeToCSV(Tinfo,p(:,:,i),dt_time,names,unitnames,varDesc,P_csvname);
end
% Calculate gate-mean quantities
bQ = wmean(Q,1./QE,'dim',3,'omitnan');
bQse = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE = rssq(QE,3);
bQp = wmean(p,1./QE,'dim',3,'omitnan');
% Save gate-mean discharge variables to csv
Q_csvname = [outstub 'AIS_discharge_' H_dataset '_GEMB' typestub ];
QE_csvname = [outstub 'AIS_discharge_error_' H_dataset '_GEMB' typestub ];
Qse_csvname = [outstub 'AIS_discharge_standard_error_' H_dataset '_GEMB' typestub ];
P_csvname = [outstub 'AIS_discharge_coverage_' H_dataset '_GEMB' typestub ];
dischargeToCSV(Tinfo,bQ,dt_time,names,unitnames,varDesc,Q_csvname);
dischargeToCSV(Tinfo,bQE,dt_time,names,unitnames,varDesc,QE_csvname);
dischargeToCSV(Tinfo,bQse,dt_time,names,unitnames,varDesc,Qse_csvname);
dischargeToCSV(Tinfo,bQp,dt_time,names,unitnames,varDesc,P_csvname);


% DOWNSTREAM SMB correction (main minus 'insitu') - positive means this correction added to the total discharge
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ',migration_distance,H_dataset,keep,ns);
Q_correction = buildDischargeStack(sz,'bQ_insitu',migration_distance,H_dataset,keep,ns); % discharge with everything except the SMB correction
Q_correction = Q - Q_correction; % difference gives us the effect of the correction
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_SMB_correction_gate_' num2str(migration_distance(i)) 'm_' H_dataset typestub ];
    dischargeToCSV(Tinfo,Q_correction(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
end


% EFFECT OF FDM on discharge (main minus NF) - negative, means this correction lowers the total discharge
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ',migration_distance,H_dataset,keep,ns);
Q_correction = buildDischargeStack(sz,'bQ_NF',migration_distance,H_dataset,keep,ns); % discharge with everything except the FDM correction
Q_correction = Q - Q_correction; % difference gives us the effect of the correction
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_FDM_correction_gate_' num2str(migration_distance(i)) 'm_' H_dataset typestub ];
    dischargeToCSV(Tinfo,Q_correction(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
end


% EFFECT OF TIME-VARYING ICE SURFACE (main minus NDH) - in areas where
% ice is thinning, this is negative after May 2015 and positive before
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ',migration_distance,H_dataset,keep,ns);
Q_correction = buildDischargeStack(sz,'bQ_NDH',migration_distance,H_dataset,keep,ns); % discharge with everything except time-varying ice surface
Q_correction = Q - Q_correction; % difference gives us the effect of the correction
% Save each gate to CSV
for i = 1:length(migration_distance)
    Q_csvname = [outstub 'AIS_dH_correction_gate_' num2str(migration_distance(i)) 'm_' H_dataset typestub ];
    dischargeToCSV(Tinfo,Q_correction(:,:,i),dt_time,names,unitnames,varDesc,Q_csvname);
end

end

%% dischargeToCSV(Tinfo,bQ,dt_time,names,unitnames,varDesc,outfile,'discharge',migration_distance(j),H_dataset)
function dischargeToCSV(Tinfo,thisDischarge,dt_time,names,unitnames,varDesc,csvname)

    thisDischarge = thisDischarge'; % rotate discharge
    T = array2timetable(thisDischarge,'rowTime',dt_time,'VariableNames',[ cellstr(names)]); % create timetable of numeric data
    T.Properties.VariableUnits = unitnames; % append unitnames
    T.Properties.VariableDescriptions = varDesc; % append variable descriptions
    command = ['rm -f ' csvname]; system(command);
    writetable(Tinfo,csvname,'writeVariableNames',0,'WriteRowNames',1);
    writetimetable(T,csvname,'WriteMode','append');

end


%% buildDischargeStack(sz,'bQ');
function out = buildDischargeStack(sz,var,migration_distance,H_dataset,keep,ns)

    out = zeros(sz).*NaN;
    for kk = 1:length(migration_distance)
	    % - load data
		if ns == 1
			tmp = load(['basin_discharge_migrate_' num2str(migration_distance(kk)) 'm_' H_dataset '_all_basins_ns.mat'],var);
		else
			tmp = load(['basin_discharge_migrate_' num2str(migration_distance(kk)) 'm_' H_dataset '_all_basins.mat'],var);
		end
        tmp = tmp.(var);
        % - trim
        tmp = tmp(keep,:);
	    % - build stack
        out(:,:,kk) = tmp;
    end

end