function discharge_to_netcdf(H_dataset,basins,migration_distance,outfile,compression_factor,keep)

% Time and velocity source
load('../out/int/discharge/basin/basin_discharge_migrate_0m_FrankenBed_all_basins.mat','time','velocity_source');
velocity_source(velocity_source==6) = 2;
velocity_source(velocity_source==8) = 6;
velocity_source(velocity_source==9) = 7;

% Basin info
names = basins.name;
type = basins.type; 
type_ID = basins.type_ID; 
basin_ID = 1:length(type_ID);

% Set full outfile
ns = 0;
if contains(outfile,'_ns')
	ns = 1;
end

if contains(outfile,'all')
	outfile = ['../out/int/discharge/nc/' outfile ];
else
    outfile = ['../out/pub/discharge/nc/' outfile ];
end

% Prepare netcdf for this thickness dataset
cmode = netcdf.getConstant('NETCDF4');
cmode = bitor(cmode,netcdf.getConstant('NC_WRITE'));
command = ['rm -f ' outfile]; system(command);
ncid = netcdf.create(outfile,cmode); 
% Set global attributes
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'Conventions','ACDD-1.3');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'title','Antarctic grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'summary',['Grounding line discharge for each Antarctic Ice Sheet'...
    ' glacier and drainage basin. For all discharge variables, each row corresponds to a basin (details in basins.nc)'...
    ' and each column corresponds to a different velocity epoch.']);
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_name','Benjamin Davison');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'creator_email','b.davison@leeds.ac.uk');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'institution','University of Leeds');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'source','https://doi.org/10.5281/zenodo.10051894');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'product_version','1.0');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'time_coverage_start', datestr(min(time),'yyyymmddTHHMMSS') );
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'time_coverage_end', datestr(max(time),'yyyymmddTHHMMSS') );
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'keywords','Antarctic Ice Sheet; grounding line discharge');
netcdf.putAtt(ncid,netcdf.getConstant('NC_GLOBAL'),'date_created', datestr(datetime('now'),'yyyymmddTHHMMSS'));
%   - create dimensions
dimidBasinCount = netcdf.defDim(ncid,'basin',numel(names)); 
dimidTime = netcdf.defDim(ncid,'time',length(time)); 
dimidGate = netcdf.defDim(ncid,'gate',length(migration_distance));
%   - Define basin name variable
BasinsNameVarid = netcdf.defVar(ncid,'basin_name','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsNameVarid,'long_name','Ice sheet drainage basin names');
netcdf.putAtt(ncid,BasinsNameVarid,'standard_name','names');
netcdf.putAtt(ncid,BasinsNameVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsNameVarid,names);
%   - Define basin type variable
BasinsTypeVarid = netcdf.defVar(ncid,'basin_type','NC_STRING',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeVarid,'long_name','Basin Type (Full ice sheet, MEaSUREs regional, MEaSUREs glaciers, Zwally, Cook, ice shelf, Ice Sheet Rignot, Ice Sheet Zwally)');
netcdf.putAtt(ncid,BasinsTypeVarid,'standard_name','type');
netcdf.putAtt(ncid,BasinsTypeVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeVarid,type);
%   - Define basin type ID variable
BasinsTypeIDVarid = netcdf.defVar(ncid,'basin_type_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsTypeIDVarid,'long_name','Basin Type ID (full ice sheet==0, MEaSUREs regional==1, MEaSUREs glaciers==2, Zwally==3, Cook==4, ice shelf==5, ice_sheet_Rignot==6, ice_sheet_Zwally==7)');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'standard_name','type_id');
netcdf.putAtt(ncid,BasinsTypeIDVarid,'coverage_content_type','referenceInformation'); % (image, thematicClassification, physicalMeasurement, auxiliaryInformation, qualityInformation, referenceInformation, modelResult, or coordinate).
netcdf.putAtt(ncid,BasinsTypeIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsTypeIDVarid,type_ID);
%   - Define basin ID variable
BasinsIDVarid = netcdf.defVar(ncid,'basin_ID','NC_FLOAT',dimidBasinCount);
netcdf.putAtt(ncid,BasinsIDVarid,'long_name','Basin ID');
netcdf.putAtt(ncid,BasinsIDVarid,'standard_name','ID');
netcdf.putAtt(ncid,BasinsIDVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,BasinsIDVarid ,'units','n/a');
netcdf.putVar(ncid,BasinsIDVarid,basin_ID);
%   - Define time variable
TimeVarid = netcdf.defVar(ncid,'time','NC_DOUBLE',dimidTime);
netcdf.putAtt(ncid,TimeVarid,'long_name','time of measurement');
netcdf.putAtt(ncid,TimeVarid,'standard_name','time');
netcdf.putAtt(ncid,TimeVarid,'cf_role','timeseries_id');
netcdf.putAtt(ncid,TimeVarid,'axis','T');
netcdf.putAtt(ncid,TimeVarid ,'units','days since 1950-01-01 00:00:00');
netcdf.putAtt(ncid,TimeVarid ,'calendar','proleptic_gregorian');
netcdf.putVar(ncid,TimeVarid,time-datenum(1950,1,1,0,0,0));
%   - Define gate distance variable
GateDistVarid = netcdf.defVar(ncid,'distance','NC_FLOAT',dimidGate);
netcdf.putAtt(ncid,GateDistVarid,'long_name','distance upstream from seaward gate');
netcdf.putAtt(ncid,GateDistVarid,'standard_name','distance');
netcdf.putAtt(ncid,GateDistVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,GateDistVarid ,'units','m');
netcdf.putVar(ncid,GateDistVarid,migration_distance);
%   - Define velocity source variable
VelSourceVarid = netcdf.defVar(ncid,'datasource','NC_FLOAT',dimidTime);
netcdf.putAtt(ncid,VelSourceVarid,'long_name','ice velocity dataset source. 1 = MEaSUREs annual; 2 = Sentinel-1; 3 = ERS/BISICLES; 4 = ITS_LIVE; 5 = MEaSUREs multiyear; 6 = ITS_LIVE ASE sim; 7 = Joughin Pine Island TSX');
netcdf.putAtt(ncid,VelSourceVarid,'standard_name','source');
netcdf.putAtt(ncid,VelSourceVarid,'coverage_content_type','referenceInformation'); 
netcdf.putAtt(ncid,VelSourceVarid ,'units','n/a');
netcdf.putVar(ncid,VelSourceVarid,single(velocity_source));


% MAIN ESTIMATE (IMAU FDM and all corrections)
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Calculate inverse-error weighted mean quantities
bQ_main = wmean(Q,1./QE,'dim',3,'omitnan');
bQse_main = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE_main = rssq(QE,3);
bQp_main = wmean(p,1./QE,'dim',3,'omitnan');
%   - all gates discharge
QAllVarid = netcdf.defVar(ncid,'discharge_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,QAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QAllVarid,'long_name','basin-integrated grounding line discharge for all flux gates (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QAllVarid,'standard_name','discharge_all_gates');
netcdf.putAtt(ncid,QAllVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QAllVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QAllVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,QAllVarid,Q);
%   - all gates error (rssq)
QEAllVarid = netcdf.defVar(ncid,'discharge_error_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,QEAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QEAllVarid,'long_name','basin-integrated grounding line discharge error for all flux gates (IMAU FDM firn) with all corrections applied. Calculated as root-sum-square of all flux gate pixel errors in each basin');
netcdf.putAtt(ncid,QEAllVarid,'standard_name','discharge_error_all_gates');
netcdf.putAtt(ncid,QEAllVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QEAllVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QEAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QEAllVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,QEAllVarid,QE);
%   - all gates proportion observed
QpAllVarid = netcdf.defVar(ncid,'discharge_coverage_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,QpAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QpAllVarid,'long_name','proportion of discharge observed at all flux gates (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QpAllVarid,'standard_name','discharge_coverage_all_gates');
netcdf.putAtt(ncid,QpAllVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QpAllVarid ,'units','%');
netcdf.putAtt(ncid,QpAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QpAllVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,QpAllVarid,p);
%   - gate-mean discharge
QMeanVarid = netcdf.defVar(ncid,'discharge_mean','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QMeanVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QMeanVarid,'long_name','gate-mean basin-integrated grounding line discharge (1/error-weighted average of all flux gates) (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QMeanVarid,'standard_name','discharge_mean');
netcdf.putAtt(ncid,QMeanVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QMeanVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QMeanVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QMeanVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QMeanVarid,bQ_main);
%   - discharge standard error
QSEVarid = netcdf.defVar(ncid,'discharge_standard_error','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QSEVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QSEVarid,'long_name','gate-mean standard error of basin-integrated grounding line discharge from all gates (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QSEVarid,'standard_name','discharge_standard_error');
netcdf.putAtt(ncid,QSEVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QSEVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QSEVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QSEVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QSEVarid,bQse_main);
%   - gate-mean error
QEMeanAllVarid = netcdf.defVar(ncid,'discharge_error','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QEMeanAllVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QEMeanAllVarid,'long_name','gate-mean basin-integrated grounding line discharge error (root-sum-square of all flux gate error) (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QEMeanAllVarid,'standard_name','discharge_error');
netcdf.putAtt(ncid,QEMeanAllVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QEMeanAllVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QEMeanAllVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QEMeanAllVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QEMeanAllVarid,bQE_main);
%   - gate-mean proportion observed
QpMeanVarid = netcdf.defVar(ncid,'discharge_coverage','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QpMeanVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QpMeanVarid,'long_name','proportion of discharge observed (1/error-weighted average of all flux gates) (IMAU FDM firn) with all corrections applied');
netcdf.putAtt(ncid,QpMeanVarid,'standard_name','discharge_coverage');
netcdf.putAtt(ncid,QpMeanVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QpMeanVarid ,'units','%');
netcdf.putAtt(ncid,QpMeanVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QpMeanVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QpMeanVarid,bQp_main);
% keep copy of all gates for calculating corrections later
Qmain = Q;


% GSFC ESTIMATE
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ_GSFC',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE_GSFC',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp_GSFC',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Calculate inverse-error weighted mean quantities
bQ_GSFC = wmean(Q,1./QE,'dim',3,'omitnan');
bQse_GSFC = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE_GSFC = rssq(QE,3);
bQp_GSFC = wmean(p,1./QE,'dim',3,'omitnan');
%   - all gates discharge
QAllGSFCVarid = netcdf.defVar(ncid,'discharge_all_gates_GSFC','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,QAllGSFCVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QAllGSFCVarid,'long_name','basin-integrated grounding line discharge for all flux gates (GSFC firn) with all corrections applied');
netcdf.putAtt(ncid,QAllGSFCVarid,'standard_name','discharge_all_gates_GSFC');
netcdf.putAtt(ncid,QAllGSFCVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QAllGSFCVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QAllGSFCVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QAllGSFCVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,QAllGSFCVarid,Q);
%   - gate-mean discharge
QMeanGSFCVarid = netcdf.defVar(ncid,'discharge_mean_GSFC','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QMeanGSFCVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QMeanGSFCVarid,'long_name','gate-mean basin-integrated grounding line discharge (1/error-weighted average of all flux gates) (GSFC firn) with all corrections applied');
netcdf.putAtt(ncid,QMeanGSFCVarid,'standard_name','discharge_mean_GSFC');
netcdf.putAtt(ncid,QMeanGSFCVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QMeanGSFCVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QMeanGSFCVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QMeanGSFCVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QMeanGSFCVarid,bQ_GSFC);


% GEMB ESTIMATE
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q = buildDischargeStack(sz,'bQ_GEMB',migration_distance,H_dataset,keep,ns);
QE = buildDischargeStack(sz,'bQE_GEMB',migration_distance,H_dataset,keep,ns);
p = buildDischargeStack(sz,'bQp_GEMB',migration_distance,H_dataset,keep,ns);
% Check for nan errors
QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% Calculate inverse-error weighted mean quantities
bQ_GEMB = wmean(Q,1./QE,'dim',3,'omitnan');
bQse_GEMB = nanstd(Q,[],3)./length(migration_distance).^0.5;
bQE_GEMB = rssq(QE,3);
bQp_GEMB = wmean(p,1./QE,'dim',3,'omitnan');
%   - all gate discharge
QAllGEMBVarid = netcdf.defVar(ncid,'discharge_all_gates_GEMB','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,QAllGEMBVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QAllGEMBVarid,'long_name','basin-integrated grounding line discharge for all flux gates (GEMB firn) with all corrections applied');
netcdf.putAtt(ncid,QAllGEMBVarid,'standard_name','discharge_all_gates_GEMB');
netcdf.putAtt(ncid,QAllGEMBVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QAllGEMBVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QAllGEMBVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QAllGEMBVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,QAllGEMBVarid,Q);
%   - gate-mean discharge
QMeanGEMBVarid = netcdf.defVar(ncid,'discharge_mean_GEMB','NC_DOUBLE',[dimidBasinCount dimidTime]);
netcdf.defVarDeflate(ncid,QMeanGEMBVarid,false,true,compression_factor);
netcdf.putAtt(ncid,QMeanGEMBVarid,'long_name','gate-mean basin-integrated grounding line discharge (1/error-weighted average of all flux gates) (GEMB firn) with all corrections applied');
netcdf.putAtt(ncid,QMeanGEMBVarid,'standard_name','discharge_mean_GEMB');
netcdf.putAtt(ncid,QMeanGEMBVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,QMeanGEMBVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,QMeanGEMBVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,QMeanGEMBVarid ,'coordinates','basin time');
netcdf.putVar(ncid,QMeanGEMBVarid,bQ_GEMB);


% DOWNSTREAM SMB correction (main minus 'insitu') - positive means this correction added to the total discharge
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q_correction = buildDischargeStack(sz,'bQ_insitu',migration_distance,H_dataset,keep,ns); % discharge with everything except the SMB correction
Q_correction = Qmain - Q_correction; % difference gives us the effect of the correction
%   - write to netcdf
SMBVarid = netcdf.defVar(ncid,'SMB_correction_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,SMBVarid,false,true,compression_factor);
netcdf.putAtt(ncid,SMBVarid,'long_name','impact of surface mass change between flux gate and grounding line on ice discharge compared to using the reference thickness');
netcdf.putAtt(ncid,SMBVarid,'standard_name','surface mass balance correction between each gate and grounding line');
netcdf.putAtt(ncid,SMBVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,SMBVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,SMBVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,SMBVarid ,'coordinates','basin time');
netcdf.putVar(ncid,SMBVarid,Q_correction);


% EFFECT OF FDM on discharge (main minus NF) - negative, means this correction lowers the total discharge
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q_correction = buildDischargeStack(sz,'bQ_NF',migration_distance,H_dataset,keep,ns); % discharge with everything except the FDM correction
Q_correction = Qmain - Q_correction; % difference gives us the effect of the correction
%   - write to netcdf
FirnVarid = netcdf.defVar(ncid,'FDM_firn_correction_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,FirnVarid,false,true,compression_factor);
netcdf.putAtt(ncid,FirnVarid,'long_name','impact of time-varying firn air content (from IMAU FDM) on ice discharge compared to using the reference thickness');
netcdf.putAtt(ncid,FirnVarid,'standard_name','IMAU FDM firn air content correction at each flux gate');
netcdf.putAtt(ncid,FirnVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,FirnVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,FirnVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,FirnVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,FirnVarid,Q_correction);


% EFFECT OF TIME-VARYING ICE SURFACE (main minus NDH) - in areas where
% ice is thinning, this is negative after May 2015 and positive before
sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
Q_correction = buildDischargeStack(sz,'bQ_NDH',migration_distance,H_dataset,keep,ns); % discharge with everything except time-varying ice surface
Q_correction = Qmain - Q_correction; % difference gives us the effect of the correction
%   - write to netcdf
dHVarid = netcdf.defVar(ncid,'dH_correction_all_gates','NC_DOUBLE',[dimidBasinCount dimidTime dimidGate]);
netcdf.defVarDeflate(ncid,dHVarid,false,true,compression_factor);
netcdf.putAtt(ncid,dHVarid,'long_name','impact of time-varying ice thickness on ice discharge compared to using the reference thickness');
netcdf.putAtt(ncid,dHVarid,'standard_name','change in ice thickness correction at each flux gate');
netcdf.putAtt(ncid,dHVarid,'coverage_content_type','physicalMeasurement'); 
netcdf.putAtt(ncid,dHVarid ,'units','Gt/yr');
netcdf.putAtt(ncid,dHVarid ,'_FillValue',double(NaN));
netcdf.putAtt(ncid,dHVarid ,'coordinates','basin time gate');
netcdf.putVar(ncid,dHVarid,Q_correction);


% Stop writing netcdf
netcdf.close(ncid);


% % static (to get effect of all corrections)
% sz = size(zeros([numel(basins.name),length(time),length(migration_distance)]));
% Q = buildDischargeStack(sz,'bQ_static',migration_distance,H_dataset,keep);
% QE = buildDischargeStack(sz,'bQE_static',migration_distance,H_dataset,keep);
% p = buildDischargeStack(sz,'bQp_static',migration_distance,H_dataset,keep);
% % Check for nan errors
% QE(isnan(QE)) = abs(Q(isnan(QE))).*0.1;
% % get mean
% bQ_static = wmean(Q,1./QE,'dim',3,'omitnan');
% bQse_static = nanstd(Q,[],3)./length(migration_distance).^0.5;
% bQE_static = rssq(QE,3);
% bQp_static = wmean(p,1./QE,'dim',3,'omitnan');

% % Reset main
% bQ = bQ_main;
% bQse = bQse_main;
% bQE = bQE_main;
% bQEsum = bQE_main; % dummy
% bQp = bQp_main;
% 
% % Save as .mat file because I love matlab
% if contains(outfile,'all_basins')
%     save(['basin_discharge_migrate_mean_' H_dataset '_all_basins.mat'],...
%         'bQ','bQE','bQp','bQse',...
%         'bQ_insitu','bQE_insitu','bQp_insitu','bQse_insitu',...
%         'bQ_static','bQE_static','bQp_static','bQse_static',...
%         'bQ_NF','bQE_NF','bQp_NF','bQse_NF',...
%         'bQ_NDH','bQE_NDH','bQp_NDH','bQ_NDH',...
%         'bQ_GSFC','bQE_GSFC','bQp_GSFC','bQse_GSFC',...
%         'bQ_GEMB','bQE_GEMB','bQp_GEMB','bQse_GEMB',...
%         'time','velocity_source');
% else
%     save(['basin_discharge_migrate_mean_' H_dataset '.mat'],...
%         'bQ','bQE','bQp','bQse',...
%         'bQ_insitu','bQE_insitu','bQp_insitu','bQse_insitu',...
%         'bQ_static','bQE_static','bQp_static','bQse_static',...
%         'bQ_NF','bQE_NF','bQp_NF','bQse_NF',...
%         'bQ_NDH','bQE_NDH','bQp_NDH','bQ_NDH',...
%         'bQ_GSFC','bQE_GSFC','bQp_GSFC','bQse_GSFC',...
%         'bQ_GEMB','bQE_GEMB','bQp_GEMB','bQse_GEMB',...
%         'time','velocity_source');
% end

    
end




%% buildDischargeStack(sz,'bQ');
function out = buildDischargeStack(sz,var,migration_distance,H_dataset,keep,ns)

    out = zeros(sz).*NaN;
    for kk = 1:length(migration_distance)
	    % - load data
		if ns == 1
			tmp = load(['basin_discharge_migrate_' num2str(migration_distance(kk)) 'm_' H_dataset '_all_basins_ns.mat'],var);
		else
			tmp = load(['basin_discharge_migrate_' num2str(migration_distance(kk)) 'm_' H_dataset '_all_basins.mat'],var);
		end
        tmp = tmp.(var);
        % - trim
        tmp = tmp(keep,:);
	    % - build stack
        out(:,:,kk) = tmp;
    end

end

