function fill_ice_velocity(migration_distance)

% add paths to libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
end

%% Load flux gate

g = load('../out/pub/gates/flux_gates_migrated.mat');
migration_idx = find(g.migration_distance == migration_distance); % metres
gate_x = g.gate_x_migrate{migration_idx};
gate_y = g.gate_y_migrate{migration_idx};
gate_nan = isnan(gate_x); % indices of gate nans
clear g


%% Load raw velocity

load(['../out/int/gate_data/gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm_compiled.mat'])

%% Load reference velocity

ref = load(['../out/int/gate_data/reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_vx','gate_vy','gate_vx_err','gate_vy_err','gate_fd','gate_vxd','gate_vyd','gate_theta','gate_ctvd','gate_ctvd_err');

%% Remove outliers

% Align datasources and remove some layers that turned out to be unhelpful
% (e.g. multi-year coarse velocities in the middle of monthly high-res velocities)
[vx_raw,remove] = align_all_datasources(vx_raw,source_vel,time_vel);
vy_raw = align_all_datasources(vy_raw,source_vel,time_vel);
vx_raw(:,remove) = [];
vy_raw(:,remove) = [];
vxE_raw(:,remove) = [];
vyE_raw(:,remove) = [];
source_vel(remove) = [];
time_vel(remove) = [];
clear remove

% initialise
vx_clean = vx_raw;
vy_clean = vy_raw;
vxE_clean = vxE_raw;
vyE_clean = vyE_raw;

% scaling factor for outlier removal 
c=-1/(sqrt(2)*erfcinv(3/2));

% add some negligible noise to the time vector, to permit detrending with
% duplicate times
time_vel = time_vel(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time_vel));
tmp = time_vel + r;
tmp = sort(tmp);

% Prepare data cleaning
gate_theta = repmat(ref.gate_theta,[1,length(time_vel)]);
sp = abs(vx_clean.*sin(gate_theta) - vy_clean.*cos(gate_theta)); % use the cross-gate velocity to find outliers
%sp = hypot(vx_clean,vy_clean);
spE = hypot(vxE_clean,vyE_clean);
removed = zeros(size(vx_clean));

% Global outlier removal
%   - stage 1
insuff = sum(isfinite(sp),2) < size(sp,2)*0.3; % need more than 30% of timeseries for outlier removal to be meaningful
sp_detrend = detrend(sp',1,'omitnan','samplepoints',datetime(tmp,'convertfrom','datenum'))'; % remove linear trend from all timeseries; takes a while...
sMAD = c.*nanmedian(abs(sp_detrend-nanmedian(sp_detrend,2)),2);
removed(abs(sp_detrend-nanmedian(sp_detrend,2)) > sMAD.*5) = 1;
removed(insuff,:) = 0; % only apply global filter to timeseries with enough data points
sp(logical(removed)) = NaN;
spE(logical(removed)) = NaN;
%   - stage 2
insuff = sum(isfinite(sp),2) < size(sp,2)*0.3; % need more than 30% of timeseries for outlier removal to be meaningful
sp_detrend = detrend(sp',1,'omitnan','samplepoints',datetime(tmp,'convertfrom','datenum'))'; % remove linear trend from all timeseries; takes a while...
sMAD = c.*nanmedian(abs(sp_detrend-nanmedian(sp_detrend,2)),2);
removed(abs(sp_detrend-nanmedian(sp_detrend,2)) > sMAD.*2) = 1;
removed(insuff,:) = 0; % only apply global filter to timeseries with enough data points
sp(logical(removed)) = NaN;
spE(logical(removed)) = NaN;

% Local outlier removal
%   - add negligible random noise to time so outlier detection works
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time_vel));
tmp = time_vel + r;
tmp = sort(tmp);
%   - stage 1 (4 month window)
tf = isoutlier(sp,'movmedian',125,2,'samplepoints',tmp,'ThresholdFactor', 2); % outliers are those more than 3-scaled MADs from the median in a 90-day moving window
too_early = time_vel<datenum(2015,1,1); % only use local outlier removal after 2015
tf(:,too_early) = false; % only use local outlier removal after 2015
removed(tf) = 1; % apply local outlier
sp(logical(removed)) = NaN; 
spE(logical(removed)) = NaN;
%   - stage 2 (3 month window)
tf = isoutlier(sp,'movmedian',93,2,'samplepoints',tmp,'ThresholdFactor', 2); % outliers are those more than 3-scaled MADs from the median in a 90-day moving window
too_early = time_vel<datenum(2015,1,1); % only use local outlier removal after 2015
tf(:,too_early) = false; % only use local outlier removal after 2015
removed(tf) = 1; % apply local outlier
sp(logical(removed)) = NaN; 


% Apply outlier removal to easting and northing velocity
removed = logical(removed);
vx_clean(removed) = NaN;
vy_clean(removed) = NaN;
vxE_clean(removed) = NaN;
vyE_clean(removed) = NaN;

% clear some space
clear sp spE

% save
%save(['gate_vel_clean_migrate_' num2str(migration_distance) 'm.mat'],'vx_clean','vy_clean','vxE_clean','vyE_clean','time_vel','source_vel','removed');

%% Fill gaps

% initialise
vx_filled = vx_clean;
vy_filled = vy_clean;
vxE_filled = vxE_clean;
vyE_filled = vyE_clean;

% sort time
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time_vel));
tmp = time_vel + r;
tmp = sort(tmp);

% Fill small time-series gaps
filled = zeros(size(vx_filled));
for i = 1:length(gate_x)
    if isfinite(gate_x(i))
        % vx
        ts = vx_filled(i,:);
        if sum(isfinite(ts))>1
            ts = interp1gap(tmp,ts,tmp,62,'linear','extrap',NaN);
        end
        vx_filled(i,:) = ts;
        % vy
        ts = vy_filled(i,:);
        if sum(isfinite(ts))>1
            ts = interp1gap(tmp,ts,tmp,62,'linear','extrap',NaN);
        end
        vy_filled(i,:) = ts;
    end
end

% Fill small (<=300 m) spatial gaps
for i = 1:length(time_vel)
    % vx
    prof = vx_filled(:,i);
    prof = interp1gap(prof,4,'linear','extrap',NaN);
    vx_filled(:,i) = prof;
    % vy
    prof = vy_filled(:,i);
    prof = interp1gap(prof,4,'linear','extrap',NaN);
    vy_filled(:,i) = prof;
end

% Fill remaining time-series gaps
for i = 1:length(gate_x)
    if isfinite(gate_x(i))
        % vx
        ts = vx_filled(i,:);
        if sum(isfinite(ts))>1
            ts = interp1gap(tmp,ts,tmp,'linear','extrap',NaN);
            ts = fillmissing(ts,'next');
            ts = fillmissing(ts,'previous');
        end
        vx_filled(i,:) = ts;
        % vy
        ts = vy_filled(i,:);
        if sum(isfinite(ts))>1
            ts = interp1gap(tmp,ts,tmp,'linear','extrap',NaN);
            ts = fillmissing(ts,'next');
            ts = fillmissing(ts,'previous');
        end
        vy_filled(i,:) = ts;
    end
end

% Any timeseries that had just 1 or no observations still need filling.
% Fill these using the reference velocity
disp([ num2str(sum(isnan(vx_filled(:)))) ' nans remaining in vx_filled before using reference velocity']);
for i = 1:length(time_vel)
    % vx
    tmp_vx = vx_filled(:,i);
    tmp_vxE = vxE_filled(:,i);
    isn = isnan(tmp_vx);
    tmp_vx(isn) = ref.gate_vx(isn);
    tmp_vxE(isn) = ref.gate_vx_err(isn);
    vx_filled(:,i) = tmp_vx;
    vxE_filled(:,i) = tmp_vxE;
    % vy
    tmp_vy = vy_filled(:,i);
    tmp_vyE = vyE_filled(:,i);
    isn = isnan(tmp_vy);
    tmp_vy(isn) = ref.gate_vy(isn);
    tmp_vyE(isn) = ref.gate_vy_err(isn);
    vy_filled(:,i) = tmp_vy;
    vyE_filled(:,i) = tmp_vyE;
end


%% Smooth the time-series with a 60-day moving window

% prep time
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time_vel));
tmp = time_vel + r;
tmp = sort(tmp);

% Apply smoother
vx_filled = movmean(vx_filled,93,2,'omitnan','samplepoints',tmp);
vx_filled = movmean(vx_filled,125,2,'omitnan','samplepoints',tmp);
vy_filled = movmean(vy_filled,93,2,'omitnan','samplepoints',tmp);
vy_filled = movmean(vy_filled,125,2,'omitnan','samplepoints',tmp);
vxE_filled = movmean(vxE_filled,93,2,'omitnan','samplepoints',tmp);
vxE_filled = movmean(vxE_filled,125,2,'omitnan','samplepoints',tmp);
vyE_filled = movmean(vyE_filled,93,2,'omitnan','samplepoints',tmp);
vyE_filled = movmean(vyE_filled,125,2,'omitnan','samplepoints',tmp);

% Set error to 10% of velocity where we have filled gaps
isn = isnan(vxE_filled) | isnan(vyE_filled);
vxE_filled(isn) = abs(vx_filled(isn)).*0.1;
vyE_filled(isn) = abs(vy_filled(isn)).*0.1;

% Check for unrealistically large or small errors
vxE_filled(vxE_filled>5e3 | vxE_filled<=0) = abs(vx_filled(vxE_filled>5e3 | vxE_filled<=0)).*0.1;
vyE_filled(vyE_filled>5e3 | vyE_filled<=0) = abs(vy_filled(vyE_filled>5e3 | vyE_filled<=0)).*0.1;

% Make sure there are gaps in velocity where there are gaps in the gate
vx_filled(gate_nan,:) = NaN;
vy_filled(gate_nan,:) = NaN;
vxE_filled(gate_nan,:) = NaN;
vyE_filled(gate_nan,:) = NaN;
filled(isfinite(vx_filled) & isnan(vx_clean)) = 1;

% Save
save(['../out/int/gate_data/gate_vel_filled_migrate_' num2str(migration_distance) 'm.mat'],'vx_filled','vy_filled','vxE_filled','vyE_filled','time_vel','source_vel','filled');

end


%% Function align_all_datasources
function [velocity,remove] = align_all_datasources(velocity,source,time)

% add negligible random noise to time to avoid duplicates
time = time(:)';
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time));
time = time + r;
time = sort(time);

% Prep
idxS1 = source==6;
idx0 = source==2 & time>min(time(idxS1));
timeS1 = time(idxS1);
time0 = time(idx0);
full_time = min(timeS1):30:max(timeS1);

% Get fits through different data sources
d = zeros([size(velocity,1),1]);
for i = 1:size(velocity,1)
    if sum(isfinite(velocity(i,idx0)))>5 && sum(isfinite(velocity(i,idxS1)))>5 % only bother making the fit if we have enough of both sources
        % Get S1 fit
        [brob, ~] = robustfit(timeS1, velocity(i,idxS1));
        SLF_S1 = brob(1) + brob(2)*full_time;
        % Get fit through everything else
        [brob, ~] = robustfit(time0, velocity(i,idx0));
        SLF0 = brob(1) + brob(2)*full_time;
        % Calculate the difference
        d(i) = nanmean(SLF_S1(:)) - nanmean(SLF0(:));
    end
end
d(isnan(d)) = 0;

% Apply shift to velocities
velocity(:,source~=6) = velocity(:,source~=6) + d;
velocity(:,source==4) = velocity(:,source==4) - d; % don't apply to ITSLIVE full Antarctica in this way


% Then align ITSLIVE full Antarctica 240x240 m data with MEaSUREs 1x1 km (after adjusting MEaSURes)
%   - get the MEaSUREs index
M_idx = find(source==1);
M_time = time(M_idx);
%   - Get the ITSLIVE index
I_idx = find(source==4);
I_time = time(I_idx);
%   - Remove ITSLIVE data before 1996 and after 2010
remove = I_time<=datenum(1996,1,1) | I_time>=datenum(2010,1,1);
I_idx(remove) = [];
I_time(remove) = [];
clear remove
%   - Extract the datasets
I_vel = velocity(:,I_idx);
tmp = velocity(:,M_idx);
M_vel = zeros(size(I_vel)).*NaN;
for i = 1:numel(I_idx)
    [~,nearidx] = findNearest(M_time,I_time(i));
    M_vel(:,i) = tmp(:,nearidx);
end
clear tmp nearidx
%   - Get the difference between datasets
I_vs_M = nanmean((M_vel - I_vel),2);
%   - adjust the MEaSUREs velocity
velocity(:,I_idx) = velocity(:,I_idx) + I_vs_M;
clear I_vel M_vel tmp I_time I_idx remove M_time M_idx


% Finally, remove some unwanted layers from the stack
remove = zeros([1,length(source)]);
remove(source==4 & time<=datenum(1996,1,1)) = 1; % remove ITSLIVE before 1996
remove(source==4 & time>=datenum(2006,1,1)) = 1; % remove ITSLIVE after 2006
remove(source==1 & time>=datenum(2016,1,1)) = 1; % remove MEaSUREs annual after 2016
remove(source==5 & time>=datenum(2016,1,1)) = 1; % remove MEaSUREs multiyear mosaic after 2016 (once we have monthly)
remove(source==2) = 1; % remove all ENVEO data
remove = logical(remove);

end



