% merge_discharge_timeseries_SID_corrected

clear
close all
clc

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('../'));
end

%% Preparation

% set netcdf compression factor
compression_factor = 5; % 0-9

% Set gate migration distance
migration_distance = 0:200:3000; % metres

% basins and gates
load('../out/int/basins/all_basins.mat');

% Balance discharge
balance_discharge = load('../out/int/discharge/balance/balance_discharge.mat');

% Thickness datasets
H_datasets = {'FrankenBed','FrankenBedAdj','BedMachine','BedMap2'};


%% Write output

% Find basins with discharge
[basins,balance_discharge,keep] = trim_basins;

% Balance discharge
balance_discharge_to_netcdf(basins,balance_discharge,'balance_discharge.nc');
balance_discharge_to_csv(basins,balance_discharge,'balance_discharge.csv');

% Basins
basins_to_netcdf(basins,'basins.nc',compression_factor);
basins_to_shapefile(basins,'basins.shp');

% Discharge
for i = 1:numel(H_datasets)
    discharge_to_netcdf(H_datasets{i},basins,migration_distance,['AIS_discharge_' H_datasets{i} '.nc'],compression_factor,keep);
	discharge_to_csv(H_datasets{i},basins,migration_distance,['AIS_discharge_' H_datasets{i} '.csv'],keep);
	discharge_to_netcdf(H_datasets{i},basins,migration_distance,['AIS_discharge_' H_datasets{i} '_ns.nc'],compression_factor,keep);
	discharge_to_csv(H_datasets{i},basins,migration_distance,['AIS_discharge_' H_datasets{i} '_ns.csv'],keep);
end

% Save FrankenBedAdj info
gates = load('../out/pub/gates/flux_gates_migrated');
FrankenBedAdj_to_netcdf(gates,migration_distance,'FrankenBedAdj.nc',compression_factor);
FrankenBedAdj_to_netcdf(gates,migration_distance,'FrankenBedAdj_ns.nc',compression_factor);


quit;


