% plot_discharge_summary_figs

clear
close all
clc

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));  
    addpath(genpath('/resstore/b0133/Data/Antarctic_boundaries_nsidc0709'));
end

%% Load

% basins
basin_names = ncread('../out/pub/basins/basins.nc','basin_name');
basin_ID = ncread('../out/pub/basins/basins.nc','basin_type_ID');
basin_type = ncread('../out/pub/basins/basins.nc','basin_type');
basin_x = ncread('../out/pub/basins/basins.nc','perim_x');
basin_y = ncread('../out/pub/basins/basins.nc','perim_y');
centroid_x = ncread('../out/pub/basins/basins.nc','centroid_x');
centroid_y = ncread('../out/pub/basins/basins.nc','centroid_y');

% discharge
bQ = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_mean');
bQns = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed_ns.nc','discharge_mean'); % no smoothing
bQse = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_standard_error');
bQp = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_coverage_all_gates'),3);
time = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','time')+datenum(1950,1,1,0,0,0);

% Other bed source
bQ_FBA = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBedAdj.nc','discharge_mean');
bQ_BM = ncread('../out/pub/discharge/nc/AIS_discharge_BedMachine.nc','discharge_mean');
bQ_B2 = ncread('../out/pub/discharge/nc/AIS_discharge_BedMap2.nc','discharge_mean');


% Corrections
corrections.SMB = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','SMB_correction_all_gates'),3);
corrections.firn = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','FDM_firn_correction_all_gates'),3);
corrections.dH = nanmean(ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','dH_correction_all_gates'),3);
corrections.net = corrections.firn + corrections.SMB + corrections.dH;

% Firn models
FDM_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates');
GSFC_Q = ncread('../out/pub/discharge/nc/AIS_discharge_FrankenBed.nc','discharge_all_gates_GSFC');
firn_diff = (FDM_Q-GSFC_Q)./FDM_Q.*100;
clear FDM_Q GSFC_Q

% velocity
% load('reference_velocity_200m.mat','vx','vy');
% load('reference_thickness_200m.mat','x','y');
% sp = hypot(vx,vy);
% clear vx vy
% % -- BedMachine mask
% [X,Y] = meshgrid(x,y);
% mask = bedmachine_interp('mask',X,Y);
% mask = single(ismember(mask,[1 2 3 4]) & isfinite(sp));
% mask(mask==0)=NaN;
% clear X Y 
% % -- save
% sp = sp.*mask;
% sp_x = x;
% sp_y = y;
% save('reference_speed_masked.mat','sp','sp_x','sp_y','-v7.3');
load('../out/pub/reference_grids/reference_speed_masked.mat'); % made using the code above

%% Calculate trends

% 1996-2023
tr_full.lin = zeros([numel(basin_ID),1]).*NaN;
tr_full.rlin = zeros([numel(basin_ID),1]).*NaN;
tr_full.R_SLF = zeros([numel(basin_ID),1]).*NaN;
tr_full.P_SLF = zeros([numel(basin_ID),1]).*NaN;
for i = 1:numel(basin_ID)
    ts = bQ(i,:);
    % Get linear fit
    [p, ~, mu] = polyfit(time(:), ts(:), 1);
    fit_ts = polyval(p, time(:), [], mu);
    tr_full.lin(i) = diff([fit_ts(end), fit_ts(1)])./(diff([max(time(:)), min(time(:))])/365.25);
    tr_full.rlin(i) = tr_full.lin(i)/nanmedian(fit_ts).*100;
    [tr_full.R_SLF(i), tr_full.P_SLF(i)] = corr(time(:), ts(:), 'type', 'Pearson');
end

%% Plot prep

% setup patches for summer
ptchX = [datenum(2015,10,1),datenum(2015,10,1),datenum(2016,3,1),datenum(2016,3,1),datenum(2015,10,1);...
    datenum(2016,10,1),datenum(2016,10,1),datenum(2017,3,1),datenum(2017,3,1),datenum(2016,10,1);...
    datenum(2017,10,1),datenum(2017,10,1),datenum(2018,3,1),datenum(2018,3,1),datenum(2017,10,1);...
    datenum(2018,10,1),datenum(2018,10,1),datenum(2019,3,1),datenum(2019,3,1),datenum(2018,10,1);...
    datenum(2019,10,1),datenum(2019,10,1),datenum(2020,3,1),datenum(2020,3,1),datenum(2019,10,1);...
    datenum(2020,10,1),datenum(2020,10,1),datenum(2021,3,1),datenum(2021,3,1),datenum(2020,10,1);...
    datenum(2021,10,1),datenum(2021,10,1),datenum(2022,3,1),datenum(2022,3,1),datenum(2021,10,1);...
    datenum(2022,10,1),datenum(2022,10,1),datenum(2023,3,1),datenum(2023,3,1),datenum(2022,10,1)];
    
% Peninsula boundary
apn_x = [-2.6354   -0.9919]*1e6;
apn_y = [0.2446    1.6165]*1e6;

% Index for time after 2016
A16 = time>datenum(2015,10,1);

% Bed colormap
cmap = cbrewer('qual','Set1',4);
FB_col = 'k';
FBA_col = cmap(2,:);
BM_col = cmap(3,:);
B2_col = cmap(4,:);

% Corrections colormap
cor_cmap = cbrewer('qual','Set1',4);

% trend colormap
cpts = -7.5:.05:7.5;
cmap = cmocean('balance',length(cpts));

% Firn
num_gates = 16;
gate_cmap = colorcet('Gouldian','N',num_gates);

%% Plot

for i = 1:size(basin_names,1)
    
    disp(['Progress: ' num2str(i) '/' num2str(size(basin_names,1)) ]);
    
    % Get basin name and type
    n = strtrim(basin_names(i,:));
    type = strtrim(basin_type(i,:));
    
    % set count string for name
    if i<10
        count_str = ['000' num2str(i)];
    elseif i>=10 && i<100
        count_str = ['00' num2str(i)];
    elseif i>=100 && i<1000
        count_str = ['0' num2str(i)];
    else
        count_str = num2str(i);
    end
    
    % Prep MODIS MOA background
    max_x = nanmax(basin_x(i,:)); 
    min_x = nanmin(basin_x(i,:));
    max_y = nanmax(basin_y(i,:)); 
    min_y = nanmin(basin_y(i,:));
    x_len = max_x - min_x;
    y_len = max_y - min_y;
    len = max([x_len,y_len]);
    buffer = min([len.*0.1,20000]);
%     if i>6
%         [moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',[min_x max_x],[min_y max_y],buffer);
%         [modis_X,modis_Y] = meshgrid(modis_x,modis_y);
%         moa=uint16(moa);
%         mask = bedmachine_interp('mask',modis_X,modis_Y);
%         moa(ismember(mask,[0,3])) = 0;
%         RGB = mat2im(moa,gray(256),[1 20000]); 
%     end
    
    % Prepare trend data
    [~,color_ind] = findNearest(cpts,tr_full.rlin(i));
    x = basin_x(i,:); y = basin_y(i,:);
    idx = strfind( isnan(x), true(1,3) );
    if ~isempty(idx)
        idx = idx(1)-1;
        x = x(1:idx); y = y(1:idx);
    end
    
    % Are we on the Peninsula?
    apn = 0;
    if basin_ID(i) == 4 || sum(inpoly2([apn_x(:),apn_y(:)],[centroid_x(i),centroid_y(i)]))>0
        apn=1;
    end
    
    
    % Initialise figure;
    figure('color','w','units','inches','position',[2 2 8 6],'visible','off');
    subplot = @(m,n,p) subtightplot (m, n, p,[.1 0.1],[.1 .1],[.1 .1]);
    
    % Plot Antarctica location
    p1 = subplot(5,2,[1,3]);
    antbounds('gl','polyshape','facecolor',[.8 .8 .8]); hold on
    %   - plot all boundaries
    if apn==1
        xplot = basin_x(basin_ID==4,:)';
        yplot = basin_y(basin_ID==4,:)';
        plot(xplot(:),yplot(:),'color',[.3 .3 .3 .5]);
    else
        if i>7
            if basin_ID(i) == 1
                plot_basins('imbie','color',[.3 .3 .3 .5]);
            elseif basin_ID(i) == 2
                plot_basins('imbie refined','color',[.3 .3 .3 .5]);
            elseif basin_ID(i) == 3
                xplot = basin_x(basin_ID==3,:)';
                yplot = basin_y(basin_ID==3,:)';
                plot(xplot(:),yplot(:),'color',[.3 .3 .3 .5]);
            elseif basin_ID(i) == 5
                xplot = basin_x(basin_ID==5,:)';
                yplot = basin_y(basin_ID==5,:)';
                plot(xplot(:),yplot(:),'color',[.3 .3 .3 .5]);
            end
        end
    end
    antbounds('coast','k');
    %   - highlight this basin/glacier/ice shelf
    if i>7
        if apn==1
            mid_loc = ceil(length(x)/2);
            fill(x,y,'r','linewidth',0.5,'edgecolor','none');
            scatter(x(mid_loc),y(mid_loc),20,'r','filled');
        else
            mid_loc = ceil(length(x)/2);
            fill(x,y,'r','linewidth',0.5);
            scatter(x(mid_loc),y(mid_loc),20,'r','filled');
        end
    end
    %scatter(centroid_x(i),centroid_y(i),15,'r','filled');
    if apn==1
        set(gca,'XLim',apn_x,'YLim',apn_y);
    end
    title(n,'interpreter','none','fontname','Helvetica','fontweight','bold','fontsize',10)    
    set(gca,'XColor', 'none','YColor','none')
    pos1 = p1.Position;
    p1.Position = [pos1(1)-0.075 pos1(2)+0.05 pos1(3).*0.7 pos1(4).*0.7];
    
    % Plot trend and filled region
    p2 = subplot(5,2,[2,4]);
%     da = daspect; da = [1 1 da(3)];
%     if i>6
%         hm = image(modis_x,modis_y,RGB); axis xy; set(hm,'alphadata',moa>0)
%         uistack(hm,'bottom'); ax = axis; axis xy; daspect(da); hold on
%     end
    antbounds('coast','color','k'); hold on;
    % if colouring by trend
    %h = fill(x,y,cmap(color_ind,:),'edgecolor','none');
    %set(h,'facealpha',.8)
    imagescn(sp_x,sp_y,log10(sp));
    rgbmap('white','ice blue','ocean blue','tan','red','mahogany','black',455);
    caxis(log10([1 3000]))
    cb1 = colorbar('location','eastoutside');
    ylabel(cb1,'Speed (km yr^{-1})');
    plot(basin_x(i,:),basin_y(i,:),'color','k','linestyle','-','marker','none','linewidth',2);
    set(gca,'XLim',[min_x-buffer max_x+buffer]);
    set(gca,'YLim',[min_y-buffer max_y+buffer]);
    %try; measuresps('vel','k'); end
    title(['1996-2023 trend: ' num2str(round(tr_full.lin(i).*10,2)) ' Gt decade^{-2} or ' num2str(round(tr_full.rlin(i),2)) ' % yr^{-2}'],'fontname','Helvetica','fontsize',10);
    axis off
    pos2 = p2.Position;
    p2.Position = [pos2(1)-0.3 pos2(2)-0.025 pos2(3).*1.25 pos2(4).*1.25];
    cb1_pos = cb1.Position;
    cb1.Position = [cb1_pos(1) cb1_pos(2)+0.04 cb1_pos(3)*0.75 cb1_pos(4).*0.75];
    
    % Discharge timeseries 1996-2023
    p3 = subplot(5,2,5);
    scatter(time,bQ(i,:),8,'k','filled','markerEdgeColor','none'); hold on; datetick('x')
    ptch = shadedErrorBar(time,bQ(i,:),1.96.*bQse(i,:)); % 95% confidence bounds
    ptch.mainLine.Color = 'none'; ptch.edge(1).Color = 'none'; ptch.edge(2).Color = 'none';
    ptch.patch.FaceColor = [.3 .3 .3]; ptch.patch.FaceAlpha = 0.3;
    %ylabel('Discharge (Gt yr^{-1})','fontsize',10);
    box on
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
        'XTick',datenum(1996:2:2024,1,1),'XTickLabel',{' '});
    pos3 = p3.Position;
    p3.Position = [pos3(1)-0.01 pos3(2)+0.03 pos3(3) pos3(4).*1.5];
    ylims = get(gca,'YLim');
    rng = diff(ylims);
    text(datenum(1997,1,1),max(ylims)+rng*0.1,'Discharge (Gt yr^{-1})','fontname','Helvetica','fontsize',8);

    % proportion observed 1996-2023
    p4 = subplot(5,2,7);
    scatter(time,bQp(i,:),8,'k','filled'); datetick('x');
    %ylabel('Observed (%)','fontsize',10);
    box on;
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
        'XTick',datenum(1996:2:2024,1,1),...
        'XTickLabel',{' ','1998',' ','2002',' ','2006',' ','2010',...
        ' ','2014',' ','2018',' ','2022'},...
        'YLim',[0 100]);  
    pos4 = p4.Position;
    p4.Position = [pos4(1)-0.01 pos4(2)+0.05 pos4(3) pos4(4).*1.5];
    ylims = get(gca,'YLim');
    rng = diff(ylims);
    text(datenum(1997,1,1),max(ylims)+rng.*0.1,'Observed (%)','fontname','Helvetica','fontsize',8);

    
    % Discharge time-series 2016-2023
    p5 = subplot(5,2,9);
    %   - plot smoothed data
    scatter(time(A16),bQ(i,A16),8,'k','filled','markerEdgeColor','none'); hold on; datetick('x')
    ylims = get(gca,'YLim');
    ptchY = [ylims(1) ylims(2) ylims(2) ylims(1) ylims(1)];
    ptchY = repmat(ptchY,[8,1]);
    fill(ptchX',ptchY','r','facealpha',0.2,'edgecolor','none');
    ptch = shadedErrorBar(time(A16),bQ(i,A16),1.96.*bQse(i,A16)); % 95% confidence bounds
    ptch.mainLine.Color = 'none';
    ptch.edge(1).Color = 'none';
    ptch.edge(2).Color = 'none';
    ptch.patch.FaceColor = [.5 .5 .5];
    ptch.patch.FaceAlpha = 0.3;
    %   - plot unsmoothed data
    %plot(time(A16),bQns(i,A16),'k','linewidth',1);
    %   - visuals
    set(gca,'XLim',[datenum(2016,1,1) datenum(2023,6,1)],...
    'XTick',datenum(2017:2:2024,1,1),...
    'XTickLabel',{'2017','2019','2021','2023'},...
    'YLim',ylims); 
    %ylabel('Discharge (Gt yr^{-1})','fontsize',10);
    box on
    pos5 = p5.Position;
    p5.Position = [pos5(1)-0.01 pos5(2)+0.05 pos5(3) pos5(4).*1.5];
    rng = diff(ylims);
    text(datenum(2016,7,1),max(ylims)+rng.*0.1,'Discharge (Gt yr^{-1})','fontname','Helvetica','fontsize',8);
    
    % Plot different bed sources
    p6 = subplot(5,2,6);
    scatter(time,bQ(i,:),8,'k','filled'); hold on; datetick('x')
    scatter(time,bQ_FBA(i,:),8,FBA_col,'filled');
    scatter(time,bQ_BM(i,:),8,BM_col,'filled');
    scatter(time,bQ_B2(i,:),8,B2_col,'filled');
    %ylabel('Discharge (Gt yr^{-1})','fontsize',10);
    box on
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
        'XTick',datenum(1996:2:2024,1,1),...
        'XTickLabel',{' '});
    ylims = get(gca,'YLim');
    rng = diff(ylims);
    pos6 = p6.Position;
    p6.Position = [pos6(1)-0.05 pos6(2)+0.03 pos6(3) pos6(4).*1.5];
    %text(datenum(1997,1,1),max(ylims)+max(ylims).*0.1,'Discharge (Gt yr^{-1})','fontname','Helvetica','fontsize',8);
    text(datenum(2012,1,1),max(ylims)+rng.*0.1,'FB','fontname','Helvetica','fontsize',8,'color','k','fontweight','bold');
    text(datenum(2015,1,1),max(ylims)+rng.*0.1,'FBA','fontname','Helvetica','fontsize',8,'color',FBA_col,'fontweight','bold');
    text(datenum(2018,7,1),max(ylims)+rng.*0.1,'BM','fontname','Helvetica','fontsize',8,'color',BM_col,'fontweight','bold');
    text(datenum(2022,1,1),max(ylims)+rng.*0.1,'B2','fontname','Helvetica','fontsize',8,'color',B2_col,'fontweight','bold');

    % Plot corrections
    p7 = subplot(5,2,8);
    plot([time(1) time(end)],[0 0],'k--'); hold on;
    scatter(time,corrections.SMB(i,:),8,'r','filled'); datetick('x'); % downstream correction (baseline minus 'in situ')
    scatter(time,corrections.firn(i,:),8,cor_cmap(2,:),'filled');  % firn correction (baseline minus 'no firn')
    scatter(time,corrections.dH(i,:),8,cor_cmap(3,:),'filled'); % dH (baseline minus dH only)
    scatter(time,corrections.net(i,:),8,'k','filled'); % net effect of all corrections
    box on
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
        'XTick',datenum(1996:2:2024,1,1),...
        'XTickLabel',{' '});
    %ylabel('\Delta Discharge (Gt yr^{-1})','fontsize',10)
    ylims = get(gca,'YLim');
    rng = diff(ylims);
    pos7 = p7.Position;
    p7.Position = [pos7(1)-0.05 pos7(2)+0.05 pos7(3) pos7(4).*1.5];
    text(datenum(1997,1,1),max(ylims)+rng.*0.1,'\Delta Discharge (Gt yr^{-1})','fontname','Helvetica','fontsize',8);
    text(datenum(2010,1,1),max(ylims)+rng.*0.1,'SMB','fontname','Helvetica','fontsize',8,'color','r','fontweight','bold');
    text(datenum(2013,7,1),max(ylims)+rng.*0.1,'Firn','fontname','Helvetica','fontsize',8,'color',cor_cmap(2,:),'fontweight','bold');
    text(datenum(2017,1,1),max(ylims)+rng.*0.1,'dH','fontname','Helvetica','fontsize',8,'color',cor_cmap(3,:),'fontweight','bold');
    text(datenum(2020,7,1),max(ylims)+rng.*0.1,'Net','fontname','Helvetica','fontsize',8,'color','k','fontweight','bold');

    
    % Plot difference between firn models at each gate
    p8 = subplot(5,2,10);
    for j = 1:num_gates
        scatter(time,squeeze(firn_diff(i,:,j)),8,gate_cmap(j,:),'filled','markerEdgeColor','none'); 
        if j == 1; hold on; datetick('x'); end
    end
    box on
    set(gca,'XLim',[datenum(1996,1,1) datenum(2023,6,1)],...
        'XTick',datenum(1996:2:2024,1,1),...
        'XTickLabel',{' ','1998',' ','2002',' ','2006',' ','2010',...
        ' ','2014',' ','2018',' ','2022'});
    %ylabel('FDM-GSFC (% of FDM)','fontsize',10);
    ylims = get(gca,'YLim');
    rng = diff(ylims);
    pos8 = p8.Position;
    cb2 = colorbar(p8,'location','eastoutside');
    ylabel(cb2,'Distance (km)','fontsize',8)
    colormap(p8,gate_cmap);
    caxis([0 3]);
    cb2_pos = cb2.Position;
    cb2.Position = [cb2_pos(1)+0.075-0.05 cb2_pos(2)+0.05 cb2_pos(3)*0.5 cb2_pos(4)*1.5];
    p8.Position = [pos8(1)-0.05 pos8(2)+0.05 pos8(3) pos8(4).*1.5];
    text(datenum(1997,1,1),max(ylims)+rng.*0.1,'FDM-GSFC (% of FDM)','fontname','Helvetica','fontsize',8);
    
    % Export
    export_fig([ '../out/pub/figures/summary_figs/' count_str '_' n '.png'],'-dpng','-r150');
    close
    
end

