function [basins,balance_discharge,keep] = trim_basins

% Prepare basin info
names0 = ncread('all_basins.nc','basin_name');
ID0 = ncread('all_basins.nc','basin_type_ID');
type0 = ncread('all_basins.nc','basin_type');
x0 = ncread('all_basins.nc','perim_x');
y0 = ncread('all_basins.nc','perim_y');
centroid_x = ncread('all_basins.nc','centroid_x');
centroid_y = ncread('all_basins.nc','centroid_y');

% Make the names easier to work with
tmp_names = cell([length(ID0),1]);
tmp_type = cell([length(ID0),1]);
for i = 1:length(ID0)
    n = strtrim(names0(i,:));
    type = strtrim(type0(i,:));
    tmp_names{i} = n;
    tmp_type{i} = type;
end
names0 = tmp_names;
type0 = tmp_type;
clear tmp_names tmp_type

% Make the coordinates easier to work with
x = cell([1,length(ID0)]);
y = cell([1,length(ID0)]);
for i = 1:length(ID0)
    bx = x0(i,:); 
    by = y0(i,:);
    idx = strfind( isnan(bx), true(1,3) );
    if ~isempty(idx)
        idx = idx(1)-1;
        bx = bx(1:idx); 
        by = by(1:idx);
    end
    x{i} = bx;
    y{i} = by;
end

bQ = ncread('AIS_discharge_FrankenBed_all_basins.nc','discharge_mean');
keep = zeros([numel(ID0),1]);
for i = 1:numel(ID0)
    if sum(bQ(i,:)>0)>1
        keep(i) = 1;
    end
end
keep = logical(keep);

% basins
basins = struct();
basins.name = names0(keep);
basins.x = x(keep);
basins.y = y(keep);
basins.type_ID = ID0(keep);
basins.type = type0(keep);
basins.centroid = [centroid_x(keep,:), centroid_y(keep,:)];


% Balance discharge
balance_discharge = load('../out/int/discharge/balance/balance_discharge.mat');
balance_discharge.Qbal_RACMO = balance_discharge.Qbal_RACMO(keep);
balance_discharge.Qbal_HIRHAM = balance_discharge.Qbal_HIRHAM(keep);
balance_discharge.Qbal_MAR = balance_discharge.Qbal_MAR(keep);
balance_discharge.Qbal_ens = balance_discharge.Qbal_ens(keep);
balance_discharge.Qbal_err_RACMO = balance_discharge.Qbal_err_RACMO(keep);
balance_discharge.Qbal_err_HIRHAM = balance_discharge.Qbal_err_HIRHAM(keep);
balance_discharge.Qbal_err_MAR = balance_discharge.Qbal_err_MAR(keep);
balance_discharge.Qbal_err_ens = balance_discharge.Qbal_err_ens(keep);
balance_discharge.HIRHAM_tf_all = balance_discharge.HIRHAM_tf_all{keep};
balance_discharge.MAR_tf_all = balance_discharge.MAR_tf_all{keep};
balance_discharge.RACMO_tf_all = balance_discharge.RACMO_tf_all{keep};


end

